// ------------------------------------------------------------------------------
// Copyright (c) 2011 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------ 


#ifndef SWIG_CGAL_MESH_3_DECL_H
#define SWIG_CGAL_MESH_3_DECL_H

#include <CGAL/export/helpers.h>

#ifdef  SWIG_CGAL_MESH_3_EXPORT
#define SWIG_CGAL_MESH_3_DECL CGAL_DLL_EXPORT
#else
#define SWIG_CGAL_MESH_3_DECL CGAL_DLL_IMPORT
#endif

#endif // SWIG_CGAL_MESH_3_DECL_H
