# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.8
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.





from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_CGAL_Spatial_searching', [dirname(__file__)])
        except ImportError:
            import _CGAL_Spatial_searching
            return _CGAL_Spatial_searching
        if fp is not None:
            try:
                _mod = imp.load_module('_CGAL_Spatial_searching', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _CGAL_Spatial_searching = swig_import_helper()
    del swig_import_helper
else:
    import _CGAL_Spatial_searching
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


import CGAL.CGAL_Kernel
class Point_with_transformed_distance_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Point_with_transformed_distance_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Point_with_transformed_distance_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Point_with_transformed_distance_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_Spatial_searching.Point_with_transformed_distance_2_first_set
    __swig_getmethods__["first"] = _CGAL_Spatial_searching.Point_with_transformed_distance_2_first_get
    if _newclass:
        first = _swig_property(_CGAL_Spatial_searching.Point_with_transformed_distance_2_first_get, _CGAL_Spatial_searching.Point_with_transformed_distance_2_first_set)
    __swig_setmethods__["second"] = _CGAL_Spatial_searching.Point_with_transformed_distance_2_second_set
    __swig_getmethods__["second"] = _CGAL_Spatial_searching.Point_with_transformed_distance_2_second_get
    if _newclass:
        second = _swig_property(_CGAL_Spatial_searching.Point_with_transformed_distance_2_second_get, _CGAL_Spatial_searching.Point_with_transformed_distance_2_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Point_with_transformed_distance_2
    __del__ = lambda self: None
Point_with_transformed_distance_2_swigregister = _CGAL_Spatial_searching.Point_with_transformed_distance_2_swigregister
Point_with_transformed_distance_2_swigregister(Point_with_transformed_distance_2)

class Point_with_transformed_distance_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Point_with_transformed_distance_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Point_with_transformed_distance_3, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Point_with_transformed_distance_3(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_Spatial_searching.Point_with_transformed_distance_3_first_set
    __swig_getmethods__["first"] = _CGAL_Spatial_searching.Point_with_transformed_distance_3_first_get
    if _newclass:
        first = _swig_property(_CGAL_Spatial_searching.Point_with_transformed_distance_3_first_get, _CGAL_Spatial_searching.Point_with_transformed_distance_3_first_set)
    __swig_setmethods__["second"] = _CGAL_Spatial_searching.Point_with_transformed_distance_3_second_set
    __swig_getmethods__["second"] = _CGAL_Spatial_searching.Point_with_transformed_distance_3_second_get
    if _newclass:
        second = _swig_property(_CGAL_Spatial_searching.Point_with_transformed_distance_3_second_get, _CGAL_Spatial_searching.Point_with_transformed_distance_3_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Point_with_transformed_distance_3
    __del__ = lambda self: None
Point_with_transformed_distance_3_swigregister = _CGAL_Spatial_searching.Point_with_transformed_distance_3_swigregister
Point_with_transformed_distance_3_swigregister(Point_with_transformed_distance_3)

class Fuzzy_sphere_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Fuzzy_sphere_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Fuzzy_sphere_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Fuzzy_sphere_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_sphere_2_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_sphere_2_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_sphere_2
    __del__ = lambda self: None
Fuzzy_sphere_2_swigregister = _CGAL_Spatial_searching.Fuzzy_sphere_2_swigregister
Fuzzy_sphere_2_swigregister(Fuzzy_sphere_2)

class Fuzzy_iso_box_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Fuzzy_iso_box_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Fuzzy_iso_box_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Fuzzy_iso_box_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_2_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_2_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_iso_box_2
    __del__ = lambda self: None
Fuzzy_iso_box_2_swigregister = _CGAL_Spatial_searching.Fuzzy_iso_box_2_swigregister
Fuzzy_iso_box_2_swigregister(Fuzzy_iso_box_2)

class Fuzzy_sphere_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Fuzzy_sphere_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Fuzzy_sphere_3, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Fuzzy_sphere_3(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_sphere_3_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_sphere_3_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_sphere_3
    __del__ = lambda self: None
Fuzzy_sphere_3_swigregister = _CGAL_Spatial_searching.Fuzzy_sphere_3_swigregister
Fuzzy_sphere_3_swigregister(Fuzzy_sphere_3)

class Fuzzy_iso_box_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Fuzzy_iso_box_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Fuzzy_iso_box_3, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Fuzzy_iso_box_3(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_3_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_3_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_iso_box_3
    __del__ = lambda self: None
Fuzzy_iso_box_3_swigregister = _CGAL_Spatial_searching.Fuzzy_iso_box_3_swigregister
Fuzzy_iso_box_3_swigregister(Fuzzy_iso_box_3)

class Orthogonal_incremental_neighbor_search_tree_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_incremental_neighbor_search_tree_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_incremental_neighbor_search_tree_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_2
    __del__ = lambda self: None
Orthogonal_incremental_neighbor_search_tree_2_swigregister = _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_swigregister
Orthogonal_incremental_neighbor_search_tree_2_swigregister(Orthogonal_incremental_neighbor_search_tree_2)

class Orthogonal_incremental_neighbor_search_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_incremental_neighbor_search_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_incremental_neighbor_search_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_2_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_2_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_2
    __del__ = lambda self: None
Orthogonal_incremental_neighbor_search_2_swigregister = _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_2_swigregister
Orthogonal_incremental_neighbor_search_2_swigregister(Orthogonal_incremental_neighbor_search_2)

class Orthogonal_incremental_neighbor_search_tree_iterator_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_incremental_neighbor_search_tree_iterator_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_incremental_neighbor_search_tree_iterator_2, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_iterator_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_iterator_2
    __del__ = lambda self: None
Orthogonal_incremental_neighbor_search_tree_iterator_2_swigregister = _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_swigregister
Orthogonal_incremental_neighbor_search_tree_iterator_2_swigregister(Orthogonal_incremental_neighbor_search_tree_iterator_2)

class Orthogonal_incremental_neighbor_search_iterator_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_incremental_neighbor_search_iterator_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_incremental_neighbor_search_iterator_2, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_iterator_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_iterator_2
    __del__ = lambda self: None
Orthogonal_incremental_neighbor_search_iterator_2_swigregister = _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_swigregister
Orthogonal_incremental_neighbor_search_iterator_2_swigregister(Orthogonal_incremental_neighbor_search_iterator_2)

class Incremental_neighbor_search_tree_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Incremental_neighbor_search_tree_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Incremental_neighbor_search_tree_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_2
    __del__ = lambda self: None
Incremental_neighbor_search_tree_2_swigregister = _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_swigregister
Incremental_neighbor_search_tree_2_swigregister(Incremental_neighbor_search_tree_2)

class Incremental_neighbor_search_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Incremental_neighbor_search_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Incremental_neighbor_search_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Incremental_neighbor_search_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_2_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_2_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_2
    __del__ = lambda self: None
Incremental_neighbor_search_2_swigregister = _CGAL_Spatial_searching.Incremental_neighbor_search_2_swigregister
Incremental_neighbor_search_2_swigregister(Incremental_neighbor_search_2)

class Incremental_neighbor_search_tree_iterator_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Incremental_neighbor_search_tree_iterator_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Incremental_neighbor_search_tree_iterator_2, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_iterator_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_iterator_2
    __del__ = lambda self: None
Incremental_neighbor_search_tree_iterator_2_swigregister = _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_swigregister
Incremental_neighbor_search_tree_iterator_2_swigregister(Incremental_neighbor_search_tree_iterator_2)

class Incremental_neighbor_search_iterator_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Incremental_neighbor_search_iterator_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Incremental_neighbor_search_iterator_2, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Incremental_neighbor_search_iterator_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_iterator_2
    __del__ = lambda self: None
Incremental_neighbor_search_iterator_2_swigregister = _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_swigregister
Incremental_neighbor_search_iterator_2_swigregister(Incremental_neighbor_search_iterator_2)

class K_neighbor_search_tree_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, K_neighbor_search_tree_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, K_neighbor_search_tree_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_K_neighbor_search_tree_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_2
    __del__ = lambda self: None
K_neighbor_search_tree_2_swigregister = _CGAL_Spatial_searching.K_neighbor_search_tree_2_swigregister
K_neighbor_search_tree_2_swigregister(K_neighbor_search_tree_2)

class K_neighbor_search_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, K_neighbor_search_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, K_neighbor_search_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_K_neighbor_search_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_2_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_2
    __del__ = lambda self: None
K_neighbor_search_2_swigregister = _CGAL_Spatial_searching.K_neighbor_search_2_swigregister
K_neighbor_search_2_swigregister(K_neighbor_search_2)

class K_neighbor_search_tree_iterator_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, K_neighbor_search_tree_iterator_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, K_neighbor_search_tree_iterator_2, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_K_neighbor_search_tree_iterator_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_iterator_2
    __del__ = lambda self: None
K_neighbor_search_tree_iterator_2_swigregister = _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_swigregister
K_neighbor_search_tree_iterator_2_swigregister(K_neighbor_search_tree_iterator_2)

class K_neighbor_search_iterator_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, K_neighbor_search_iterator_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, K_neighbor_search_iterator_2, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_K_neighbor_search_iterator_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_iterator_2
    __del__ = lambda self: None
K_neighbor_search_iterator_2_swigregister = _CGAL_Spatial_searching.K_neighbor_search_iterator_2_swigregister
K_neighbor_search_iterator_2_swigregister(K_neighbor_search_iterator_2)

class Orthogonal_k_neighbor_search_tree_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_k_neighbor_search_tree_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_k_neighbor_search_tree_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_2
    __del__ = lambda self: None
Orthogonal_k_neighbor_search_tree_2_swigregister = _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_swigregister
Orthogonal_k_neighbor_search_tree_2_swigregister(Orthogonal_k_neighbor_search_tree_2)

class Orthogonal_k_neighbor_search_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_k_neighbor_search_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_k_neighbor_search_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_2_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_2
    __del__ = lambda self: None
Orthogonal_k_neighbor_search_2_swigregister = _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_2_swigregister
Orthogonal_k_neighbor_search_2_swigregister(Orthogonal_k_neighbor_search_2)

class Orthogonal_k_neighbor_search_tree_iterator_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_k_neighbor_search_tree_iterator_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_k_neighbor_search_tree_iterator_2, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_iterator_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_iterator_2
    __del__ = lambda self: None
Orthogonal_k_neighbor_search_tree_iterator_2_swigregister = _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_swigregister
Orthogonal_k_neighbor_search_tree_iterator_2_swigregister(Orthogonal_k_neighbor_search_tree_iterator_2)

class Orthogonal_k_neighbor_search_iterator_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_k_neighbor_search_iterator_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_k_neighbor_search_iterator_2, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_iterator_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_iterator_2
    __del__ = lambda self: None
Orthogonal_k_neighbor_search_iterator_2_swigregister = _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_swigregister
Orthogonal_k_neighbor_search_iterator_2_swigregister(Orthogonal_k_neighbor_search_iterator_2)

class Orthogonal_incremental_neighbor_search_tree_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_incremental_neighbor_search_tree_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_incremental_neighbor_search_tree_3, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_3(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_3
    __del__ = lambda self: None
Orthogonal_incremental_neighbor_search_tree_3_swigregister = _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_swigregister
Orthogonal_incremental_neighbor_search_tree_3_swigregister(Orthogonal_incremental_neighbor_search_tree_3)

class Orthogonal_incremental_neighbor_search_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_incremental_neighbor_search_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_incremental_neighbor_search_3, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_3(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_3_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_3_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_3
    __del__ = lambda self: None
Orthogonal_incremental_neighbor_search_3_swigregister = _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_3_swigregister
Orthogonal_incremental_neighbor_search_3_swigregister(Orthogonal_incremental_neighbor_search_3)

class Orthogonal_incremental_neighbor_search_tree_iterator_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_incremental_neighbor_search_tree_iterator_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_incremental_neighbor_search_tree_iterator_3, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_iterator_3()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_iterator_3
    __del__ = lambda self: None
Orthogonal_incremental_neighbor_search_tree_iterator_3_swigregister = _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_swigregister
Orthogonal_incremental_neighbor_search_tree_iterator_3_swigregister(Orthogonal_incremental_neighbor_search_tree_iterator_3)

class Orthogonal_incremental_neighbor_search_iterator_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_incremental_neighbor_search_iterator_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_incremental_neighbor_search_iterator_3, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_iterator_3()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_iterator_3
    __del__ = lambda self: None
Orthogonal_incremental_neighbor_search_iterator_3_swigregister = _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_swigregister
Orthogonal_incremental_neighbor_search_iterator_3_swigregister(Orthogonal_incremental_neighbor_search_iterator_3)

class Incremental_neighbor_search_tree_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Incremental_neighbor_search_tree_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Incremental_neighbor_search_tree_3, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_3(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_3
    __del__ = lambda self: None
Incremental_neighbor_search_tree_3_swigregister = _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_swigregister
Incremental_neighbor_search_tree_3_swigregister(Incremental_neighbor_search_tree_3)

class Incremental_neighbor_search_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Incremental_neighbor_search_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Incremental_neighbor_search_3, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Incremental_neighbor_search_3(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_3_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_3_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_3
    __del__ = lambda self: None
Incremental_neighbor_search_3_swigregister = _CGAL_Spatial_searching.Incremental_neighbor_search_3_swigregister
Incremental_neighbor_search_3_swigregister(Incremental_neighbor_search_3)

class Incremental_neighbor_search_tree_iterator_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Incremental_neighbor_search_tree_iterator_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Incremental_neighbor_search_tree_iterator_3, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_iterator_3()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_iterator_3
    __del__ = lambda self: None
Incremental_neighbor_search_tree_iterator_3_swigregister = _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_swigregister
Incremental_neighbor_search_tree_iterator_3_swigregister(Incremental_neighbor_search_tree_iterator_3)

class Incremental_neighbor_search_iterator_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Incremental_neighbor_search_iterator_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Incremental_neighbor_search_iterator_3, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Incremental_neighbor_search_iterator_3()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_iterator_3
    __del__ = lambda self: None
Incremental_neighbor_search_iterator_3_swigregister = _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_swigregister
Incremental_neighbor_search_iterator_3_swigregister(Incremental_neighbor_search_iterator_3)

class K_neighbor_search_tree_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, K_neighbor_search_tree_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, K_neighbor_search_tree_3, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_K_neighbor_search_tree_3(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_3
    __del__ = lambda self: None
K_neighbor_search_tree_3_swigregister = _CGAL_Spatial_searching.K_neighbor_search_tree_3_swigregister
K_neighbor_search_tree_3_swigregister(K_neighbor_search_tree_3)

class K_neighbor_search_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, K_neighbor_search_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, K_neighbor_search_3, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_K_neighbor_search_3(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_3_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_3
    __del__ = lambda self: None
K_neighbor_search_3_swigregister = _CGAL_Spatial_searching.K_neighbor_search_3_swigregister
K_neighbor_search_3_swigregister(K_neighbor_search_3)

class K_neighbor_search_tree_iterator_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, K_neighbor_search_tree_iterator_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, K_neighbor_search_tree_iterator_3, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_K_neighbor_search_tree_iterator_3()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_iterator_3
    __del__ = lambda self: None
K_neighbor_search_tree_iterator_3_swigregister = _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_swigregister
K_neighbor_search_tree_iterator_3_swigregister(K_neighbor_search_tree_iterator_3)

class K_neighbor_search_iterator_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, K_neighbor_search_iterator_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, K_neighbor_search_iterator_3, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_K_neighbor_search_iterator_3()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_iterator_3
    __del__ = lambda self: None
K_neighbor_search_iterator_3_swigregister = _CGAL_Spatial_searching.K_neighbor_search_iterator_3_swigregister
K_neighbor_search_iterator_3_swigregister(K_neighbor_search_iterator_3)

class Orthogonal_k_neighbor_search_tree_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_k_neighbor_search_tree_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_k_neighbor_search_tree_3, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_3(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_3
    __del__ = lambda self: None
Orthogonal_k_neighbor_search_tree_3_swigregister = _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_swigregister
Orthogonal_k_neighbor_search_tree_3_swigregister(Orthogonal_k_neighbor_search_tree_3)

class Orthogonal_k_neighbor_search_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_k_neighbor_search_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_k_neighbor_search_3, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_3(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_3_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_3
    __del__ = lambda self: None
Orthogonal_k_neighbor_search_3_swigregister = _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_3_swigregister
Orthogonal_k_neighbor_search_3_swigregister(Orthogonal_k_neighbor_search_3)

class Orthogonal_k_neighbor_search_tree_iterator_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_k_neighbor_search_tree_iterator_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_k_neighbor_search_tree_iterator_3, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_iterator_3()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_iterator_3
    __del__ = lambda self: None
Orthogonal_k_neighbor_search_tree_iterator_3_swigregister = _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_swigregister
Orthogonal_k_neighbor_search_tree_iterator_3_swigregister(Orthogonal_k_neighbor_search_tree_iterator_3)

class Orthogonal_k_neighbor_search_iterator_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Orthogonal_k_neighbor_search_iterator_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Orthogonal_k_neighbor_search_iterator_3, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_iterator_3()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_iterator_3
    __del__ = lambda self: None
Orthogonal_k_neighbor_search_iterator_3_swigregister = _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_swigregister
Orthogonal_k_neighbor_search_iterator_3_swigregister(Orthogonal_k_neighbor_search_iterator_3)

# This file is compatible with both classic and new-style classes.


