// ------------------------------------------------------------------------------
// Copyright (c) 2011 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------ 


#ifndef SWIG_CGAL_KERNEL_GLOBAL_FUNCTIONS_H
#define SWIG_CGAL_KERNEL_GLOBAL_FUNCTIONS_H

#include <SWIG_CGAL/Kernel/typedefs.h>
#include <CGAL/squared_distance_3.h>
#include <SWIG_CGAL/Kernel/Point_2.h>
#include <SWIG_CGAL/Kernel/Segment_2.h>
#include <SWIG_CGAL/Kernel/Triangle_2.h>
#include <SWIG_CGAL/Kernel/Ray_2.h>
#include <SWIG_CGAL/Kernel/Direction_2.h>
#include <SWIG_CGAL/Kernel/Iso_rectangle_2.h>
#include <SWIG_CGAL/Kernel/Point_3.h>
#include <SWIG_CGAL/Kernel/Plane_3.h>
#include <SWIG_CGAL/Kernel/Line_3.h>
#include <SWIG_CGAL/Kernel/Segment_3.h>
#include <SWIG_CGAL/Kernel/Ray_3.h>
#include <SWIG_CGAL/Kernel/Tetrahedron_3.h>
#include <SWIG_CGAL/Kernel/Iso_cuboid_3.h>
#include <SWIG_CGAL/Kernel/Object.h>


#include <SWIG_CGAL/Common/global_function_macros.h>
#include <SWIG_CGAL/Kernel/global_function_signatures.h>

#undef SWIG_CGAL_FORWARD_CALL_GF_1
#undef SWIG_CGAL_FORWARD_CALL_GF_2
#undef SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2
#undef SWIG_CGAL_FORWARD_CALL_GF_3
#undef SWIG_CGAL_FORWARD_CALL_GF_4
#undef SWIG_CGAL_FORWARD_CALL_GF_5
#undef SWIG_CGAL_FORWARD_CALL_GF_6
#undef SWIG_CGAL_FORWARD_CALL_GF_7

#endif //SWIG_CGAL_KERNEL_GLOBAL_FUNCTIONS_H
