// ------------------------------------------------------------------------------
// Copyright (c) 2014 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------


#ifndef SWIG_CGAL_BOX_INTERSECTION_D_ENUM_H
#define SWIG_CGAL_BOX_INTERSECTION_D_ENUM_H

enum Setting  { COMPLETE, BIPARTITE };
enum Topology { HALF_OPEN, CLOSED };

#endif //SWIG_CGAL_BOX_INTERSECTION_D_ENUM_H
