// ------------------------------------------------------------------------------
// Copyright (c) 2012 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------ 

#ifndef SWIG_CGAL_CONVEX_HULL_2_TYPEDEFS_H
#define SWIG_CGAL_CONVEX_HULL_2_TYPEDEFS_H

#include <SWIG_CGAL/Kernel/typedefs.h>

#include <CGAL/ch_akl_toussaint.h>
#include <CGAL/ch_bykat.h>
#include <CGAL/ch_eddy.h>
#include <CGAL/ch_selected_extreme_points_2.h>
#include <CGAL/ch_graham_andrew.h> 
#include <CGAL/ch_jarvis.h>
#include <CGAL/ch_melkman.h>
#include <CGAL/convexity_check_2.h> 
#include <CGAL/convex_hull_2.h> 

#endif //SWIG_CGAL_CONVEX_HULL_2_TYPEDEFS_H
