// ------------------------------------------------------------------------------
// Copyright (c) 2011 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------ 


#ifndef SWIG_CGAL_PYTHON_EXCEPTIONS_H
#define SWIG_CGAL_PYTHON_EXCEPTIONS_H

struct Bad_element_type{};
struct Stop_iteration{};
struct Not_a_list{};
struct Not_an_iterator{};
  
#endif  // SWIG_CGAL_PYTHON_EXCEPTIONS_H
