// ------------------------------------------------------------------------------
// Copyright (c) 2011 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------ 


#ifndef SWIG_CGAL_TRIANGULATION_2_CONFIG_H
#define SWIG_CGAL_TRIANGULATION_2_CONFIG_H

#ifdef SWIGJAVA
#define ADD_JAVA_DATA_IN_FACET_CDT_2 //define this variable to add a jobject in faces of CDT_plus_2 and CDT_2
#define ADD_JAVA_DATA_IN_SIMPLICES_DT2 //define this variable to add a jobject in faces and vertices of DT2
#endif


#endif //SWIG_CGAL_TRIANGULATION_2_CONFIG_H
