// ------------------------------------------------------------------------------
// Copyright (c) 2011 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------ 


#ifndef SWIG_CGAL_SPATIAL_SEARCHING_ALL_INCLUDES_H
#define SWIG_CGAL_SPATIAL_SEARCHING_ALL_INCLUDES_H
 
#include <SWIG_CGAL/Spatial_searching/typedefs.h>
#include <SWIG_CGAL/Spatial_searching/Kd_tree.h>
#include <SWIG_CGAL/Spatial_searching/NN_search.h>
#include <SWIG_CGAL/Spatial_searching/Fuzzy_objects.h>


#endif //SWIG_CGAL_SPATIAL_SEARCHING_ALL_INCLUDES_H
