// ------------------------------------------------------------------------------
// Copyright (c) 2013 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------

#ifndef SWIG_CGAL_HALFEDGEDS_TYPEDEFS_H
#define SWIG_CGAL_HALFEDGEDS_TYPEDEFS_H


#include <SWIG_CGAL/Kernel/typedefs.h>
#include <CGAL/HalfedgeDS_default.h>

typedef CGAL::HalfedgeDS_default<EPIC_Kernel> HDS_d;

#endif //SWIG_CGAL_HALFEDGEDS_TYPEDEFS_H
