// ------------------------------------------------------------------------------
// Copyright (c) 2011 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------ 


#ifndef SWIG_CGAL_TRIANGULATION_3_OBJECT_H
#define SWIG_CGAL_TRIANGULATION_3_OBJECT_H

#include <SWIG_CGAL/Triangulation_3/decl.h>
#define SWIG_CGAL_XXXXXX_DECL SWIG_CGAL_TRIANGULATION_3_DECL
#include <SWIG_CGAL/Common/Object_impl.h>

#endif //SWIG_CGAL_TRIANGULATION_3_OBJECT_H
