// ------------------------------------------------------------------------------
// Copyright (c) 2011 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------ 


#ifndef SWIG_CGAL_TRIANGULATION_2_ALL_INCLUDES_H
#define SWIG_CGAL_TRIANGULATION_2_ALL_INCLUDES_H

#include <SWIG_CGAL/Triangulation_2/typedefs.h>
#include <SWIG_CGAL/Triangulation_2/Triangulation_2.h>
#include <SWIG_CGAL/Triangulation_2/Delaunay_triangulation_2.h>
#include <SWIG_CGAL/Triangulation_2/Regular_triangulation_2.h>
#include <SWIG_CGAL/Triangulation_2/Constrained_triangulation_2.h>
#include <SWIG_CGAL/Triangulation_2/Constrained_Delaunay_triangulation_2.h>
#include <SWIG_CGAL/Triangulation_2/Constrained_triangulation_plus_2.h>
#include <SWIG_CGAL/Triangulation_2/triangulation_handles.h>

#endif //SWIG_CGAL_TRIANGULATION_2_ALL_INCLUDES_H
