# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.8
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.





from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_CGAL_Voronoi_diagram_2', [dirname(__file__)])
        except ImportError:
            import _CGAL_Voronoi_diagram_2
            return _CGAL_Voronoi_diagram_2
        if fp is not None:
            try:
                _mod = imp.load_module('_CGAL_Voronoi_diagram_2', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _CGAL_Voronoi_diagram_2 = swig_import_helper()
    del swig_import_helper
else:
    import _CGAL_Voronoi_diagram_2
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


import CGAL.CGAL_Kernel
import CGAL.CGAL_Triangulation_2
class Voronoi_diagram_2_Vertex_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Vertex_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Vertex_handle, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Vertex_handle()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_halfedge(self, *args)

    def degree(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_degree(self)

    def point(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_point(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_dual(self, *args)

    def site(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_site(self, *args)

    def is_incident_edge(self, c):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_is_incident_edge(self, c)

    def is_incident_face(self, c):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_is_incident_face(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Vertex_handle
    __del__ = lambda self: None
Voronoi_diagram_2_Vertex_handle_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_swigregister
Voronoi_diagram_2_Vertex_handle_swigregister(Voronoi_diagram_2_Vertex_handle)

class Voronoi_diagram_2_Face_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Face_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Face_handle, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Face_handle()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_halfedge(self, *args)

    def outer_ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_outer_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_dual(self, *args)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_is_unbounded(self)

    def is_halfedge_on_ccb(self, c):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_is_halfedge_on_ccb(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Face_handle
    __del__ = lambda self: None
Voronoi_diagram_2_Face_handle_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_swigregister
Voronoi_diagram_2_Face_handle_swigregister(Voronoi_diagram_2_Face_handle)

class Voronoi_diagram_2_Halfedge_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Halfedge_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Halfedge_handle, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Halfedge_handle()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def twin(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_twin(self, *args)

    def opposite(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_opposite(self, *args)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_next(self, *args)

    def previous(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_previous(self, *args)

    def face(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_face(self, *args)

    def source(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_source(self, *args)

    def target(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_target(self, *args)

    def ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_dual(self, *args)

    def up(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_up(self, *args)

    def down(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_down(self, *args)

    def left(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_left(self, *args)

    def right(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_right(self, *args)

    def has_source(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_has_source(self)

    def has_target(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_has_target(self)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_unbounded(self)

    def is_bisector(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_bisector(self)

    def is_segment(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_segment(self)

    def is_ray(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_ray(self)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Halfedge_handle
    __del__ = lambda self: None
Voronoi_diagram_2_Halfedge_handle_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_swigregister
Voronoi_diagram_2_Halfedge_handle_swigregister(Voronoi_diagram_2_Halfedge_handle)

class Voronoi_diagram_2_Face_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Face_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Face_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Face_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Face_iterator
    __del__ = lambda self: None
Voronoi_diagram_2_Face_iterator_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_swigregister
Voronoi_diagram_2_Face_iterator_swigregister(Voronoi_diagram_2_Face_iterator)

class Voronoi_diagram_2_Bounded_faces_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Bounded_faces_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Bounded_faces_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Bounded_faces_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Bounded_faces_iterator
    __del__ = lambda self: None
Voronoi_diagram_2_Bounded_faces_iterator_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_swigregister
Voronoi_diagram_2_Bounded_faces_iterator_swigregister(Voronoi_diagram_2_Bounded_faces_iterator)

class Voronoi_diagram_2_Unbounded_faces_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Unbounded_faces_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Unbounded_faces_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Unbounded_faces_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Unbounded_faces_iterator
    __del__ = lambda self: None
Voronoi_diagram_2_Unbounded_faces_iterator_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_swigregister
Voronoi_diagram_2_Unbounded_faces_iterator_swigregister(Voronoi_diagram_2_Unbounded_faces_iterator)

class Voronoi_diagram_2_Edge_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Edge_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Edge_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Edge_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Edge_iterator
    __del__ = lambda self: None
Voronoi_diagram_2_Edge_iterator_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_swigregister
Voronoi_diagram_2_Edge_iterator_swigregister(Voronoi_diagram_2_Edge_iterator)

class Voronoi_diagram_2_Halfedge_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Halfedge_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Halfedge_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Halfedge_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Halfedge_iterator
    __del__ = lambda self: None
Voronoi_diagram_2_Halfedge_iterator_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_swigregister
Voronoi_diagram_2_Halfedge_iterator_swigregister(Voronoi_diagram_2_Halfedge_iterator)

class Voronoi_diagram_2_Unbounded_halfedges_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Unbounded_halfedges_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Unbounded_halfedges_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Unbounded_halfedges_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Unbounded_halfedges_iterator
    __del__ = lambda self: None
Voronoi_diagram_2_Unbounded_halfedges_iterator_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_swigregister
Voronoi_diagram_2_Unbounded_halfedges_iterator_swigregister(Voronoi_diagram_2_Unbounded_halfedges_iterator)

class Voronoi_diagram_2_Bounded_halfedges_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Bounded_halfedges_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Bounded_halfedges_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Bounded_halfedges_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Bounded_halfedges_iterator
    __del__ = lambda self: None
Voronoi_diagram_2_Bounded_halfedges_iterator_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_swigregister
Voronoi_diagram_2_Bounded_halfedges_iterator_swigregister(Voronoi_diagram_2_Bounded_halfedges_iterator)

class Voronoi_diagram_2_Ccb_halfedge_circulator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Ccb_halfedge_circulator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Ccb_halfedge_circulator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Ccb_halfedge_circulator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Ccb_halfedge_circulator
    __del__ = lambda self: None
Voronoi_diagram_2_Ccb_halfedge_circulator_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_swigregister
Voronoi_diagram_2_Ccb_halfedge_circulator_swigregister(Voronoi_diagram_2_Ccb_halfedge_circulator)

class Voronoi_diagram_2_Halfedge_around_vertex_circulator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Halfedge_around_vertex_circulator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Halfedge_around_vertex_circulator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Halfedge_around_vertex_circulator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Halfedge_around_vertex_circulator
    __del__ = lambda self: None
Voronoi_diagram_2_Halfedge_around_vertex_circulator_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_swigregister
Voronoi_diagram_2_Halfedge_around_vertex_circulator_swigregister(Voronoi_diagram_2_Halfedge_around_vertex_circulator)

class Voronoi_diagram_2_Vertex_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Vertex_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Vertex_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Vertex_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Vertex_iterator
    __del__ = lambda self: None
Voronoi_diagram_2_Vertex_iterator_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_swigregister
Voronoi_diagram_2_Vertex_iterator_swigregister(Voronoi_diagram_2_Vertex_iterator)

class Voronoi_diagram_2_Site_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Site_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Site_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Site_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Site_iterator
    __del__ = lambda self: None
Voronoi_diagram_2_Site_iterator_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_swigregister
Voronoi_diagram_2_Site_iterator_swigregister(Voronoi_diagram_2_Site_iterator)

class Voronoi_diagram_2_Locate_result(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2_Locate_result, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2_Locate_result, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Locate_result()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def get_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_get_vertex_handle(self)

    def get_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_get_halfedge_handle(self)

    def get_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_get_face_handle(self)

    def is_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_is_vertex_handle(self)

    def is_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_is_halfedge_handle(self)

    def is_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_is_face_handle(self)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Locate_result
    __del__ = lambda self: None
Voronoi_diagram_2_Locate_result_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_swigregister
Voronoi_diagram_2_Locate_result_swigregister(Voronoi_diagram_2_Locate_result)

class Voronoi_diagram_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Voronoi_diagram_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Voronoi_diagram_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_insert(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_dual(self, *args)

    def number_of_vertices(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_vertices(self)

    def number_of_faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_faces(self)

    def number_of_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_halfedges(self)

    def number_of_connected_components(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_connected_components(self)

    def unbounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_face(self, *args)

    def bounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_face(self, *args)

    def unbounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_halfedge(self, *args)

    def bounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_halfedge(self, *args)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_is_valid(self)

    def clear(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_clear(self)

    def swap(self, other):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_swap(self, other)

    def file_output(self, fname):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_file_output(self, fname)

    def file_input(self, fname):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_file_input(self, fname)

    def faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_faces(self)

    def unbounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_faces(self)

    def bounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_faces(self)

    def edges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_edges(self)

    def halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_halfedges(self)

    def unbounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_halfedges(self)

    def bounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_halfedges(self)

    def vertices(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_vertices(self)

    def sites(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_sites(self)

    def ccb_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_ccb_halfedges(self, *args)

    def incident_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_incident_halfedges(self, *args)

    def locate(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_locate(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2
    __del__ = lambda self: None
Voronoi_diagram_2_swigregister = _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_swigregister
Voronoi_diagram_2_swigregister(Voronoi_diagram_2)

class Power_diagram_2_Vertex_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Vertex_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Vertex_handle, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Vertex_handle()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_halfedge(self, *args)

    def degree(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_degree(self)

    def point(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_point(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_dual(self, *args)

    def site(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_site(self, *args)

    def is_incident_edge(self, c):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_is_incident_edge(self, c)

    def is_incident_face(self, c):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_is_incident_face(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Vertex_handle
    __del__ = lambda self: None
Power_diagram_2_Vertex_handle_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_swigregister
Power_diagram_2_Vertex_handle_swigregister(Power_diagram_2_Vertex_handle)

class Power_diagram_2_Face_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Face_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Face_handle, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Face_handle()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_halfedge(self, *args)

    def outer_ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_outer_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_dual(self, *args)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_is_unbounded(self)

    def is_halfedge_on_ccb(self, c):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_is_halfedge_on_ccb(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Face_handle
    __del__ = lambda self: None
Power_diagram_2_Face_handle_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_swigregister
Power_diagram_2_Face_handle_swigregister(Power_diagram_2_Face_handle)

class Power_diagram_2_Halfedge_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Halfedge_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Halfedge_handle, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Halfedge_handle()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def twin(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_twin(self, *args)

    def opposite(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_opposite(self, *args)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_next(self, *args)

    def previous(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_previous(self, *args)

    def face(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_face(self, *args)

    def source(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_source(self, *args)

    def target(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_target(self, *args)

    def ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_dual(self, *args)

    def up(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_up(self, *args)

    def down(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_down(self, *args)

    def left(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_left(self, *args)

    def right(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_right(self, *args)

    def has_source(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_has_source(self)

    def has_target(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_has_target(self)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_unbounded(self)

    def is_bisector(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_bisector(self)

    def is_segment(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_segment(self)

    def is_ray(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_ray(self)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Halfedge_handle
    __del__ = lambda self: None
Power_diagram_2_Halfedge_handle_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_swigregister
Power_diagram_2_Halfedge_handle_swigregister(Power_diagram_2_Halfedge_handle)

class Power_diagram_2_Face_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Face_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Face_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Face_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Face_iterator
    __del__ = lambda self: None
Power_diagram_2_Face_iterator_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_swigregister
Power_diagram_2_Face_iterator_swigregister(Power_diagram_2_Face_iterator)

class Power_diagram_2_Bounded_faces_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Bounded_faces_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Bounded_faces_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Bounded_faces_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Bounded_faces_iterator
    __del__ = lambda self: None
Power_diagram_2_Bounded_faces_iterator_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_swigregister
Power_diagram_2_Bounded_faces_iterator_swigregister(Power_diagram_2_Bounded_faces_iterator)

class Power_diagram_2_Unbounded_faces_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Unbounded_faces_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Unbounded_faces_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Unbounded_faces_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Unbounded_faces_iterator
    __del__ = lambda self: None
Power_diagram_2_Unbounded_faces_iterator_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_swigregister
Power_diagram_2_Unbounded_faces_iterator_swigregister(Power_diagram_2_Unbounded_faces_iterator)

class Power_diagram_2_Edge_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Edge_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Edge_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Edge_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Edge_iterator
    __del__ = lambda self: None
Power_diagram_2_Edge_iterator_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_swigregister
Power_diagram_2_Edge_iterator_swigregister(Power_diagram_2_Edge_iterator)

class Power_diagram_2_Halfedge_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Halfedge_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Halfedge_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Halfedge_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Halfedge_iterator
    __del__ = lambda self: None
Power_diagram_2_Halfedge_iterator_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_swigregister
Power_diagram_2_Halfedge_iterator_swigregister(Power_diagram_2_Halfedge_iterator)

class Power_diagram_2_Unbounded_halfedges_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Unbounded_halfedges_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Unbounded_halfedges_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Unbounded_halfedges_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Unbounded_halfedges_iterator
    __del__ = lambda self: None
Power_diagram_2_Unbounded_halfedges_iterator_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_swigregister
Power_diagram_2_Unbounded_halfedges_iterator_swigregister(Power_diagram_2_Unbounded_halfedges_iterator)

class Power_diagram_2_Bounded_halfedges_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Bounded_halfedges_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Bounded_halfedges_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Bounded_halfedges_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Bounded_halfedges_iterator
    __del__ = lambda self: None
Power_diagram_2_Bounded_halfedges_iterator_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_swigregister
Power_diagram_2_Bounded_halfedges_iterator_swigregister(Power_diagram_2_Bounded_halfedges_iterator)

class Power_diagram_2_Ccb_halfedge_circulator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Ccb_halfedge_circulator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Ccb_halfedge_circulator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Ccb_halfedge_circulator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Ccb_halfedge_circulator
    __del__ = lambda self: None
Power_diagram_2_Ccb_halfedge_circulator_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_swigregister
Power_diagram_2_Ccb_halfedge_circulator_swigregister(Power_diagram_2_Ccb_halfedge_circulator)

class Power_diagram_2_Halfedge_around_vertex_circulator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Halfedge_around_vertex_circulator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Halfedge_around_vertex_circulator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Halfedge_around_vertex_circulator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Halfedge_around_vertex_circulator
    __del__ = lambda self: None
Power_diagram_2_Halfedge_around_vertex_circulator_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_swigregister
Power_diagram_2_Halfedge_around_vertex_circulator_swigregister(Power_diagram_2_Halfedge_around_vertex_circulator)

class Power_diagram_2_Vertex_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Vertex_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Vertex_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Vertex_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Vertex_iterator
    __del__ = lambda self: None
Power_diagram_2_Vertex_iterator_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_swigregister
Power_diagram_2_Vertex_iterator_swigregister(Power_diagram_2_Vertex_iterator)

class Power_diagram_2_Site_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Site_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Site_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Site_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Site_iterator
    __del__ = lambda self: None
Power_diagram_2_Site_iterator_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_swigregister
Power_diagram_2_Site_iterator_swigregister(Power_diagram_2_Site_iterator)

class Power_diagram_2_Locate_result(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2_Locate_result, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2_Locate_result, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Locate_result()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def get_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_get_vertex_handle(self)

    def get_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_get_halfedge_handle(self)

    def get_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_get_face_handle(self)

    def is_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_is_vertex_handle(self)

    def is_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_is_halfedge_handle(self)

    def is_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_is_face_handle(self)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Locate_result
    __del__ = lambda self: None
Power_diagram_2_Locate_result_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_swigregister
Power_diagram_2_Locate_result_swigregister(Power_diagram_2_Locate_result)

class Power_diagram_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Power_diagram_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Power_diagram_2, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Voronoi_diagram_2.new_Power_diagram_2(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_insert(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_dual(self, *args)

    def number_of_vertices(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_vertices(self)

    def number_of_faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_faces(self)

    def number_of_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_halfedges(self)

    def number_of_connected_components(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_connected_components(self)

    def unbounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_face(self, *args)

    def bounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_face(self, *args)

    def unbounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_halfedge(self, *args)

    def bounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_halfedge(self, *args)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_is_valid(self)

    def clear(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_clear(self)

    def swap(self, other):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_swap(self, other)

    def file_output(self, fname):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_file_output(self, fname)

    def file_input(self, fname):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_file_input(self, fname)

    def faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_faces(self)

    def unbounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_faces(self)

    def bounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_faces(self)

    def edges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_edges(self)

    def halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_halfedges(self)

    def unbounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_halfedges(self)

    def bounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_halfedges(self)

    def vertices(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_vertices(self)

    def sites(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_sites(self)

    def ccb_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_ccb_halfedges(self, *args)

    def incident_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_incident_halfedges(self, *args)

    def locate(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_locate(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2
    __del__ = lambda self: None
Power_diagram_2_swigregister = _CGAL_Voronoi_diagram_2.Power_diagram_2_swigregister
Power_diagram_2_swigregister(Power_diagram_2)


def crop_voronoi_facet(arg1, arg2, arg3, arg4):
    return _CGAL_Voronoi_diagram_2.crop_voronoi_facet(arg1, arg2, arg3, arg4)
crop_voronoi_facet = _CGAL_Voronoi_diagram_2.crop_voronoi_facet
class Optional_segment_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Optional_segment_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Optional_segment_2, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Voronoi_diagram_2.new_Optional_segment_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def empty(self):
        return _CGAL_Voronoi_diagram_2.Optional_segment_2_empty(self)

    def value(self):
        return _CGAL_Voronoi_diagram_2.Optional_segment_2_value(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Optional_segment_2_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Optional_segment_2
    __del__ = lambda self: None
Optional_segment_2_swigregister = _CGAL_Voronoi_diagram_2.Optional_segment_2_swigregister
Optional_segment_2_swigregister(Optional_segment_2)


def crop_voronoi_facet_polygon(arg1, arg2, arg3, arg4):
    return _CGAL_Voronoi_diagram_2.crop_voronoi_facet_polygon(arg1, arg2, arg3, arg4)
crop_voronoi_facet_polygon = _CGAL_Voronoi_diagram_2.crop_voronoi_facet_polygon

def crop_voronoi_edge(arg1, arg2, arg3):
    return _CGAL_Voronoi_diagram_2.crop_voronoi_edge(arg1, arg2, arg3)
crop_voronoi_edge = _CGAL_Voronoi_diagram_2.crop_voronoi_edge
# This file is compatible with both classic and new-style classes.


