// ------------------------------------------------------------------------------
// Copyright (c) 2011 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------ 

#ifndef SWIG_CGAL_SURFACE_MESHER_ALL_INCLUDES_H
#define SWIG_CGAL_SURFACE_MESHER_ALL_INCLUDES_H

#include  <SWIG_CGAL/Surface_mesher/typedefs.h>
#include  <SWIG_CGAL/Surface_mesher/Surface_mesh_details.h>
#include  <SWIG_CGAL/Surface_mesher/C2T3.h>

#endif//SWIG_CGAL_SURFACE_MESHER_ALL_INCLUDES_H
