// ------------------------------------------------------------------------------
// Copyright (c) 2011 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------ 

//squared_distance
//dimension 3
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Point_3,Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Point_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Point_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Point_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Point_3,Ray_3)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Plane_3,Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Plane_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Plane_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Plane_3,Ray_3)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Segment_3,Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Segment_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Segment_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Segment_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Segment_3,Ray_3)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Line_3,Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Line_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Line_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Line_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Line_3,Ray_3)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Ray_3,Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Ray_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Ray_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Ray_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Ray_3,Ray_3)

//dimension 2
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Point_2,Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Point_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Point_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Point_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Point_2,Ray_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Segment_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Segment_2,Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Segment_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Segment_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Segment_2,Ray_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Triangle_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Triangle_2,Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Triangle_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Triangle_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Triangle_2,Ray_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Line_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Line_2,Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Line_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Line_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Line_2,Ray_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Ray_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Ray_2,Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Ray_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Ray_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,squared_distance,Ray_2,Ray_2)

//do_insertect
//dimension 3
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_3,Point_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_3,Plane_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_3,Line_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_3,Ray_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_3,Triangle_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_3,Iso_cuboid_3)

//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Plane_3,Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Plane_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Plane_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Plane_3,Ray_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Plane_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Plane_3,Triangle_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Plane_3,Iso_cuboid_3)

//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_3,Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_3,Ray_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_3,Triangle_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_3,Iso_cuboid_3)

//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_3,Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_3,Ray_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_3,Triangle_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_3,Iso_cuboid_3)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_3,Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_3,Ray_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_3,Triangle_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_3,Iso_cuboid_3)

//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_3,Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_3,Ray_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_3,Triangle_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_3,Iso_cuboid_3)

//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_cuboid_3,Point_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_cuboid_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_cuboid_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_cuboid_3,Ray_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_cuboid_3,Segment_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_cuboid_3,Triangle_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_cuboid_3,Iso_cuboid_3)

//dimension 2
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_2,Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_2,Ray_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Point_2,Iso_rectangle_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_2,Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_2,Ray_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Segment_2,Iso_rectangle_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_2,Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_2,Ray_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_2,Triangle_2)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Triangle_2,Iso_rectangle_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_2,Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_2,Ray_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Line_2,Iso_rectangle_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_2,Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_2,Ray_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Ray_2,Iso_rectangle_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_rectangle_2,Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_rectangle_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_rectangle_2,Ray_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_rectangle_2,Segment_2)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_rectangle_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(bool,do_intersect,Iso_rectangle_2,Iso_rectangle_2)

//intersection
//dimension 3
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Plane_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Plane_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Plane_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Plane_3,Triangle_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Plane_3,Ray_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Plane_3,Iso_cuboid_3)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Segment_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Segment_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Segment_3,Triangle_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Segment_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Segment_3,Ray_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Segment_3,Iso_cuboid_3)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Line_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Line_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Line_3,Triangle_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Line_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Line_3,Ray_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Line_3,Iso_cuboid_3)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Triangle_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Triangle_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Triangle_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Triangle_3,Triangle_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Triangle_3,Ray_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Triangle_3,Iso_cuboid_3)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Ray_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Ray_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Ray_3,Line_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Ray_3,Triangle_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Ray_3,Ray_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Ray_3,Iso_cuboid_3)

//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Iso_cuboid_3,Plane_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Iso_cuboid_3,Segment_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Iso_cuboid_3,Line_3)
//MISSING IMPL IN CGAL SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Iso_cuboid_3,Triangle_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Iso_cuboid_3,Ray_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Iso_cuboid_3,Iso_cuboid_3)

//dimension 2
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Segment_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Segment_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Segment_2,Ray_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Segment_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Segment_2,Iso_rectangle_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Triangle_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Triangle_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Triangle_2,Ray_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Triangle_2,Line_2)
//SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Triangle_2,Iso_rectangle_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Line_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Line_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Line_2,Ray_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Line_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Line_2,Iso_rectangle_2)

SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Ray_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Ray_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Ray_2,Ray_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Ray_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Ray_2,Iso_rectangle_2)

//SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Iso_rectangle_2,Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Iso_rectangle_2,Segment_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Iso_rectangle_2,Ray_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Iso_rectangle_2,Line_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_AND_FILTER_CALL_GF_2(Object,intersection,Iso_rectangle_2,Iso_rectangle_2)

//area
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_3(double,area,Point_2,Point_2,Point_2)


//centroid
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_3(Point_2, centroid, Point_2, Point_2, Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_4(Point_2, centroid, Point_2, Point_2, Point_2, Point_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_1(Point_2, centroid, Triangle_2)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_3(Point_3, centroid, Point_3, Point_3, Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_4(Point_3, centroid, Point_3, Point_3, Point_3, Point_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_1(Point_3, centroid, Triangle_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_1(Point_3, centroid, Tetrahedron_3)

//other constructions
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(Vector_3,cross_product,Vector_3,Vector_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_3(double,determinant,Vector_3,Vector_3,Vector_3)
SWIG_CGAL_KERNEL_DECL SWIG_CGAL_FORWARD_CALL_GF_2(double,determinant,Vector_2,Vector_2)


//All kernel global functions
// angle
// are_ordered_along_line
// are_strictly_ordered_along_line
// barycenter
// bisector
// circumcenter
// collinear
// collinear_are_ordered_along_line
// collinear_are_strictly_ordered_along_line
// compare_distance_to_point
// compare_lexicographically
// compare_signed_distance_to_line
// compare_signed_distance_to_plane
// compare_slopes
// compare_dihedral_angle
// compare_squared_distance
// compare_squared_radius
// compare_x
// compare_xy
// compare_xyz
// compare_x_at_y
// compare_y
// compare_y_at_x
// compare_yx
// compare_z
// coplanar
// coplanar_orientation
// coplanar_side_of_bounded_circle
// do_intersect
// do_overlap
// equidistant_line
// has_larger_distance_to_point
// has_larger_signed_distance_to_line
// has_larger_signed_distance_to_plane
// has_smaller_distance_to_point
// has_smaller_signed_distance_to_line
// has_smaller_signed_distance_to_plane
// left_turn
// lexicographically_xyz_smaller
// lexicographically_xyz_smaller_or_equal
// lexicographically_xy_larger
// lexicographically_xy_larger_or_equal
// lexicographically_xy_smaller
// lexicographically_xy_smaller_or_equal
// max_vertex
// midpoint
// normal
// min_vertex
// operator+
// operator-
// operator*
// opposite
// orthogonal_vector
// orientation
// parallel
// quotient_cartesian_to_homogeneous
// radical_plane
// radical_line
// rational_rotation_approximation
// right_turn
// side_of_bounded_circle
// side_of_bounded_sphere
// side_of_oriented_circle
// side_of_oriented_sphere
// squared_area
// squared_radius
// unit_normal
// volume
// x_equal
// y_equal
// z_equal

