// ------------------------------------------------------------------------------
// Copyright (c) 2015 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------

#ifndef SWIG_CGAL_POLYGON_MESH_PROCESSING_ALL_INCLUDES_H
#define SWIG_CGAL_POLYGON_MESH_PROCESSING_ALL_INCLUDES_H

#include <SWIG_CGAL/Polygon_mesh_processing/Side_of_triangle_mesh.h>
#include <SWIG_CGAL/Polygon_mesh_processing/Polygon_mesh_slicer.h>
#include <SWIG_CGAL/Polygon_mesh_processing/utils.h>

#endif //SWIG_CGAL_POLYGON_MESH_PROCESSING_ALL_INCLUDES_H
