// ------------------------------------------------------------------------------
// Copyright (c) 2014 GeometryFactory (FRANCE)
// Distributed under the Boost Software License, Version 1.0. (See accompany-
// ing file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
// ------------------------------------------------------------------------------ 


#ifndef SWIG_CGAL_KERNEL_BBOX_3_H
#define SWIG_CGAL_KERNEL_BBOX_3_H

#include <SWIG_CGAL/Kernel/Bbox_3_decl.h>
#include <SWIG_CGAL/Kernel/Bbox_3_impl.h>

#endif //SWIG_CGAL_KERNEL_BBOX_3_H
