/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 3.0.8
 *
 * This file is not intended to be easily readable and contains a number of
 * coding conventions designed to improve portability and efficiency. Do not make
 * changes to this file unless you know what you are doing--modify the SWIG
 * interface file instead.
 * ----------------------------------------------------------------------------- */


#ifndef SWIGPYTHON
#define SWIGPYTHON
#endif

#define SWIG_PYTHON_DIRECTOR_NO_VTABLE


#ifdef __cplusplus
/* SwigValueWrapper is described in swig.swg */
template<typename T> class SwigValueWrapper {
  struct SwigMovePointer {
    T *ptr;
    SwigMovePointer(T *p) : ptr(p) { }
    ~SwigMovePointer() { delete ptr; }
    SwigMovePointer& operator=(SwigMovePointer& rhs) { T* oldptr = ptr; ptr = 0; delete oldptr; ptr = rhs.ptr; rhs.ptr = 0; return *this; }
  } pointer;
  SwigValueWrapper& operator=(const SwigValueWrapper<T>& rhs);
  SwigValueWrapper(const SwigValueWrapper<T>& rhs);
public:
  SwigValueWrapper() : pointer(0) { }
  SwigValueWrapper& operator=(const T& t) { SwigMovePointer tmp(new T(t)); pointer = tmp; return *this; }
  operator T&() const { return *pointer.ptr; }
  T *operator&() { return pointer.ptr; }
};

template <typename T> T SwigValueInit() {
  return T();
}
#endif

/* -----------------------------------------------------------------------------
 *  This section contains generic SWIG labels for method/variable
 *  declarations/attributes, and other compiler dependent labels.
 * ----------------------------------------------------------------------------- */

/* template workaround for compilers that cannot correctly implement the C++ standard */
#ifndef SWIGTEMPLATEDISAMBIGUATOR
# if defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x560)
#  define SWIGTEMPLATEDISAMBIGUATOR template
# elif defined(__HP_aCC)
/* Needed even with `aCC -AA' when `aCC -V' reports HP ANSI C++ B3910B A.03.55 */
/* If we find a maximum version that requires this, the test would be __HP_aCC <= 35500 for A.03.55 */
#  define SWIGTEMPLATEDISAMBIGUATOR template
# else
#  define SWIGTEMPLATEDISAMBIGUATOR
# endif
#endif

/* inline attribute */
#ifndef SWIGINLINE
# if defined(__cplusplus) || (defined(__GNUC__) && !defined(__STRICT_ANSI__))
#   define SWIGINLINE inline
# else
#   define SWIGINLINE
# endif
#endif

/* attribute recognised by some compilers to avoid 'unused' warnings */
#ifndef SWIGUNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define SWIGUNUSED __attribute__ ((__unused__))
#   else
#     define SWIGUNUSED
#   endif
# elif defined(__ICC)
#   define SWIGUNUSED __attribute__ ((__unused__))
# else
#   define SWIGUNUSED
# endif
#endif

#ifndef SWIG_MSC_UNSUPPRESS_4505
# if defined(_MSC_VER)
#   pragma warning(disable : 4505) /* unreferenced local function has been removed */
# endif
#endif

#ifndef SWIGUNUSEDPARM
# ifdef __cplusplus
#   define SWIGUNUSEDPARM(p)
# else
#   define SWIGUNUSEDPARM(p) p SWIGUNUSED
# endif
#endif

/* internal SWIG method */
#ifndef SWIGINTERN
# define SWIGINTERN static SWIGUNUSED
#endif

/* internal inline SWIG method */
#ifndef SWIGINTERNINLINE
# define SWIGINTERNINLINE SWIGINTERN SWIGINLINE
#endif

/* exporting methods */
#if (__GNUC__ >= 4) || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4)
#  ifndef GCC_HASCLASSVISIBILITY
#    define GCC_HASCLASSVISIBILITY
#  endif
#endif

#ifndef SWIGEXPORT
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   if defined(STATIC_LINKED)
#     define SWIGEXPORT
#   else
#     define SWIGEXPORT __declspec(dllexport)
#   endif
# else
#   if defined(__GNUC__) && defined(GCC_HASCLASSVISIBILITY)
#     define SWIGEXPORT __attribute__ ((visibility("default")))
#   else
#     define SWIGEXPORT
#   endif
# endif
#endif

/* calling conventions for Windows */
#ifndef SWIGSTDCALL
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   define SWIGSTDCALL __stdcall
# else
#   define SWIGSTDCALL
# endif
#endif

/* Deal with Microsoft's attempt at deprecating C standard runtime functions */
#if !defined(SWIG_NO_CRT_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_CRT_SECURE_NO_DEPRECATE)
# define _CRT_SECURE_NO_DEPRECATE
#endif

/* Deal with Microsoft's attempt at deprecating methods in the standard C++ library */
#if !defined(SWIG_NO_SCL_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_SCL_SECURE_NO_DEPRECATE)
# define _SCL_SECURE_NO_DEPRECATE
#endif

/* Deal with Apple's deprecated 'AssertMacros.h' from Carbon-framework */
#if defined(__APPLE__) && !defined(__ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES)
# define __ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES 0
#endif

/* Intel's compiler complains if a variable which was never initialised is
 * cast to void, which is a common idiom which we use to indicate that we
 * are aware a variable isn't used.  So we just silence that warning.
 * See: https://github.com/swig/swig/issues/192 for more discussion.
 */
#ifdef __INTEL_COMPILER
# pragma warning disable 592
#endif


#if defined(_DEBUG) && defined(SWIG_PYTHON_INTERPRETER_NO_DEBUG)
/* Use debug wrappers with the Python release dll */
# undef _DEBUG
# include <Python.h>
# define _DEBUG
#else
# include <Python.h>
#endif

/* -----------------------------------------------------------------------------
 * swigrun.swg
 *
 * This file contains generic C API SWIG runtime support for pointer
 * type checking.
 * ----------------------------------------------------------------------------- */

/* This should only be incremented when either the layout of swig_type_info changes,
   or for whatever reason, the runtime changes incompatibly */
#define SWIG_RUNTIME_VERSION "4"

/* define SWIG_TYPE_TABLE_NAME as "SWIG_TYPE_TABLE" */
#ifdef SWIG_TYPE_TABLE
# define SWIG_QUOTE_STRING(x) #x
# define SWIG_EXPAND_AND_QUOTE_STRING(x) SWIG_QUOTE_STRING(x)
# define SWIG_TYPE_TABLE_NAME SWIG_EXPAND_AND_QUOTE_STRING(SWIG_TYPE_TABLE)
#else
# define SWIG_TYPE_TABLE_NAME
#endif

/*
  You can use the SWIGRUNTIME and SWIGRUNTIMEINLINE macros for
  creating a static or dynamic library from the SWIG runtime code.
  In 99.9% of the cases, SWIG just needs to declare them as 'static'.

  But only do this if strictly necessary, ie, if you have problems
  with your compiler or suchlike.
*/

#ifndef SWIGRUNTIME
# define SWIGRUNTIME SWIGINTERN
#endif

#ifndef SWIGRUNTIMEINLINE
# define SWIGRUNTIMEINLINE SWIGRUNTIME SWIGINLINE
#endif

/*  Generic buffer size */
#ifndef SWIG_BUFFER_SIZE
# define SWIG_BUFFER_SIZE 1024
#endif

/* Flags for pointer conversions */
#define SWIG_POINTER_DISOWN        0x1
#define SWIG_CAST_NEW_MEMORY       0x2

/* Flags for new pointer objects */
#define SWIG_POINTER_OWN           0x1


/*
   Flags/methods for returning states.

   The SWIG conversion methods, as ConvertPtr, return an integer
   that tells if the conversion was successful or not. And if not,
   an error code can be returned (see swigerrors.swg for the codes).

   Use the following macros/flags to set or process the returning
   states.

   In old versions of SWIG, code such as the following was usually written:

     if (SWIG_ConvertPtr(obj,vptr,ty.flags) != -1) {
       // success code
     } else {
       //fail code
     }

   Now you can be more explicit:

    int res = SWIG_ConvertPtr(obj,vptr,ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
    } else {
      // fail code
    }

   which is the same really, but now you can also do

    Type *ptr;
    int res = SWIG_ConvertPtr(obj,(void **)(&ptr),ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
      if (SWIG_IsNewObj(res) {
        ...
	delete *ptr;
      } else {
        ...
      }
    } else {
      // fail code
    }

   I.e., now SWIG_ConvertPtr can return new objects and you can
   identify the case and take care of the deallocation. Of course that
   also requires SWIG_ConvertPtr to return new result values, such as

      int SWIG_ConvertPtr(obj, ptr,...) {
        if (<obj is ok>) {
          if (<need new object>) {
            *ptr = <ptr to new allocated object>;
            return SWIG_NEWOBJ;
          } else {
            *ptr = <ptr to old object>;
            return SWIG_OLDOBJ;
          }
        } else {
          return SWIG_BADOBJ;
        }
      }

   Of course, returning the plain '0(success)/-1(fail)' still works, but you can be
   more explicit by returning SWIG_BADOBJ, SWIG_ERROR or any of the
   SWIG errors code.

   Finally, if the SWIG_CASTRANK_MODE is enabled, the result code
   allows to return the 'cast rank', for example, if you have this

       int food(double)
       int fooi(int);

   and you call

      food(1)   // cast rank '1'  (1 -> 1.0)
      fooi(1)   // cast rank '0'

   just use the SWIG_AddCast()/SWIG_CheckState()
*/

#define SWIG_OK                    (0)
#define SWIG_ERROR                 (-1)
#define SWIG_IsOK(r)               (r >= 0)
#define SWIG_ArgError(r)           ((r != SWIG_ERROR) ? r : SWIG_TypeError)

/* The CastRankLimit says how many bits are used for the cast rank */
#define SWIG_CASTRANKLIMIT         (1 << 8)
/* The NewMask denotes the object was created (using new/malloc) */
#define SWIG_NEWOBJMASK            (SWIG_CASTRANKLIMIT  << 1)
/* The TmpMask is for in/out typemaps that use temporal objects */
#define SWIG_TMPOBJMASK            (SWIG_NEWOBJMASK << 1)
/* Simple returning values */
#define SWIG_BADOBJ                (SWIG_ERROR)
#define SWIG_OLDOBJ                (SWIG_OK)
#define SWIG_NEWOBJ                (SWIG_OK | SWIG_NEWOBJMASK)
#define SWIG_TMPOBJ                (SWIG_OK | SWIG_TMPOBJMASK)
/* Check, add and del mask methods */
#define SWIG_AddNewMask(r)         (SWIG_IsOK(r) ? (r | SWIG_NEWOBJMASK) : r)
#define SWIG_DelNewMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_NEWOBJMASK) : r)
#define SWIG_IsNewObj(r)           (SWIG_IsOK(r) && (r & SWIG_NEWOBJMASK))
#define SWIG_AddTmpMask(r)         (SWIG_IsOK(r) ? (r | SWIG_TMPOBJMASK) : r)
#define SWIG_DelTmpMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_TMPOBJMASK) : r)
#define SWIG_IsTmpObj(r)           (SWIG_IsOK(r) && (r & SWIG_TMPOBJMASK))

/* Cast-Rank Mode */
#if defined(SWIG_CASTRANK_MODE)
#  ifndef SWIG_TypeRank
#    define SWIG_TypeRank             unsigned long
#  endif
#  ifndef SWIG_MAXCASTRANK            /* Default cast allowed */
#    define SWIG_MAXCASTRANK          (2)
#  endif
#  define SWIG_CASTRANKMASK          ((SWIG_CASTRANKLIMIT) -1)
#  define SWIG_CastRank(r)           (r & SWIG_CASTRANKMASK)
SWIGINTERNINLINE int SWIG_AddCast(int r) {
  return SWIG_IsOK(r) ? ((SWIG_CastRank(r) < SWIG_MAXCASTRANK) ? (r + 1) : SWIG_ERROR) : r;
}
SWIGINTERNINLINE int SWIG_CheckState(int r) {
  return SWIG_IsOK(r) ? SWIG_CastRank(r) + 1 : 0;
}
#else /* no cast-rank mode */
#  define SWIG_AddCast(r) (r)
#  define SWIG_CheckState(r) (SWIG_IsOK(r) ? 1 : 0)
#endif


#include <string.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef void *(*swig_converter_func)(void *, int *);
typedef struct swig_type_info *(*swig_dycast_func)(void **);

/* Structure to store information on one type */
typedef struct swig_type_info {
  const char             *name;			/* mangled name of this type */
  const char             *str;			/* human readable name of this type */
  swig_dycast_func        dcast;		/* dynamic cast function down a hierarchy */
  struct swig_cast_info  *cast;			/* linked list of types that can cast into this type */
  void                   *clientdata;		/* language specific type data */
  int                    owndata;		/* flag if the structure owns the clientdata */
} swig_type_info;

/* Structure to store a type and conversion function used for casting */
typedef struct swig_cast_info {
  swig_type_info         *type;			/* pointer to type that is equivalent to this type */
  swig_converter_func     converter;		/* function to cast the void pointers */
  struct swig_cast_info  *next;			/* pointer to next cast in linked list */
  struct swig_cast_info  *prev;			/* pointer to the previous cast */
} swig_cast_info;

/* Structure used to store module information
 * Each module generates one structure like this, and the runtime collects
 * all of these structures and stores them in a circularly linked list.*/
typedef struct swig_module_info {
  swig_type_info         **types;		/* Array of pointers to swig_type_info structures that are in this module */
  size_t                 size;		        /* Number of types in this module */
  struct swig_module_info *next;		/* Pointer to next element in circularly linked list */
  swig_type_info         **type_initial;	/* Array of initially generated type structures */
  swig_cast_info         **cast_initial;	/* Array of initially generated casting structures */
  void                    *clientdata;		/* Language specific module data */
} swig_module_info;

/*
  Compare two type names skipping the space characters, therefore
  "char*" == "char *" and "Class<int>" == "Class<int >", etc.

  Return 0 when the two name types are equivalent, as in
  strncmp, but skipping ' '.
*/
SWIGRUNTIME int
SWIG_TypeNameComp(const char *f1, const char *l1,
		  const char *f2, const char *l2) {
  for (;(f1 != l1) && (f2 != l2); ++f1, ++f2) {
    while ((*f1 == ' ') && (f1 != l1)) ++f1;
    while ((*f2 == ' ') && (f2 != l2)) ++f2;
    if (*f1 != *f2) return (*f1 > *f2) ? 1 : -1;
  }
  return (int)((l1 - f1) - (l2 - f2));
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if equal, -1 if nb < tb, 1 if nb > tb
*/
SWIGRUNTIME int
SWIG_TypeCmp(const char *nb, const char *tb) {
  int equiv = 1;
  const char* te = tb + strlen(tb);
  const char* ne = nb;
  while (equiv != 0 && *ne) {
    for (nb = ne; *ne; ++ne) {
      if (*ne == '|') break;
    }
    equiv = SWIG_TypeNameComp(nb, ne, tb, te);
    if (*ne) ++ne;
  }
  return equiv;
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if not equal, 1 if equal
*/
SWIGRUNTIME int
SWIG_TypeEquiv(const char *nb, const char *tb) {
  return SWIG_TypeCmp(nb, tb) == 0 ? 1 : 0;
}

/*
  Check the typename
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheck(const char *c, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *iter = ty->cast;
    while (iter) {
      if (strcmp(iter->type->name, c) == 0) {
        if (iter == ty->cast)
          return iter;
        /* Move iter to the top of the linked list */
        iter->prev->next = iter->next;
        if (iter->next)
          iter->next->prev = iter->prev;
        iter->next = ty->cast;
        iter->prev = 0;
        if (ty->cast) ty->cast->prev = iter;
        ty->cast = iter;
        return iter;
      }
      iter = iter->next;
    }
  }
  return 0;
}

/*
  Identical to SWIG_TypeCheck, except strcmp is replaced with a pointer comparison
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheckStruct(swig_type_info *from, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *iter = ty->cast;
    while (iter) {
      if (iter->type == from) {
        if (iter == ty->cast)
          return iter;
        /* Move iter to the top of the linked list */
        iter->prev->next = iter->next;
        if (iter->next)
          iter->next->prev = iter->prev;
        iter->next = ty->cast;
        iter->prev = 0;
        if (ty->cast) ty->cast->prev = iter;
        ty->cast = iter;
        return iter;
      }
      iter = iter->next;
    }
  }
  return 0;
}

/*
  Cast a pointer up an inheritance hierarchy
*/
SWIGRUNTIMEINLINE void *
SWIG_TypeCast(swig_cast_info *ty, void *ptr, int *newmemory) {
  return ((!ty) || (!ty->converter)) ? ptr : (*ty->converter)(ptr, newmemory);
}

/*
   Dynamic pointer casting. Down an inheritance hierarchy
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeDynamicCast(swig_type_info *ty, void **ptr) {
  swig_type_info *lastty = ty;
  if (!ty || !ty->dcast) return ty;
  while (ty && (ty->dcast)) {
    ty = (*ty->dcast)(ptr);
    if (ty) lastty = ty;
  }
  return lastty;
}

/*
  Return the name associated with this type
*/
SWIGRUNTIMEINLINE const char *
SWIG_TypeName(const swig_type_info *ty) {
  return ty->name;
}

/*
  Return the pretty name associated with this type,
  that is an unmangled type name in a form presentable to the user.
*/
SWIGRUNTIME const char *
SWIG_TypePrettyName(const swig_type_info *type) {
  /* The "str" field contains the equivalent pretty names of the
     type, separated by vertical-bar characters.  We choose
     to print the last name, as it is often (?) the most
     specific. */
  if (!type) return NULL;
  if (type->str != NULL) {
    const char *last_name = type->str;
    const char *s;
    for (s = type->str; *s; s++)
      if (*s == '|') last_name = s+1;
    return last_name;
  }
  else
    return type->name;
}

/*
   Set the clientdata field for a type
*/
SWIGRUNTIME void
SWIG_TypeClientData(swig_type_info *ti, void *clientdata) {
  swig_cast_info *cast = ti->cast;
  /* if (ti->clientdata == clientdata) return; */
  ti->clientdata = clientdata;

  while (cast) {
    if (!cast->converter) {
      swig_type_info *tc = cast->type;
      if (!tc->clientdata) {
	SWIG_TypeClientData(tc, clientdata);
      }
    }
    cast = cast->next;
  }
}
SWIGRUNTIME void
SWIG_TypeNewClientData(swig_type_info *ti, void *clientdata) {
  SWIG_TypeClientData(ti, clientdata);
  ti->owndata = 1;
}

/*
  Search for a swig_type_info structure only by mangled name
  Search is a O(log #types)

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_MangledTypeQueryModule(swig_module_info *start,
                            swig_module_info *end,
		            const char *name) {
  swig_module_info *iter = start;
  do {
    if (iter->size) {
      size_t l = 0;
      size_t r = iter->size - 1;
      do {
	/* since l+r >= 0, we can (>> 1) instead (/ 2) */
	size_t i = (l + r) >> 1;
	const char *iname = iter->types[i]->name;
	if (iname) {
	  int compare = strcmp(name, iname);
	  if (compare == 0) {
	    return iter->types[i];
	  } else if (compare < 0) {
	    if (i) {
	      r = i - 1;
	    } else {
	      break;
	    }
	  } else if (compare > 0) {
	    l = i + 1;
	  }
	} else {
	  break; /* should never happen */
	}
      } while (l <= r);
    }
    iter = iter->next;
  } while (iter != end);
  return 0;
}

/*
  Search for a swig_type_info structure for either a mangled name or a human readable name.
  It first searches the mangled names of the types, which is a O(log #types)
  If a type is not found it then searches the human readable names, which is O(#types).

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeQueryModule(swig_module_info *start,
                     swig_module_info *end,
		     const char *name) {
  /* STEP 1: Search the name field using binary search */
  swig_type_info *ret = SWIG_MangledTypeQueryModule(start, end, name);
  if (ret) {
    return ret;
  } else {
    /* STEP 2: If the type hasn't been found, do a complete search
       of the str field (the human readable name) */
    swig_module_info *iter = start;
    do {
      size_t i = 0;
      for (; i < iter->size; ++i) {
	if (iter->types[i]->str && (SWIG_TypeEquiv(iter->types[i]->str, name)))
	  return iter->types[i];
      }
      iter = iter->next;
    } while (iter != end);
  }

  /* neither found a match */
  return 0;
}

/*
   Pack binary data into a string
*/
SWIGRUNTIME char *
SWIG_PackData(char *c, void *ptr, size_t sz) {
  static const char hex[17] = "0123456789abcdef";
  const unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu =  u + sz;
  for (; u != eu; ++u) {
    unsigned char uu = *u;
    *(c++) = hex[(uu & 0xf0) >> 4];
    *(c++) = hex[uu & 0xf];
  }
  return c;
}

/*
   Unpack binary data from a string
*/
SWIGRUNTIME const char *
SWIG_UnpackData(const char *c, void *ptr, size_t sz) {
  unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu = u + sz;
  for (; u != eu; ++u) {
    char d = *(c++);
    unsigned char uu;
    if ((d >= '0') && (d <= '9'))
      uu = ((d - '0') << 4);
    else if ((d >= 'a') && (d <= 'f'))
      uu = ((d - ('a'-10)) << 4);
    else
      return (char *) 0;
    d = *(c++);
    if ((d >= '0') && (d <= '9'))
      uu |= (d - '0');
    else if ((d >= 'a') && (d <= 'f'))
      uu |= (d - ('a'-10));
    else
      return (char *) 0;
    *u = uu;
  }
  return c;
}

/*
   Pack 'void *' into a string buffer.
*/
SWIGRUNTIME char *
SWIG_PackVoidPtr(char *buff, void *ptr, const char *name, size_t bsz) {
  char *r = buff;
  if ((2*sizeof(void *) + 2) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,&ptr,sizeof(void *));
  if (strlen(name) + 1 > (bsz - (r - buff))) return 0;
  strcpy(r,name);
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackVoidPtr(const char *c, void **ptr, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      *ptr = (void *) 0;
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sizeof(void *));
}

SWIGRUNTIME char *
SWIG_PackDataName(char *buff, void *ptr, size_t sz, const char *name, size_t bsz) {
  char *r = buff;
  size_t lname = (name ? strlen(name) : 0);
  if ((2*sz + 2 + lname) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,ptr,sz);
  if (lname) {
    strncpy(r,name,lname+1);
  } else {
    *r = 0;
  }
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackDataName(const char *c, void *ptr, size_t sz, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      memset(ptr,0,sz);
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sz);
}

#ifdef __cplusplus
}
#endif

/*  Errors in SWIG */
#define  SWIG_UnknownError    	   -1
#define  SWIG_IOError        	   -2
#define  SWIG_RuntimeError   	   -3
#define  SWIG_IndexError     	   -4
#define  SWIG_TypeError      	   -5
#define  SWIG_DivisionByZero 	   -6
#define  SWIG_OverflowError  	   -7
#define  SWIG_SyntaxError    	   -8
#define  SWIG_ValueError     	   -9
#define  SWIG_SystemError    	   -10
#define  SWIG_AttributeError 	   -11
#define  SWIG_MemoryError    	   -12
#define  SWIG_NullReferenceError   -13



/* Compatibility macros for Python 3 */
#if PY_VERSION_HEX >= 0x03000000

#define PyClass_Check(obj) PyObject_IsInstance(obj, (PyObject *)&PyType_Type)
#define PyInt_Check(x) PyLong_Check(x)
#define PyInt_AsLong(x) PyLong_AsLong(x)
#define PyInt_FromLong(x) PyLong_FromLong(x)
#define PyInt_FromSize_t(x) PyLong_FromSize_t(x)
#define PyString_Check(name) PyBytes_Check(name)
#define PyString_FromString(x) PyUnicode_FromString(x)
#define PyString_Format(fmt, args)  PyUnicode_Format(fmt, args)
#define PyString_AsString(str) PyBytes_AsString(str)
#define PyString_Size(str) PyBytes_Size(str)	
#define PyString_InternFromString(key) PyUnicode_InternFromString(key)
#define Py_TPFLAGS_HAVE_CLASS Py_TPFLAGS_BASETYPE
#define PyString_AS_STRING(x) PyUnicode_AS_STRING(x)
#define _PyLong_FromSsize_t(x) PyLong_FromSsize_t(x)

#endif

#ifndef Py_TYPE
#  define Py_TYPE(op) ((op)->ob_type)
#endif

/* SWIG APIs for compatibility of both Python 2 & 3 */

#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_Python_str_FromFormat PyUnicode_FromFormat
#else
#  define SWIG_Python_str_FromFormat PyString_FromFormat
#endif


/* Warning: This function will allocate a new string in Python 3,
 * so please call SWIG_Python_str_DelForPy3(x) to free the space.
 */
SWIGINTERN char*
SWIG_Python_str_AsChar(PyObject *str)
{
#if PY_VERSION_HEX >= 0x03000000
  char *cstr;
  char *newstr;
  Py_ssize_t len;
  str = PyUnicode_AsUTF8String(str);
  PyBytes_AsStringAndSize(str, &cstr, &len);
  newstr = (char *) malloc(len+1);
  memcpy(newstr, cstr, len+1);
  Py_XDECREF(str);
  return newstr;
#else
  return PyString_AsString(str);
#endif
}

#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_Python_str_DelForPy3(x) free( (void*) (x) )
#else
#  define SWIG_Python_str_DelForPy3(x) 
#endif


SWIGINTERN PyObject*
SWIG_Python_str_FromChar(const char *c)
{
#if PY_VERSION_HEX >= 0x03000000
  return PyUnicode_FromString(c); 
#else
  return PyString_FromString(c);
#endif
}

/* Add PyOS_snprintf for old Pythons */
#if PY_VERSION_HEX < 0x02020000
# if defined(_MSC_VER) || defined(__BORLANDC__) || defined(_WATCOM)
#  define PyOS_snprintf _snprintf
# else
#  define PyOS_snprintf snprintf
# endif
#endif

/* A crude PyString_FromFormat implementation for old Pythons */
#if PY_VERSION_HEX < 0x02020000

#ifndef SWIG_PYBUFFER_SIZE
# define SWIG_PYBUFFER_SIZE 1024
#endif

static PyObject *
PyString_FromFormat(const char *fmt, ...) {
  va_list ap;
  char buf[SWIG_PYBUFFER_SIZE * 2];
  int res;
  va_start(ap, fmt);
  res = vsnprintf(buf, sizeof(buf), fmt, ap);
  va_end(ap);
  return (res < 0 || res >= (int)sizeof(buf)) ? 0 : PyString_FromString(buf);
}
#endif

/* Add PyObject_Del for old Pythons */
#if PY_VERSION_HEX < 0x01060000
# define PyObject_Del(op) PyMem_DEL((op))
#endif
#ifndef PyObject_DEL
# define PyObject_DEL PyObject_Del
#endif

/* A crude PyExc_StopIteration exception for old Pythons */
#if PY_VERSION_HEX < 0x02020000
# ifndef PyExc_StopIteration
#  define PyExc_StopIteration PyExc_RuntimeError
# endif
# ifndef PyObject_GenericGetAttr
#  define PyObject_GenericGetAttr 0
# endif
#endif

/* Py_NotImplemented is defined in 2.1 and up. */
#if PY_VERSION_HEX < 0x02010000
# ifndef Py_NotImplemented
#  define Py_NotImplemented PyExc_RuntimeError
# endif
#endif

/* A crude PyString_AsStringAndSize implementation for old Pythons */
#if PY_VERSION_HEX < 0x02010000
# ifndef PyString_AsStringAndSize
#  define PyString_AsStringAndSize(obj, s, len) {*s = PyString_AsString(obj); *len = *s ? strlen(*s) : 0;}
# endif
#endif

/* PySequence_Size for old Pythons */
#if PY_VERSION_HEX < 0x02000000
# ifndef PySequence_Size
#  define PySequence_Size PySequence_Length
# endif
#endif

/* PyBool_FromLong for old Pythons */
#if PY_VERSION_HEX < 0x02030000
static
PyObject *PyBool_FromLong(long ok)
{
  PyObject *result = ok ? Py_True : Py_False;
  Py_INCREF(result);
  return result;
}
#endif

/* Py_ssize_t for old Pythons */
/* This code is as recommended by: */
/* http://www.python.org/dev/peps/pep-0353/#conversion-guidelines */
#if PY_VERSION_HEX < 0x02050000 && !defined(PY_SSIZE_T_MIN)
typedef int Py_ssize_t;
# define PY_SSIZE_T_MAX INT_MAX
# define PY_SSIZE_T_MIN INT_MIN
typedef inquiry lenfunc;
typedef intargfunc ssizeargfunc;
typedef intintargfunc ssizessizeargfunc;
typedef intobjargproc ssizeobjargproc;
typedef intintobjargproc ssizessizeobjargproc;
typedef getreadbufferproc readbufferproc;
typedef getwritebufferproc writebufferproc;
typedef getsegcountproc segcountproc;
typedef getcharbufferproc charbufferproc;
static long PyNumber_AsSsize_t (PyObject *x, void *SWIGUNUSEDPARM(exc))
{
  long result = 0;
  PyObject *i = PyNumber_Int(x);
  if (i) {
    result = PyInt_AsLong(i);
    Py_DECREF(i);
  }
  return result;
}
#endif

#if PY_VERSION_HEX < 0x02050000
#define PyInt_FromSize_t(x) PyInt_FromLong((long)x)
#endif

#if PY_VERSION_HEX < 0x02040000
#define Py_VISIT(op)				\
  do { 						\
    if (op) {					\
      int vret = visit((op), arg);		\
      if (vret)					\
        return vret;				\
    }						\
  } while (0)
#endif

#if PY_VERSION_HEX < 0x02030000
typedef struct {
  PyTypeObject type;
  PyNumberMethods as_number;
  PyMappingMethods as_mapping;
  PySequenceMethods as_sequence;
  PyBufferProcs as_buffer;
  PyObject *name, *slots;
} PyHeapTypeObject;
#endif

#if PY_VERSION_HEX < 0x02030000
typedef destructor freefunc;
#endif

#if ((PY_MAJOR_VERSION == 2 && PY_MINOR_VERSION > 6) || \
     (PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION > 0) || \
     (PY_MAJOR_VERSION > 3))
# define SWIGPY_USE_CAPSULE
# define SWIGPY_CAPSULE_NAME ((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION ".type_pointer_capsule" SWIG_TYPE_TABLE_NAME)
#endif

#if PY_VERSION_HEX < 0x03020000
#define PyDescr_TYPE(x) (((PyDescrObject *)(x))->d_type)
#define PyDescr_NAME(x) (((PyDescrObject *)(x))->d_name)
#endif

/* -----------------------------------------------------------------------------
 * error manipulation
 * ----------------------------------------------------------------------------- */

SWIGRUNTIME PyObject*
SWIG_Python_ErrorType(int code) {
  PyObject* type = 0;
  switch(code) {
  case SWIG_MemoryError:
    type = PyExc_MemoryError;
    break;
  case SWIG_IOError:
    type = PyExc_IOError;
    break;
  case SWIG_RuntimeError:
    type = PyExc_RuntimeError;
    break;
  case SWIG_IndexError:
    type = PyExc_IndexError;
    break;
  case SWIG_TypeError:
    type = PyExc_TypeError;
    break;
  case SWIG_DivisionByZero:
    type = PyExc_ZeroDivisionError;
    break;
  case SWIG_OverflowError:
    type = PyExc_OverflowError;
    break;
  case SWIG_SyntaxError:
    type = PyExc_SyntaxError;
    break;
  case SWIG_ValueError:
    type = PyExc_ValueError;
    break;
  case SWIG_SystemError:
    type = PyExc_SystemError;
    break;
  case SWIG_AttributeError:
    type = PyExc_AttributeError;
    break;
  default:
    type = PyExc_RuntimeError;
  }
  return type;
}


SWIGRUNTIME void
SWIG_Python_AddErrorMsg(const char* mesg)
{
  PyObject *type = 0;
  PyObject *value = 0;
  PyObject *traceback = 0;

  if (PyErr_Occurred()) PyErr_Fetch(&type, &value, &traceback);
  if (value) {
    char *tmp;
    PyObject *old_str = PyObject_Str(value);
    PyErr_Clear();
    Py_XINCREF(type);

    PyErr_Format(type, "%s %s", tmp = SWIG_Python_str_AsChar(old_str), mesg);
    SWIG_Python_str_DelForPy3(tmp);
    Py_DECREF(old_str);
    Py_DECREF(value);
  } else {
    PyErr_SetString(PyExc_RuntimeError, mesg);
  }
}

#if defined(SWIG_PYTHON_NO_THREADS)
#  if defined(SWIG_PYTHON_THREADS)
#    undef SWIG_PYTHON_THREADS
#  endif
#endif
#if defined(SWIG_PYTHON_THREADS) /* Threading support is enabled */
#  if !defined(SWIG_PYTHON_USE_GIL) && !defined(SWIG_PYTHON_NO_USE_GIL)
#    if (PY_VERSION_HEX >= 0x02030000) /* For 2.3 or later, use the PyGILState calls */
#      define SWIG_PYTHON_USE_GIL
#    endif
#  endif
#  if defined(SWIG_PYTHON_USE_GIL) /* Use PyGILState threads calls */
#    ifndef SWIG_PYTHON_INITIALIZE_THREADS
#     define SWIG_PYTHON_INITIALIZE_THREADS  PyEval_InitThreads() 
#    endif
#    ifdef __cplusplus /* C++ code */
       class SWIG_Python_Thread_Block {
         bool status;
         PyGILState_STATE state;
       public:
         void end() { if (status) { PyGILState_Release(state); status = false;} }
         SWIG_Python_Thread_Block() : status(true), state(PyGILState_Ensure()) {}
         ~SWIG_Python_Thread_Block() { end(); }
       };
       class SWIG_Python_Thread_Allow {
         bool status;
         PyThreadState *save;
       public:
         void end() { if (status) { PyEval_RestoreThread(save); status = false; }}
         SWIG_Python_Thread_Allow() : status(true), save(PyEval_SaveThread()) {}
         ~SWIG_Python_Thread_Allow() { end(); }
       };
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK   SWIG_Python_Thread_Block _swig_thread_block
#      define SWIG_PYTHON_THREAD_END_BLOCK     _swig_thread_block.end()
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW   SWIG_Python_Thread_Allow _swig_thread_allow
#      define SWIG_PYTHON_THREAD_END_ALLOW     _swig_thread_allow.end()
#    else /* C code */
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK   PyGILState_STATE _swig_thread_block = PyGILState_Ensure()
#      define SWIG_PYTHON_THREAD_END_BLOCK     PyGILState_Release(_swig_thread_block)
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW   PyThreadState *_swig_thread_allow = PyEval_SaveThread()
#      define SWIG_PYTHON_THREAD_END_ALLOW     PyEval_RestoreThread(_swig_thread_allow)
#    endif
#  else /* Old thread way, not implemented, user must provide it */
#    if !defined(SWIG_PYTHON_INITIALIZE_THREADS)
#      define SWIG_PYTHON_INITIALIZE_THREADS
#    endif
#    if !defined(SWIG_PYTHON_THREAD_BEGIN_BLOCK)
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK
#    endif
#    if !defined(SWIG_PYTHON_THREAD_END_BLOCK)
#      define SWIG_PYTHON_THREAD_END_BLOCK
#    endif
#    if !defined(SWIG_PYTHON_THREAD_BEGIN_ALLOW)
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW
#    endif
#    if !defined(SWIG_PYTHON_THREAD_END_ALLOW)
#      define SWIG_PYTHON_THREAD_END_ALLOW
#    endif
#  endif
#else /* No thread support */
#  define SWIG_PYTHON_INITIALIZE_THREADS
#  define SWIG_PYTHON_THREAD_BEGIN_BLOCK
#  define SWIG_PYTHON_THREAD_END_BLOCK
#  define SWIG_PYTHON_THREAD_BEGIN_ALLOW
#  define SWIG_PYTHON_THREAD_END_ALLOW
#endif

/* -----------------------------------------------------------------------------
 * Python API portion that goes into the runtime
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#endif

/* -----------------------------------------------------------------------------
 * Constant declarations
 * ----------------------------------------------------------------------------- */

/* Constant Types */
#define SWIG_PY_POINTER 4
#define SWIG_PY_BINARY  5

/* Constant information structure */
typedef struct swig_const_info {
  int type;
  char *name;
  long lvalue;
  double dvalue;
  void   *pvalue;
  swig_type_info **ptype;
} swig_const_info;


/* -----------------------------------------------------------------------------
 * Wrapper of PyInstanceMethod_New() used in Python 3
 * It is exported to the generated module, used for -fastproxy
 * ----------------------------------------------------------------------------- */
#if PY_VERSION_HEX >= 0x03000000
SWIGRUNTIME PyObject* SWIG_PyInstanceMethod_New(PyObject *SWIGUNUSEDPARM(self), PyObject *func)
{
  return PyInstanceMethod_New(func);
}
#else
SWIGRUNTIME PyObject* SWIG_PyInstanceMethod_New(PyObject *SWIGUNUSEDPARM(self), PyObject *SWIGUNUSEDPARM(func))
{
  return NULL;
}
#endif

#ifdef __cplusplus
}
#endif


/* -----------------------------------------------------------------------------
 * pyrun.swg
 *
 * This file contains the runtime support for Python modules
 * and includes code for managing global variables and pointer
 * type checking.
 *
 * ----------------------------------------------------------------------------- */

/* Common SWIG API */

/* for raw pointers */
#define SWIG_Python_ConvertPtr(obj, pptr, type, flags)  SWIG_Python_ConvertPtrAndOwn(obj, pptr, type, flags, 0)
#define SWIG_ConvertPtr(obj, pptr, type, flags)         SWIG_Python_ConvertPtr(obj, pptr, type, flags)
#define SWIG_ConvertPtrAndOwn(obj,pptr,type,flags,own)  SWIG_Python_ConvertPtrAndOwn(obj, pptr, type, flags, own)

#ifdef SWIGPYTHON_BUILTIN
#define SWIG_NewPointerObj(ptr, type, flags)            SWIG_Python_NewPointerObj(self, ptr, type, flags)
#else
#define SWIG_NewPointerObj(ptr, type, flags)            SWIG_Python_NewPointerObj(NULL, ptr, type, flags)
#endif

#define SWIG_InternalNewPointerObj(ptr, type, flags)	SWIG_Python_NewPointerObj(NULL, ptr, type, flags)

#define SWIG_CheckImplicit(ty)                          SWIG_Python_CheckImplicit(ty) 
#define SWIG_AcquirePtr(ptr, src)                       SWIG_Python_AcquirePtr(ptr, src)
#define swig_owntype                                    int

/* for raw packed data */
#define SWIG_ConvertPacked(obj, ptr, sz, ty)            SWIG_Python_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewPackedObj(ptr, sz, type)                SWIG_Python_NewPackedObj(ptr, sz, type)

/* for class or struct pointers */
#define SWIG_ConvertInstance(obj, pptr, type, flags)    SWIG_ConvertPtr(obj, pptr, type, flags)
#define SWIG_NewInstanceObj(ptr, type, flags)           SWIG_NewPointerObj(ptr, type, flags)

/* for C or C++ function pointers */
#define SWIG_ConvertFunctionPtr(obj, pptr, type)        SWIG_Python_ConvertFunctionPtr(obj, pptr, type)
#define SWIG_NewFunctionPtrObj(ptr, type)               SWIG_Python_NewPointerObj(NULL, ptr, type, 0)

/* for C++ member pointers, ie, member methods */
#define SWIG_ConvertMember(obj, ptr, sz, ty)            SWIG_Python_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewMemberObj(ptr, sz, type)                SWIG_Python_NewPackedObj(ptr, sz, type)


/* Runtime API */

#define SWIG_GetModule(clientdata)                      SWIG_Python_GetModule(clientdata)
#define SWIG_SetModule(clientdata, pointer)             SWIG_Python_SetModule(pointer)
#define SWIG_NewClientData(obj)                         SwigPyClientData_New(obj)

#define SWIG_SetErrorObj                                SWIG_Python_SetErrorObj                            
#define SWIG_SetErrorMsg                        	SWIG_Python_SetErrorMsg				   
#define SWIG_ErrorType(code)                    	SWIG_Python_ErrorType(code)                        
#define SWIG_Error(code, msg)            		SWIG_Python_SetErrorMsg(SWIG_ErrorType(code), msg) 
#define SWIG_fail                        		goto fail					   


/* Runtime API implementation */

/* Error manipulation */

SWIGINTERN void 
SWIG_Python_SetErrorObj(PyObject *errtype, PyObject *obj) {
  SWIG_PYTHON_THREAD_BEGIN_BLOCK; 
  PyErr_SetObject(errtype, obj);
  Py_DECREF(obj);
  SWIG_PYTHON_THREAD_END_BLOCK;
}

SWIGINTERN void 
SWIG_Python_SetErrorMsg(PyObject *errtype, const char *msg) {
  SWIG_PYTHON_THREAD_BEGIN_BLOCK;
  PyErr_SetString(errtype, msg);
  SWIG_PYTHON_THREAD_END_BLOCK;
}

#define SWIG_Python_Raise(obj, type, desc)  SWIG_Python_SetErrorObj(SWIG_Python_ExceptionType(desc), obj)

/* Set a constant value */

#if defined(SWIGPYTHON_BUILTIN)

SWIGINTERN void
SwigPyBuiltin_AddPublicSymbol(PyObject *seq, const char *key) {
  PyObject *s = PyString_InternFromString(key);
  PyList_Append(seq, s);
  Py_DECREF(s);
}

SWIGINTERN void
SWIG_Python_SetConstant(PyObject *d, PyObject *public_interface, const char *name, PyObject *obj) {   
#if PY_VERSION_HEX < 0x02030000
  PyDict_SetItemString(d, (char *)name, obj);
#else
  PyDict_SetItemString(d, name, obj);
#endif
  Py_DECREF(obj);
  if (public_interface)
    SwigPyBuiltin_AddPublicSymbol(public_interface, name);
}

#else

SWIGINTERN void
SWIG_Python_SetConstant(PyObject *d, const char *name, PyObject *obj) {   
#if PY_VERSION_HEX < 0x02030000
  PyDict_SetItemString(d, (char *)name, obj);
#else
  PyDict_SetItemString(d, name, obj);
#endif
  Py_DECREF(obj);                            
}

#endif

/* Append a value to the result obj */

SWIGINTERN PyObject*
SWIG_Python_AppendOutput(PyObject* result, PyObject* obj) {
#if !defined(SWIG_PYTHON_OUTPUT_TUPLE)
  if (!result) {
    result = obj;
  } else if (result == Py_None) {
    Py_DECREF(result);
    result = obj;
  } else {
    if (!PyList_Check(result)) {
      PyObject *o2 = result;
      result = PyList_New(1);
      PyList_SetItem(result, 0, o2);
    }
    PyList_Append(result,obj);
    Py_DECREF(obj);
  }
  return result;
#else
  PyObject*   o2;
  PyObject*   o3;
  if (!result) {
    result = obj;
  } else if (result == Py_None) {
    Py_DECREF(result);
    result = obj;
  } else {
    if (!PyTuple_Check(result)) {
      o2 = result;
      result = PyTuple_New(1);
      PyTuple_SET_ITEM(result, 0, o2);
    }
    o3 = PyTuple_New(1);
    PyTuple_SET_ITEM(o3, 0, obj);
    o2 = result;
    result = PySequence_Concat(o2, o3);
    Py_DECREF(o2);
    Py_DECREF(o3);
  }
  return result;
#endif
}

/* Unpack the argument tuple */

SWIGINTERN Py_ssize_t
SWIG_Python_UnpackTuple(PyObject *args, const char *name, Py_ssize_t min, Py_ssize_t max, PyObject **objs)
{
  if (!args) {
    if (!min && !max) {
      return 1;
    } else {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got none", 
		   name, (min == max ? "" : "at least "), (int)min);
      return 0;
    }
  }  
  if (!PyTuple_Check(args)) {
    if (min <= 1 && max >= 1) {
      Py_ssize_t i;
      objs[0] = args;
      for (i = 1; i < max; ++i) {
	objs[i] = 0;
      }
      return 2;
    }
    PyErr_SetString(PyExc_SystemError, "UnpackTuple() argument list is not a tuple");
    return 0;
  } else {
    Py_ssize_t l = PyTuple_GET_SIZE(args);
    if (l < min) {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got %d", 
		   name, (min == max ? "" : "at least "), (int)min, (int)l);
      return 0;
    } else if (l > max) {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got %d", 
		   name, (min == max ? "" : "at most "), (int)max, (int)l);
      return 0;
    } else {
      Py_ssize_t i;
      for (i = 0; i < l; ++i) {
	objs[i] = PyTuple_GET_ITEM(args, i);
      }
      for (; l < max; ++l) {
	objs[l] = 0;
      }
      return i + 1;
    }    
  }
}

/* A functor is a function object with one single object argument */
#if PY_VERSION_HEX >= 0x02020000
#define SWIG_Python_CallFunctor(functor, obj)	        PyObject_CallFunctionObjArgs(functor, obj, NULL);
#else
#define SWIG_Python_CallFunctor(functor, obj)	        PyObject_CallFunction(functor, "O", obj);
#endif

/*
  Helper for static pointer initialization for both C and C++ code, for example
  static PyObject *SWIG_STATIC_POINTER(MyVar) = NewSomething(...);
*/
#ifdef __cplusplus
#define SWIG_STATIC_POINTER(var)  var
#else
#define SWIG_STATIC_POINTER(var)  var = 0; if (!var) var
#endif

/* -----------------------------------------------------------------------------
 * Pointer declarations
 * ----------------------------------------------------------------------------- */

/* Flags for new pointer objects */
#define SWIG_POINTER_NOSHADOW       (SWIG_POINTER_OWN      << 1)
#define SWIG_POINTER_NEW            (SWIG_POINTER_NOSHADOW | SWIG_POINTER_OWN)

#define SWIG_POINTER_IMPLICIT_CONV  (SWIG_POINTER_DISOWN   << 1)

#define SWIG_BUILTIN_TP_INIT	    (SWIG_POINTER_OWN << 2)
#define SWIG_BUILTIN_INIT	    (SWIG_BUILTIN_TP_INIT | SWIG_POINTER_OWN)

#ifdef __cplusplus
extern "C" {
#endif

/*  How to access Py_None */
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  ifndef SWIG_PYTHON_NO_BUILD_NONE
#    ifndef SWIG_PYTHON_BUILD_NONE
#      define SWIG_PYTHON_BUILD_NONE
#    endif
#  endif
#endif

#ifdef SWIG_PYTHON_BUILD_NONE
#  ifdef Py_None
#   undef Py_None
#   define Py_None SWIG_Py_None()
#  endif
SWIGRUNTIMEINLINE PyObject * 
_SWIG_Py_None(void)
{
  PyObject *none = Py_BuildValue((char*)"");
  Py_DECREF(none);
  return none;
}
SWIGRUNTIME PyObject * 
SWIG_Py_None(void)
{
  static PyObject *SWIG_STATIC_POINTER(none) = _SWIG_Py_None();
  return none;
}
#endif

/* The python void return value */

SWIGRUNTIMEINLINE PyObject * 
SWIG_Py_Void(void)
{
  PyObject *none = Py_None;
  Py_INCREF(none);
  return none;
}

/* SwigPyClientData */

typedef struct {
  PyObject *klass;
  PyObject *newraw;
  PyObject *newargs;
  PyObject *destroy;
  int delargs;
  int implicitconv;
  PyTypeObject *pytype;
} SwigPyClientData;

SWIGRUNTIMEINLINE int 
SWIG_Python_CheckImplicit(swig_type_info *ty)
{
  SwigPyClientData *data = (SwigPyClientData *)ty->clientdata;
  return data ? data->implicitconv : 0;
}

SWIGRUNTIMEINLINE PyObject *
SWIG_Python_ExceptionType(swig_type_info *desc) {
  SwigPyClientData *data = desc ? (SwigPyClientData *) desc->clientdata : 0;
  PyObject *klass = data ? data->klass : 0;
  return (klass ? klass : PyExc_RuntimeError);
}


SWIGRUNTIME SwigPyClientData * 
SwigPyClientData_New(PyObject* obj)
{
  if (!obj) {
    return 0;
  } else {
    SwigPyClientData *data = (SwigPyClientData *)malloc(sizeof(SwigPyClientData));
    /* the klass element */
    data->klass = obj;
    Py_INCREF(data->klass);
    /* the newraw method and newargs arguments used to create a new raw instance */
    if (PyClass_Check(obj)) {
      data->newraw = 0;
      data->newargs = obj;
      Py_INCREF(obj);
    } else {
#if (PY_VERSION_HEX < 0x02020000)
      data->newraw = 0;
#else
      data->newraw = PyObject_GetAttrString(data->klass, (char *)"__new__");
#endif
      if (data->newraw) {
	Py_INCREF(data->newraw);
	data->newargs = PyTuple_New(1);
	PyTuple_SetItem(data->newargs, 0, obj);
      } else {
	data->newargs = obj;
      }
      Py_INCREF(data->newargs);
    }
    /* the destroy method, aka as the C++ delete method */
    data->destroy = PyObject_GetAttrString(data->klass, (char *)"__swig_destroy__");
    if (PyErr_Occurred()) {
      PyErr_Clear();
      data->destroy = 0;
    }
    if (data->destroy) {
      int flags;
      Py_INCREF(data->destroy);
      flags = PyCFunction_GET_FLAGS(data->destroy);
#ifdef METH_O
      data->delargs = !(flags & (METH_O));
#else
      data->delargs = 0;
#endif
    } else {
      data->delargs = 0;
    }
    data->implicitconv = 0;
    data->pytype = 0;
    return data;
  }
}

SWIGRUNTIME void 
SwigPyClientData_Del(SwigPyClientData *data) {
  Py_XDECREF(data->newraw);
  Py_XDECREF(data->newargs);
  Py_XDECREF(data->destroy);
}

/* =============== SwigPyObject =====================*/

typedef struct {
  PyObject_HEAD
  void *ptr;
  swig_type_info *ty;
  int own;
  PyObject *next;
#ifdef SWIGPYTHON_BUILTIN
  PyObject *dict;
#endif
} SwigPyObject;


#ifdef SWIGPYTHON_BUILTIN

SWIGRUNTIME PyObject *
SwigPyObject_get___dict__(PyObject *v, PyObject *SWIGUNUSEDPARM(args))
{
  SwigPyObject *sobj = (SwigPyObject *)v;

  if (!sobj->dict)
    sobj->dict = PyDict_New();

  Py_INCREF(sobj->dict);
  return sobj->dict;
}

#endif

SWIGRUNTIME PyObject *
SwigPyObject_long(SwigPyObject *v)
{
  return PyLong_FromVoidPtr(v->ptr);
}

SWIGRUNTIME PyObject *
SwigPyObject_format(const char* fmt, SwigPyObject *v)
{
  PyObject *res = NULL;
  PyObject *args = PyTuple_New(1);
  if (args) {
    if (PyTuple_SetItem(args, 0, SwigPyObject_long(v)) == 0) {
      PyObject *ofmt = SWIG_Python_str_FromChar(fmt);
      if (ofmt) {
#if PY_VERSION_HEX >= 0x03000000
	res = PyUnicode_Format(ofmt,args);
#else
	res = PyString_Format(ofmt,args);
#endif
	Py_DECREF(ofmt);
      }
      Py_DECREF(args);
    }
  }
  return res;
}

SWIGRUNTIME PyObject *
SwigPyObject_oct(SwigPyObject *v)
{
  return SwigPyObject_format("%o",v);
}

SWIGRUNTIME PyObject *
SwigPyObject_hex(SwigPyObject *v)
{
  return SwigPyObject_format("%x",v);
}

SWIGRUNTIME PyObject *
#ifdef METH_NOARGS
SwigPyObject_repr(SwigPyObject *v)
#else
SwigPyObject_repr(SwigPyObject *v, PyObject *args)
#endif
{
  const char *name = SWIG_TypePrettyName(v->ty);
  PyObject *repr = SWIG_Python_str_FromFormat("<Swig Object of type '%s' at %p>", (name ? name : "unknown"), (void *)v);
  if (v->next) {
# ifdef METH_NOARGS
    PyObject *nrep = SwigPyObject_repr((SwigPyObject *)v->next);
# else
    PyObject *nrep = SwigPyObject_repr((SwigPyObject *)v->next, args);
# endif
# if PY_VERSION_HEX >= 0x03000000
    PyObject *joined = PyUnicode_Concat(repr, nrep);
    Py_DecRef(repr);
    Py_DecRef(nrep);
    repr = joined;
# else
    PyString_ConcatAndDel(&repr,nrep);
# endif
  }
  return repr;  
}

SWIGRUNTIME int
SwigPyObject_compare(SwigPyObject *v, SwigPyObject *w)
{
  void *i = v->ptr;
  void *j = w->ptr;
  return (i < j) ? -1 : ((i > j) ? 1 : 0);
}

/* Added for Python 3.x, would it also be useful for Python 2.x? */
SWIGRUNTIME PyObject*
SwigPyObject_richcompare(SwigPyObject *v, SwigPyObject *w, int op)
{
  PyObject* res;
  if( op != Py_EQ && op != Py_NE ) {
    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
  }
  res = PyBool_FromLong( (SwigPyObject_compare(v, w)==0) == (op == Py_EQ) ? 1 : 0);
  return res;  
}


SWIGRUNTIME PyTypeObject* SwigPyObject_TypeOnce(void);

#ifdef SWIGPYTHON_BUILTIN
static swig_type_info *SwigPyObject_stype = 0;
SWIGRUNTIME PyTypeObject*
SwigPyObject_type(void) {
    SwigPyClientData *cd;
    assert(SwigPyObject_stype);
    cd = (SwigPyClientData*) SwigPyObject_stype->clientdata;
    assert(cd);
    assert(cd->pytype);
    return cd->pytype;
}
#else
SWIGRUNTIME PyTypeObject*
SwigPyObject_type(void) {
  static PyTypeObject *SWIG_STATIC_POINTER(type) = SwigPyObject_TypeOnce();
  return type;
}
#endif

SWIGRUNTIMEINLINE int
SwigPyObject_Check(PyObject *op) {
#ifdef SWIGPYTHON_BUILTIN
  PyTypeObject *target_tp = SwigPyObject_type();
  if (PyType_IsSubtype(op->ob_type, target_tp))
    return 1;
  return (strcmp(op->ob_type->tp_name, "SwigPyObject") == 0);
#else
  return (Py_TYPE(op) == SwigPyObject_type())
    || (strcmp(Py_TYPE(op)->tp_name,"SwigPyObject") == 0);
#endif
}

SWIGRUNTIME PyObject *
SwigPyObject_New(void *ptr, swig_type_info *ty, int own);

SWIGRUNTIME void
SwigPyObject_dealloc(PyObject *v)
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  PyObject *next = sobj->next;
  if (sobj->own == SWIG_POINTER_OWN) {
    swig_type_info *ty = sobj->ty;
    SwigPyClientData *data = ty ? (SwigPyClientData *) ty->clientdata : 0;
    PyObject *destroy = data ? data->destroy : 0;
    if (destroy) {
      /* destroy is always a VARARGS method */
      PyObject *res;

      /* PyObject_CallFunction() has the potential to silently drop
         the active active exception.  In cases of unnamed temporary
         variable or where we just finished iterating over a generator
         StopIteration will be active right now, and this needs to
         remain true upon return from SwigPyObject_dealloc.  So save
         and restore. */
      
      PyObject *val = NULL, *type = NULL, *tb = NULL;
      PyErr_Fetch(&val, &type, &tb);

      if (data->delargs) {
        /* we need to create a temporary object to carry the destroy operation */
        PyObject *tmp = SwigPyObject_New(sobj->ptr, ty, 0);
        res = SWIG_Python_CallFunctor(destroy, tmp);
        Py_DECREF(tmp);
      } else {
        PyCFunction meth = PyCFunction_GET_FUNCTION(destroy);
        PyObject *mself = PyCFunction_GET_SELF(destroy);
        res = ((*meth)(mself, v));
      }
      if (!res)
        PyErr_WriteUnraisable(destroy);

      PyErr_Restore(val, type, tb);

      Py_XDECREF(res);
    } 
#if !defined(SWIG_PYTHON_SILENT_MEMLEAK)
    else {
      const char *name = SWIG_TypePrettyName(ty);
      printf("swig/python detected a memory leak of type '%s', no destructor found.\n", (name ? name : "unknown"));
    }
#endif
  } 
  Py_XDECREF(next);
  PyObject_DEL(v);
}

SWIGRUNTIME PyObject* 
SwigPyObject_append(PyObject* v, PyObject* next)
{
  SwigPyObject *sobj = (SwigPyObject *) v;
#ifndef METH_O
  PyObject *tmp = 0;
  if (!PyArg_ParseTuple(next,(char *)"O:append", &tmp)) return NULL;
  next = tmp;
#endif
  if (!SwigPyObject_Check(next)) {
    PyErr_SetString(PyExc_TypeError, "Attempt to append a non SwigPyObject");
    return NULL;
  }
  sobj->next = next;
  Py_INCREF(next);
  return SWIG_Py_Void();
}

SWIGRUNTIME PyObject* 
#ifdef METH_NOARGS
SwigPyObject_next(PyObject* v)
#else
SwigPyObject_next(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
#endif
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  if (sobj->next) {    
    Py_INCREF(sobj->next);
    return sobj->next;
  } else {
    return SWIG_Py_Void();
  }
}

SWIGINTERN PyObject*
#ifdef METH_NOARGS
SwigPyObject_disown(PyObject *v)
#else
SwigPyObject_disown(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
#endif
{
  SwigPyObject *sobj = (SwigPyObject *)v;
  sobj->own = 0;
  return SWIG_Py_Void();
}

SWIGINTERN PyObject*
#ifdef METH_NOARGS
SwigPyObject_acquire(PyObject *v)
#else
SwigPyObject_acquire(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
#endif
{
  SwigPyObject *sobj = (SwigPyObject *)v;
  sobj->own = SWIG_POINTER_OWN;
  return SWIG_Py_Void();
}

SWIGINTERN PyObject*
SwigPyObject_own(PyObject *v, PyObject *args)
{
  PyObject *val = 0;
#if (PY_VERSION_HEX < 0x02020000)
  if (!PyArg_ParseTuple(args,(char *)"|O:own",&val))
#elif (PY_VERSION_HEX < 0x02050000)
  if (!PyArg_UnpackTuple(args, (char *)"own", 0, 1, &val)) 
#else
  if (!PyArg_UnpackTuple(args, "own", 0, 1, &val)) 
#endif
    {
      return NULL;
    } 
  else
    {
      SwigPyObject *sobj = (SwigPyObject *)v;
      PyObject *obj = PyBool_FromLong(sobj->own);
      if (val) {
#ifdef METH_NOARGS
	if (PyObject_IsTrue(val)) {
	  SwigPyObject_acquire(v);
	} else {
	  SwigPyObject_disown(v);
	}
#else
	if (PyObject_IsTrue(val)) {
	  SwigPyObject_acquire(v,args);
	} else {
	  SwigPyObject_disown(v,args);
	}
#endif
      } 
      return obj;
    }
}

#ifdef METH_O
static PyMethodDef
swigobject_methods[] = {
  {(char *)"disown",  (PyCFunction)SwigPyObject_disown,  METH_NOARGS,  (char *)"releases ownership of the pointer"},
  {(char *)"acquire", (PyCFunction)SwigPyObject_acquire, METH_NOARGS,  (char *)"acquires ownership of the pointer"},
  {(char *)"own",     (PyCFunction)SwigPyObject_own,     METH_VARARGS, (char *)"returns/sets ownership of the pointer"},
  {(char *)"append",  (PyCFunction)SwigPyObject_append,  METH_O,       (char *)"appends another 'this' object"},
  {(char *)"next",    (PyCFunction)SwigPyObject_next,    METH_NOARGS,  (char *)"returns the next 'this' object"},
  {(char *)"__repr__",(PyCFunction)SwigPyObject_repr,    METH_NOARGS,  (char *)"returns object representation"},
  {0, 0, 0, 0}  
};
#else
static PyMethodDef
swigobject_methods[] = {
  {(char *)"disown",  (PyCFunction)SwigPyObject_disown,  METH_VARARGS,  (char *)"releases ownership of the pointer"},
  {(char *)"acquire", (PyCFunction)SwigPyObject_acquire, METH_VARARGS,  (char *)"acquires ownership of the pointer"},
  {(char *)"own",     (PyCFunction)SwigPyObject_own,     METH_VARARGS,  (char *)"returns/sets ownership of the pointer"},
  {(char *)"append",  (PyCFunction)SwigPyObject_append,  METH_VARARGS,  (char *)"appends another 'this' object"},
  {(char *)"next",    (PyCFunction)SwigPyObject_next,    METH_VARARGS,  (char *)"returns the next 'this' object"},
  {(char *)"__repr__",(PyCFunction)SwigPyObject_repr,   METH_VARARGS,  (char *)"returns object representation"},
  {0, 0, 0, 0}  
};
#endif

#if PY_VERSION_HEX < 0x02020000
SWIGINTERN PyObject *
SwigPyObject_getattr(SwigPyObject *sobj,char *name)
{
  return Py_FindMethod(swigobject_methods, (PyObject *)sobj, name);
}
#endif

SWIGRUNTIME PyTypeObject*
SwigPyObject_TypeOnce(void) {
  static char swigobject_doc[] = "Swig object carries a C/C++ instance pointer";

  static PyNumberMethods SwigPyObject_as_number = {
    (binaryfunc)0, /*nb_add*/
    (binaryfunc)0, /*nb_subtract*/
    (binaryfunc)0, /*nb_multiply*/
    /* nb_divide removed in Python 3 */
#if PY_VERSION_HEX < 0x03000000
    (binaryfunc)0, /*nb_divide*/
#endif
    (binaryfunc)0, /*nb_remainder*/
    (binaryfunc)0, /*nb_divmod*/
    (ternaryfunc)0,/*nb_power*/
    (unaryfunc)0,  /*nb_negative*/
    (unaryfunc)0,  /*nb_positive*/
    (unaryfunc)0,  /*nb_absolute*/
    (inquiry)0,    /*nb_nonzero*/
    0,		   /*nb_invert*/
    0,		   /*nb_lshift*/
    0,		   /*nb_rshift*/
    0,		   /*nb_and*/
    0,		   /*nb_xor*/
    0,		   /*nb_or*/
#if PY_VERSION_HEX < 0x03000000
    0,   /*nb_coerce*/
#endif
    (unaryfunc)SwigPyObject_long, /*nb_int*/
#if PY_VERSION_HEX < 0x03000000
    (unaryfunc)SwigPyObject_long, /*nb_long*/
#else
    0, /*nb_reserved*/
#endif
    (unaryfunc)0,                 /*nb_float*/
#if PY_VERSION_HEX < 0x03000000
    (unaryfunc)SwigPyObject_oct,  /*nb_oct*/
    (unaryfunc)SwigPyObject_hex,  /*nb_hex*/
#endif
#if PY_VERSION_HEX >= 0x03050000 /* 3.5 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_inplace_matrix_multiply */
#elif PY_VERSION_HEX >= 0x03000000 /* 3.0 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_index, nb_inplace_divide removed */
#elif PY_VERSION_HEX >= 0x02050000 /* 2.5.0 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_index */
#elif PY_VERSION_HEX >= 0x02020000 /* 2.2.0 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_inplace_true_divide */
#elif PY_VERSION_HEX >= 0x02000000 /* 2.0.0 */
    0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_inplace_or */
#endif
  };

  static PyTypeObject swigpyobject_type;
  static int type_init = 0;
  if (!type_init) {
    const PyTypeObject tmp = {
      /* PyObject header changed in Python 3 */
#if PY_VERSION_HEX >= 0x03000000
      PyVarObject_HEAD_INIT(NULL, 0)
#else
      PyObject_HEAD_INIT(NULL)
      0,                                    /* ob_size */
#endif
      (char *)"SwigPyObject",               /* tp_name */
      sizeof(SwigPyObject),                 /* tp_basicsize */
      0,                                    /* tp_itemsize */
      (destructor)SwigPyObject_dealloc,     /* tp_dealloc */
      0,				    /* tp_print */
#if PY_VERSION_HEX < 0x02020000
      (getattrfunc)SwigPyObject_getattr,    /* tp_getattr */
#else
      (getattrfunc)0,                       /* tp_getattr */
#endif
      (setattrfunc)0,                       /* tp_setattr */
#if PY_VERSION_HEX >= 0x03000000
    0, /* tp_reserved in 3.0.1, tp_compare in 3.0.0 but not used */
#else
      (cmpfunc)SwigPyObject_compare,        /* tp_compare */
#endif
      (reprfunc)SwigPyObject_repr,          /* tp_repr */
      &SwigPyObject_as_number,              /* tp_as_number */
      0,                                    /* tp_as_sequence */
      0,                                    /* tp_as_mapping */
      (hashfunc)0,                          /* tp_hash */
      (ternaryfunc)0,                       /* tp_call */
      0,				    /* tp_str */
      PyObject_GenericGetAttr,              /* tp_getattro */
      0,                                    /* tp_setattro */
      0,                                    /* tp_as_buffer */
      Py_TPFLAGS_DEFAULT,                   /* tp_flags */
      swigobject_doc,                       /* tp_doc */
      0,                                    /* tp_traverse */
      0,                                    /* tp_clear */
      (richcmpfunc)SwigPyObject_richcompare,/* tp_richcompare */
      0,                                    /* tp_weaklistoffset */
#if PY_VERSION_HEX >= 0x02020000
      0,                                    /* tp_iter */
      0,                                    /* tp_iternext */
      swigobject_methods,                   /* tp_methods */
      0,                                    /* tp_members */
      0,                                    /* tp_getset */
      0,                                    /* tp_base */
      0,                                    /* tp_dict */
      0,                                    /* tp_descr_get */
      0,                                    /* tp_descr_set */
      0,                                    /* tp_dictoffset */
      0,                                    /* tp_init */
      0,                                    /* tp_alloc */
      0,                                    /* tp_new */
      0,                                    /* tp_free */
      0,                                    /* tp_is_gc */
      0,                                    /* tp_bases */
      0,                                    /* tp_mro */
      0,                                    /* tp_cache */
      0,                                    /* tp_subclasses */
      0,                                    /* tp_weaklist */
#endif
#if PY_VERSION_HEX >= 0x02030000
      0,                                    /* tp_del */
#endif
#if PY_VERSION_HEX >= 0x02060000
      0,                                    /* tp_version_tag */
#endif
#if PY_VERSION_HEX >= 0x03040000
      0,                                    /* tp_finalize */
#endif
#ifdef COUNT_ALLOCS
      0,                                    /* tp_allocs */
      0,                                    /* tp_frees */
      0,                                    /* tp_maxalloc */
#if PY_VERSION_HEX >= 0x02050000
      0,                                    /* tp_prev */
#endif
      0                                     /* tp_next */
#endif
    };
    swigpyobject_type = tmp;
    type_init = 1;
#if PY_VERSION_HEX < 0x02020000
    swigpyobject_type.ob_type = &PyType_Type;
#else
    if (PyType_Ready(&swigpyobject_type) < 0)
      return NULL;
#endif
  }
  return &swigpyobject_type;
}

SWIGRUNTIME PyObject *
SwigPyObject_New(void *ptr, swig_type_info *ty, int own)
{
  SwigPyObject *sobj = PyObject_NEW(SwigPyObject, SwigPyObject_type());
  if (sobj) {
    sobj->ptr  = ptr;
    sobj->ty   = ty;
    sobj->own  = own;
    sobj->next = 0;
  }
  return (PyObject *)sobj;
}

/* -----------------------------------------------------------------------------
 * Implements a simple Swig Packed type, and use it instead of string
 * ----------------------------------------------------------------------------- */

typedef struct {
  PyObject_HEAD
  void *pack;
  swig_type_info *ty;
  size_t size;
} SwigPyPacked;

SWIGRUNTIME int
SwigPyPacked_print(SwigPyPacked *v, FILE *fp, int SWIGUNUSEDPARM(flags))
{
  char result[SWIG_BUFFER_SIZE];
  fputs("<Swig Packed ", fp); 
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))) {
    fputs("at ", fp); 
    fputs(result, fp); 
  }
  fputs(v->ty->name,fp); 
  fputs(">", fp);
  return 0; 
}
  
SWIGRUNTIME PyObject *
SwigPyPacked_repr(SwigPyPacked *v)
{
  char result[SWIG_BUFFER_SIZE];
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))) {
    return SWIG_Python_str_FromFormat("<Swig Packed at %s%s>", result, v->ty->name);
  } else {
    return SWIG_Python_str_FromFormat("<Swig Packed %s>", v->ty->name);
  }  
}

SWIGRUNTIME PyObject *
SwigPyPacked_str(SwigPyPacked *v)
{
  char result[SWIG_BUFFER_SIZE];
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))){
    return SWIG_Python_str_FromFormat("%s%s", result, v->ty->name);
  } else {
    return SWIG_Python_str_FromChar(v->ty->name);
  }  
}

SWIGRUNTIME int
SwigPyPacked_compare(SwigPyPacked *v, SwigPyPacked *w)
{
  size_t i = v->size;
  size_t j = w->size;
  int s = (i < j) ? -1 : ((i > j) ? 1 : 0);
  return s ? s : strncmp((char *)v->pack, (char *)w->pack, 2*v->size);
}

SWIGRUNTIME PyTypeObject* SwigPyPacked_TypeOnce(void);

SWIGRUNTIME PyTypeObject*
SwigPyPacked_type(void) {
  static PyTypeObject *SWIG_STATIC_POINTER(type) = SwigPyPacked_TypeOnce();
  return type;
}

SWIGRUNTIMEINLINE int
SwigPyPacked_Check(PyObject *op) {
  return ((op)->ob_type == SwigPyPacked_TypeOnce()) 
    || (strcmp((op)->ob_type->tp_name,"SwigPyPacked") == 0);
}

SWIGRUNTIME void
SwigPyPacked_dealloc(PyObject *v)
{
  if (SwigPyPacked_Check(v)) {
    SwigPyPacked *sobj = (SwigPyPacked *) v;
    free(sobj->pack);
  }
  PyObject_DEL(v);
}

SWIGRUNTIME PyTypeObject*
SwigPyPacked_TypeOnce(void) {
  static char swigpacked_doc[] = "Swig object carries a C/C++ instance pointer";
  static PyTypeObject swigpypacked_type;
  static int type_init = 0;
  if (!type_init) {
    const PyTypeObject tmp = {
      /* PyObject header changed in Python 3 */
#if PY_VERSION_HEX>=0x03000000
      PyVarObject_HEAD_INIT(NULL, 0)
#else
      PyObject_HEAD_INIT(NULL)
      0,                                    /* ob_size */
#endif
      (char *)"SwigPyPacked",               /* tp_name */
      sizeof(SwigPyPacked),                 /* tp_basicsize */
      0,                                    /* tp_itemsize */
      (destructor)SwigPyPacked_dealloc,     /* tp_dealloc */
      (printfunc)SwigPyPacked_print,        /* tp_print */
      (getattrfunc)0,                       /* tp_getattr */
      (setattrfunc)0,                       /* tp_setattr */
#if PY_VERSION_HEX>=0x03000000
      0, /* tp_reserved in 3.0.1 */
#else
      (cmpfunc)SwigPyPacked_compare,        /* tp_compare */
#endif
      (reprfunc)SwigPyPacked_repr,          /* tp_repr */
      0,                                    /* tp_as_number */
      0,                                    /* tp_as_sequence */
      0,                                    /* tp_as_mapping */
      (hashfunc)0,                          /* tp_hash */
      (ternaryfunc)0,                       /* tp_call */
      (reprfunc)SwigPyPacked_str,           /* tp_str */
      PyObject_GenericGetAttr,              /* tp_getattro */
      0,                                    /* tp_setattro */
      0,                                    /* tp_as_buffer */
      Py_TPFLAGS_DEFAULT,                   /* tp_flags */
      swigpacked_doc,                       /* tp_doc */
      0,                                    /* tp_traverse */
      0,                                    /* tp_clear */
      0,                                    /* tp_richcompare */
      0,                                    /* tp_weaklistoffset */
#if PY_VERSION_HEX >= 0x02020000
      0,                                    /* tp_iter */
      0,                                    /* tp_iternext */
      0,                                    /* tp_methods */
      0,                                    /* tp_members */
      0,                                    /* tp_getset */
      0,                                    /* tp_base */
      0,                                    /* tp_dict */
      0,                                    /* tp_descr_get */
      0,                                    /* tp_descr_set */
      0,                                    /* tp_dictoffset */
      0,                                    /* tp_init */
      0,                                    /* tp_alloc */
      0,                                    /* tp_new */
      0,                                    /* tp_free */
      0,                                    /* tp_is_gc */
      0,                                    /* tp_bases */
      0,                                    /* tp_mro */
      0,                                    /* tp_cache */
      0,                                    /* tp_subclasses */
      0,                                    /* tp_weaklist */
#endif
#if PY_VERSION_HEX >= 0x02030000
      0,                                    /* tp_del */
#endif
#if PY_VERSION_HEX >= 0x02060000
      0,                                    /* tp_version_tag */
#endif
#if PY_VERSION_HEX >= 0x03040000
      0,                                    /* tp_finalize */
#endif
#ifdef COUNT_ALLOCS
      0,                                    /* tp_allocs */
      0,                                    /* tp_frees */
      0,                                    /* tp_maxalloc */
#if PY_VERSION_HEX >= 0x02050000
      0,                                    /* tp_prev */
#endif
      0                                     /* tp_next */
#endif
    };
    swigpypacked_type = tmp;
    type_init = 1;
#if PY_VERSION_HEX < 0x02020000
    swigpypacked_type.ob_type = &PyType_Type;
#else
    if (PyType_Ready(&swigpypacked_type) < 0)
      return NULL;
#endif
  }
  return &swigpypacked_type;
}

SWIGRUNTIME PyObject *
SwigPyPacked_New(void *ptr, size_t size, swig_type_info *ty)
{
  SwigPyPacked *sobj = PyObject_NEW(SwigPyPacked, SwigPyPacked_type());
  if (sobj) {
    void *pack = malloc(size);
    if (pack) {
      memcpy(pack, ptr, size);
      sobj->pack = pack;
      sobj->ty   = ty;
      sobj->size = size;
    } else {
      PyObject_DEL((PyObject *) sobj);
      sobj = 0;
    }
  }
  return (PyObject *) sobj;
}

SWIGRUNTIME swig_type_info *
SwigPyPacked_UnpackData(PyObject *obj, void *ptr, size_t size)
{
  if (SwigPyPacked_Check(obj)) {
    SwigPyPacked *sobj = (SwigPyPacked *)obj;
    if (sobj->size != size) return 0;
    memcpy(ptr, sobj->pack, size);
    return sobj->ty;
  } else {
    return 0;
  }
}

/* -----------------------------------------------------------------------------
 * pointers/data manipulation
 * ----------------------------------------------------------------------------- */

SWIGRUNTIMEINLINE PyObject *
_SWIG_This(void)
{
    return SWIG_Python_str_FromChar("this");
}

static PyObject *swig_this = NULL;

SWIGRUNTIME PyObject *
SWIG_This(void)
{
  if (swig_this == NULL)
    swig_this = _SWIG_This();
  return swig_this;
}

/* #define SWIG_PYTHON_SLOW_GETSET_THIS */

/* TODO: I don't know how to implement the fast getset in Python 3 right now */
#if PY_VERSION_HEX>=0x03000000
#define SWIG_PYTHON_SLOW_GETSET_THIS 
#endif

SWIGRUNTIME SwigPyObject *
SWIG_Python_GetSwigThis(PyObject *pyobj) 
{
  PyObject *obj;

  if (SwigPyObject_Check(pyobj))
    return (SwigPyObject *) pyobj;

#ifdef SWIGPYTHON_BUILTIN
  (void)obj;
# ifdef PyWeakref_CheckProxy
  if (PyWeakref_CheckProxy(pyobj)) {
    pyobj = PyWeakref_GET_OBJECT(pyobj);
    if (pyobj && SwigPyObject_Check(pyobj))
      return (SwigPyObject*) pyobj;
  }
# endif
  return NULL;
#else

  obj = 0;

#if (!defined(SWIG_PYTHON_SLOW_GETSET_THIS) && (PY_VERSION_HEX >= 0x02030000))
  if (PyInstance_Check(pyobj)) {
    obj = _PyInstance_Lookup(pyobj, SWIG_This());      
  } else {
    PyObject **dictptr = _PyObject_GetDictPtr(pyobj);
    if (dictptr != NULL) {
      PyObject *dict = *dictptr;
      obj = dict ? PyDict_GetItem(dict, SWIG_This()) : 0;
    } else {
#ifdef PyWeakref_CheckProxy
      if (PyWeakref_CheckProxy(pyobj)) {
	PyObject *wobj = PyWeakref_GET_OBJECT(pyobj);
	return wobj ? SWIG_Python_GetSwigThis(wobj) : 0;
      }
#endif
      obj = PyObject_GetAttr(pyobj,SWIG_This());
      if (obj) {
	Py_DECREF(obj);
      } else {
	if (PyErr_Occurred()) PyErr_Clear();
	return 0;
      }
    }
  }
#else
  obj = PyObject_GetAttr(pyobj,SWIG_This());
  if (obj) {
    Py_DECREF(obj);
  } else {
    if (PyErr_Occurred()) PyErr_Clear();
    return 0;
  }
#endif
  if (obj && !SwigPyObject_Check(obj)) {
    /* a PyObject is called 'this', try to get the 'real this'
       SwigPyObject from it */ 
    return SWIG_Python_GetSwigThis(obj);
  }
  return (SwigPyObject *)obj;
#endif
}

/* Acquire a pointer value */

SWIGRUNTIME int
SWIG_Python_AcquirePtr(PyObject *obj, int own) {
  if (own == SWIG_POINTER_OWN) {
    SwigPyObject *sobj = SWIG_Python_GetSwigThis(obj);
    if (sobj) {
      int oldown = sobj->own;
      sobj->own = own;
      return oldown;
    }
  }
  return 0;
}

/* Convert a pointer value */

SWIGRUNTIME int
SWIG_Python_ConvertPtrAndOwn(PyObject *obj, void **ptr, swig_type_info *ty, int flags, int *own) {
  int res;
  SwigPyObject *sobj;
  int implicit_conv = (flags & SWIG_POINTER_IMPLICIT_CONV) != 0;

  if (!obj)
    return SWIG_ERROR;
  if (obj == Py_None && !implicit_conv) {
    if (ptr)
      *ptr = 0;
    return SWIG_OK;
  }

  res = SWIG_ERROR;

  sobj = SWIG_Python_GetSwigThis(obj);
  if (own)
    *own = 0;
  while (sobj) {
    void *vptr = sobj->ptr;
    if (ty) {
      swig_type_info *to = sobj->ty;
      if (to == ty) {
        /* no type cast needed */
        if (ptr) *ptr = vptr;
        break;
      } else {
        swig_cast_info *tc = SWIG_TypeCheck(to->name,ty);
        if (!tc) {
          sobj = (SwigPyObject *)sobj->next;
        } else {
          if (ptr) {
            int newmemory = 0;
            *ptr = SWIG_TypeCast(tc,vptr,&newmemory);
            if (newmemory == SWIG_CAST_NEW_MEMORY) {
              assert(own); /* badly formed typemap which will lead to a memory leak - it must set and use own to delete *ptr */
              if (own)
                *own = *own | SWIG_CAST_NEW_MEMORY;
            }
          }
          break;
        }
      }
    } else {
      if (ptr) *ptr = vptr;
      break;
    }
  }
  if (sobj) {
    if (own)
      *own = *own | sobj->own;
    if (flags & SWIG_POINTER_DISOWN) {
      sobj->own = 0;
    }
    res = SWIG_OK;
  } else {
    if (implicit_conv) {
      SwigPyClientData *data = ty ? (SwigPyClientData *) ty->clientdata : 0;
      if (data && !data->implicitconv) {
        PyObject *klass = data->klass;
        if (klass) {
          PyObject *impconv;
          data->implicitconv = 1; /* avoid recursion and call 'explicit' constructors*/
          impconv = SWIG_Python_CallFunctor(klass, obj);
          data->implicitconv = 0;
          if (PyErr_Occurred()) {
            PyErr_Clear();
            impconv = 0;
          }
          if (impconv) {
            SwigPyObject *iobj = SWIG_Python_GetSwigThis(impconv);
            if (iobj) {
              void *vptr;
              res = SWIG_Python_ConvertPtrAndOwn((PyObject*)iobj, &vptr, ty, 0, 0);
              if (SWIG_IsOK(res)) {
                if (ptr) {
                  *ptr = vptr;
                  /* transfer the ownership to 'ptr' */
                  iobj->own = 0;
                  res = SWIG_AddCast(res);
                  res = SWIG_AddNewMask(res);
                } else {
                  res = SWIG_AddCast(res);		    
                }
              }
            }
            Py_DECREF(impconv);
          }
        }
      }
    }
    if (!SWIG_IsOK(res) && obj == Py_None) {
      if (ptr)
        *ptr = 0;
      if (PyErr_Occurred())
        PyErr_Clear();
      res = SWIG_OK;
    }
  }
  return res;
}

/* Convert a function ptr value */

SWIGRUNTIME int
SWIG_Python_ConvertFunctionPtr(PyObject *obj, void **ptr, swig_type_info *ty) {
  if (!PyCFunction_Check(obj)) {
    return SWIG_ConvertPtr(obj, ptr, ty, 0);
  } else {
    void *vptr = 0;
    
    /* here we get the method pointer for callbacks */
    const char *doc = (((PyCFunctionObject *)obj) -> m_ml -> ml_doc);
    const char *desc = doc ? strstr(doc, "swig_ptr: ") : 0;
    if (desc)
      desc = ty ? SWIG_UnpackVoidPtr(desc + 10, &vptr, ty->name) : 0;
    if (!desc) 
      return SWIG_ERROR;
    if (ty) {
      swig_cast_info *tc = SWIG_TypeCheck(desc,ty);
      if (tc) {
        int newmemory = 0;
        *ptr = SWIG_TypeCast(tc,vptr,&newmemory);
        assert(!newmemory); /* newmemory handling not yet implemented */
      } else {
        return SWIG_ERROR;
      }
    } else {
      *ptr = vptr;
    }
    return SWIG_OK;
  }
}

/* Convert a packed value value */

SWIGRUNTIME int
SWIG_Python_ConvertPacked(PyObject *obj, void *ptr, size_t sz, swig_type_info *ty) {
  swig_type_info *to = SwigPyPacked_UnpackData(obj, ptr, sz);
  if (!to) return SWIG_ERROR;
  if (ty) {
    if (to != ty) {
      /* check type cast? */
      swig_cast_info *tc = SWIG_TypeCheck(to->name,ty);
      if (!tc) return SWIG_ERROR;
    }
  }
  return SWIG_OK;
}  

/* -----------------------------------------------------------------------------
 * Create a new pointer object
 * ----------------------------------------------------------------------------- */

/*
  Create a new instance object, without calling __init__, and set the
  'this' attribute.
*/

SWIGRUNTIME PyObject* 
SWIG_Python_NewShadowInstance(SwigPyClientData *data, PyObject *swig_this)
{
#if (PY_VERSION_HEX >= 0x02020000)
  PyObject *inst = 0;
  PyObject *newraw = data->newraw;
  if (newraw) {
    inst = PyObject_Call(newraw, data->newargs, NULL);
    if (inst) {
#if !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
      PyObject **dictptr = _PyObject_GetDictPtr(inst);
      if (dictptr != NULL) {
	PyObject *dict = *dictptr;
	if (dict == NULL) {
	  dict = PyDict_New();
	  *dictptr = dict;
	  PyDict_SetItem(dict, SWIG_This(), swig_this);
	}
      }
#else
      PyObject *key = SWIG_This();
      PyObject_SetAttr(inst, key, swig_this);
#endif
    }
  } else {
#if PY_VERSION_HEX >= 0x03000000
    inst = ((PyTypeObject*) data->newargs)->tp_new((PyTypeObject*) data->newargs, Py_None, Py_None);
    if (inst) {
      PyObject_SetAttr(inst, SWIG_This(), swig_this);
      Py_TYPE(inst)->tp_flags &= ~Py_TPFLAGS_VALID_VERSION_TAG;
    }
#else
    PyObject *dict = PyDict_New();
    if (dict) {
      PyDict_SetItem(dict, SWIG_This(), swig_this);
      inst = PyInstance_NewRaw(data->newargs, dict);
      Py_DECREF(dict);
    }
#endif
  }
  return inst;
#else
#if (PY_VERSION_HEX >= 0x02010000)
  PyObject *inst = 0;
  PyObject *dict = PyDict_New();
  if (dict) {
    PyDict_SetItem(dict, SWIG_This(), swig_this);
    inst = PyInstance_NewRaw(data->newargs, dict);
    Py_DECREF(dict);
  }
  return (PyObject *) inst;
#else
  PyInstanceObject *inst = PyObject_NEW(PyInstanceObject, &PyInstance_Type);
  if (inst == NULL) {
    return NULL;
  }
  inst->in_class = (PyClassObject *)data->newargs;
  Py_INCREF(inst->in_class);
  inst->in_dict = PyDict_New();
  if (inst->in_dict == NULL) {
    Py_DECREF(inst);
    return NULL;
  }
#ifdef Py_TPFLAGS_HAVE_WEAKREFS
  inst->in_weakreflist = NULL;
#endif
#ifdef Py_TPFLAGS_GC
  PyObject_GC_Init(inst);
#endif
  PyDict_SetItem(inst->in_dict, SWIG_This(), swig_this);
  return (PyObject *) inst;
#endif
#endif
}

SWIGRUNTIME void
SWIG_Python_SetSwigThis(PyObject *inst, PyObject *swig_this)
{
 PyObject *dict;
#if (PY_VERSION_HEX >= 0x02020000) && !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
 PyObject **dictptr = _PyObject_GetDictPtr(inst);
 if (dictptr != NULL) {
   dict = *dictptr;
   if (dict == NULL) {
     dict = PyDict_New();
     *dictptr = dict;
   }
   PyDict_SetItem(dict, SWIG_This(), swig_this);
   return;
 }
#endif
 dict = PyObject_GetAttrString(inst, (char*)"__dict__");
 PyDict_SetItem(dict, SWIG_This(), swig_this);
 Py_DECREF(dict);
} 


SWIGINTERN PyObject *
SWIG_Python_InitShadowInstance(PyObject *args) {
  PyObject *obj[2];
  if (!SWIG_Python_UnpackTuple(args, "swiginit", 2, 2, obj)) {
    return NULL;
  } else {
    SwigPyObject *sthis = SWIG_Python_GetSwigThis(obj[0]);
    if (sthis) {
      SwigPyObject_append((PyObject*) sthis, obj[1]);
    } else {
      SWIG_Python_SetSwigThis(obj[0], obj[1]);
    }
    return SWIG_Py_Void();
  }
}

/* Create a new pointer object */

SWIGRUNTIME PyObject *
SWIG_Python_NewPointerObj(PyObject *self, void *ptr, swig_type_info *type, int flags) {
  SwigPyClientData *clientdata;
  PyObject * robj;
  int own;

  if (!ptr)
    return SWIG_Py_Void();

  clientdata = type ? (SwigPyClientData *)(type->clientdata) : 0;
  own = (flags & SWIG_POINTER_OWN) ? SWIG_POINTER_OWN : 0;
  if (clientdata && clientdata->pytype) {
    SwigPyObject *newobj;
    if (flags & SWIG_BUILTIN_TP_INIT) {
      newobj = (SwigPyObject*) self;
      if (newobj->ptr) {
        PyObject *next_self = clientdata->pytype->tp_alloc(clientdata->pytype, 0);
        while (newobj->next)
	  newobj = (SwigPyObject *) newobj->next;
        newobj->next = next_self;
        newobj = (SwigPyObject *)next_self;
#ifdef SWIGPYTHON_BUILTIN
        newobj->dict = 0;
#endif
      }
    } else {
      newobj = PyObject_New(SwigPyObject, clientdata->pytype);
#ifdef SWIGPYTHON_BUILTIN
      newobj->dict = 0;
#endif
    }
    if (newobj) {
      newobj->ptr = ptr;
      newobj->ty = type;
      newobj->own = own;
      newobj->next = 0;
      return (PyObject*) newobj;
    }
    return SWIG_Py_Void();
  }

  assert(!(flags & SWIG_BUILTIN_TP_INIT));

  robj = SwigPyObject_New(ptr, type, own);
  if (robj && clientdata && !(flags & SWIG_POINTER_NOSHADOW)) {
    PyObject *inst = SWIG_Python_NewShadowInstance(clientdata, robj);
    Py_DECREF(robj);
    robj = inst;
  }
  return robj;
}

/* Create a new packed object */

SWIGRUNTIMEINLINE PyObject *
SWIG_Python_NewPackedObj(void *ptr, size_t sz, swig_type_info *type) {
  return ptr ? SwigPyPacked_New((void *) ptr, sz, type) : SWIG_Py_Void();
}

/* -----------------------------------------------------------------------------*
 *  Get type list 
 * -----------------------------------------------------------------------------*/

#ifdef SWIG_LINK_RUNTIME
void *SWIG_ReturnGlobalTypeList(void *);
#endif

SWIGRUNTIME swig_module_info *
SWIG_Python_GetModule(void *SWIGUNUSEDPARM(clientdata)) {
  static void *type_pointer = (void *)0;
  /* first check if module already created */
  if (!type_pointer) {
#ifdef SWIG_LINK_RUNTIME
    type_pointer = SWIG_ReturnGlobalTypeList((void *)0);
#else
# ifdef SWIGPY_USE_CAPSULE
    type_pointer = PyCapsule_Import(SWIGPY_CAPSULE_NAME, 0);
# else
    type_pointer = PyCObject_Import((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION,
				    (char*)"type_pointer" SWIG_TYPE_TABLE_NAME);
# endif
    if (PyErr_Occurred()) {
      PyErr_Clear();
      type_pointer = (void *)0;
    }
#endif
  }
  return (swig_module_info *) type_pointer;
}

#if PY_MAJOR_VERSION < 2
/* PyModule_AddObject function was introduced in Python 2.0.  The following function
   is copied out of Python/modsupport.c in python version 2.3.4 */
SWIGINTERN int
PyModule_AddObject(PyObject *m, char *name, PyObject *o)
{
  PyObject *dict;
  if (!PyModule_Check(m)) {
    PyErr_SetString(PyExc_TypeError, "PyModule_AddObject() needs module as first arg");
    return SWIG_ERROR;
  }
  if (!o) {
    PyErr_SetString(PyExc_TypeError, "PyModule_AddObject() needs non-NULL value");
    return SWIG_ERROR;
  }
  
  dict = PyModule_GetDict(m);
  if (dict == NULL) {
    /* Internal error -- modules must have a dict! */
    PyErr_Format(PyExc_SystemError, "module '%s' has no __dict__",
		 PyModule_GetName(m));
    return SWIG_ERROR;
  }
  if (PyDict_SetItemString(dict, name, o))
    return SWIG_ERROR;
  Py_DECREF(o);
  return SWIG_OK;
}
#endif

SWIGRUNTIME void
#ifdef SWIGPY_USE_CAPSULE
SWIG_Python_DestroyModule(PyObject *obj)
#else
SWIG_Python_DestroyModule(void *vptr)
#endif
{
#ifdef SWIGPY_USE_CAPSULE
  swig_module_info *swig_module = (swig_module_info *) PyCapsule_GetPointer(obj, SWIGPY_CAPSULE_NAME);
#else
  swig_module_info *swig_module = (swig_module_info *) vptr;
#endif
  swig_type_info **types = swig_module->types;
  size_t i;
  for (i =0; i < swig_module->size; ++i) {
    swig_type_info *ty = types[i];
    if (ty->owndata) {
      SwigPyClientData *data = (SwigPyClientData *) ty->clientdata;
      if (data) SwigPyClientData_Del(data);
    }
  }
  Py_DECREF(SWIG_This());
  swig_this = NULL;
}

SWIGRUNTIME void
SWIG_Python_SetModule(swig_module_info *swig_module) {
#if PY_VERSION_HEX >= 0x03000000
 /* Add a dummy module object into sys.modules */
  PyObject *module = PyImport_AddModule((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION);
#else
  static PyMethodDef swig_empty_runtime_method_table[] = { {NULL, NULL, 0, NULL} }; /* Sentinel */
  PyObject *module = Py_InitModule((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION, swig_empty_runtime_method_table);
#endif
#ifdef SWIGPY_USE_CAPSULE
  PyObject *pointer = PyCapsule_New((void *) swig_module, SWIGPY_CAPSULE_NAME, SWIG_Python_DestroyModule);
  if (pointer && module) {
    PyModule_AddObject(module, (char*)"type_pointer_capsule" SWIG_TYPE_TABLE_NAME, pointer);
  } else {
    Py_XDECREF(pointer);
  }
#else
  PyObject *pointer = PyCObject_FromVoidPtr((void *) swig_module, SWIG_Python_DestroyModule);
  if (pointer && module) {
    PyModule_AddObject(module, (char*)"type_pointer" SWIG_TYPE_TABLE_NAME, pointer);
  } else {
    Py_XDECREF(pointer);
  }
#endif
}

/* The python cached type query */
SWIGRUNTIME PyObject *
SWIG_Python_TypeCache(void) {
  static PyObject *SWIG_STATIC_POINTER(cache) = PyDict_New();
  return cache;
}

SWIGRUNTIME swig_type_info *
SWIG_Python_TypeQuery(const char *type)
{
  PyObject *cache = SWIG_Python_TypeCache();
  PyObject *key = SWIG_Python_str_FromChar(type); 
  PyObject *obj = PyDict_GetItem(cache, key);
  swig_type_info *descriptor;
  if (obj) {
#ifdef SWIGPY_USE_CAPSULE
    descriptor = (swig_type_info *) PyCapsule_GetPointer(obj, NULL);
#else
    descriptor = (swig_type_info *) PyCObject_AsVoidPtr(obj);
#endif
  } else {
    swig_module_info *swig_module = SWIG_GetModule(0);
    descriptor = SWIG_TypeQueryModule(swig_module, swig_module, type);
    if (descriptor) {
#ifdef SWIGPY_USE_CAPSULE
      obj = PyCapsule_New((void*) descriptor, NULL, NULL);
#else
      obj = PyCObject_FromVoidPtr(descriptor, NULL);
#endif
      PyDict_SetItem(cache, key, obj);
      Py_DECREF(obj);
    }
  }
  Py_DECREF(key);
  return descriptor;
}

/* 
   For backward compatibility only
*/
#define SWIG_POINTER_EXCEPTION  0
#define SWIG_arg_fail(arg)      SWIG_Python_ArgFail(arg)
#define SWIG_MustGetPtr(p, type, argnum, flags)  SWIG_Python_MustGetPtr(p, type, argnum, flags)

SWIGRUNTIME int
SWIG_Python_AddErrMesg(const char* mesg, int infront)
{  
  if (PyErr_Occurred()) {
    PyObject *type = 0;
    PyObject *value = 0;
    PyObject *traceback = 0;
    PyErr_Fetch(&type, &value, &traceback);
    if (value) {
      char *tmp;
      PyObject *old_str = PyObject_Str(value);
      Py_XINCREF(type);
      PyErr_Clear();
      if (infront) {
	PyErr_Format(type, "%s %s", mesg, tmp = SWIG_Python_str_AsChar(old_str));
      } else {
	PyErr_Format(type, "%s %s", tmp = SWIG_Python_str_AsChar(old_str), mesg);
      }
      SWIG_Python_str_DelForPy3(tmp);
      Py_DECREF(old_str);
    }
    return 1;
  } else {
    return 0;
  }
}
  
SWIGRUNTIME int
SWIG_Python_ArgFail(int argnum)
{
  if (PyErr_Occurred()) {
    /* add information about failing argument */
    char mesg[256];
    PyOS_snprintf(mesg, sizeof(mesg), "argument number %d:", argnum);
    return SWIG_Python_AddErrMesg(mesg, 1);
  } else {
    return 0;
  }
}

SWIGRUNTIMEINLINE const char *
SwigPyObject_GetDesc(PyObject *self)
{
  SwigPyObject *v = (SwigPyObject *)self;
  swig_type_info *ty = v ? v->ty : 0;
  return ty ? ty->str : "";
}

SWIGRUNTIME void
SWIG_Python_TypeError(const char *type, PyObject *obj)
{
  if (type) {
#if defined(SWIG_COBJECT_TYPES)
    if (obj && SwigPyObject_Check(obj)) {
      const char *otype = (const char *) SwigPyObject_GetDesc(obj);
      if (otype) {
	PyErr_Format(PyExc_TypeError, "a '%s' is expected, 'SwigPyObject(%s)' is received",
		     type, otype);
	return;
      }
    } else 
#endif      
    {
      const char *otype = (obj ? obj->ob_type->tp_name : 0); 
      if (otype) {
	PyObject *str = PyObject_Str(obj);
	const char *cstr = str ? SWIG_Python_str_AsChar(str) : 0;
	if (cstr) {
	  PyErr_Format(PyExc_TypeError, "a '%s' is expected, '%s(%s)' is received",
		       type, otype, cstr);
          SWIG_Python_str_DelForPy3(cstr);
	} else {
	  PyErr_Format(PyExc_TypeError, "a '%s' is expected, '%s' is received",
		       type, otype);
	}
	Py_XDECREF(str);
	return;
      }
    }   
    PyErr_Format(PyExc_TypeError, "a '%s' is expected", type);
  } else {
    PyErr_Format(PyExc_TypeError, "unexpected type is received");
  }
}


/* Convert a pointer value, signal an exception on a type mismatch */
SWIGRUNTIME void *
SWIG_Python_MustGetPtr(PyObject *obj, swig_type_info *ty, int SWIGUNUSEDPARM(argnum), int flags) {
  void *result;
  if (SWIG_Python_ConvertPtr(obj, &result, ty, flags) == -1) {
    PyErr_Clear();
#if SWIG_POINTER_EXCEPTION
    if (flags) {
      SWIG_Python_TypeError(SWIG_TypePrettyName(ty), obj);
      SWIG_Python_ArgFail(argnum);
    }
#endif
  }
  return result;
}

#ifdef SWIGPYTHON_BUILTIN
SWIGRUNTIME int
SWIG_Python_NonDynamicSetAttr(PyObject *obj, PyObject *name, PyObject *value) {
  PyTypeObject *tp = obj->ob_type;
  PyObject *descr;
  PyObject *encoded_name;
  descrsetfunc f;
  int res = -1;

# ifdef Py_USING_UNICODE
  if (PyString_Check(name)) {
    name = PyUnicode_Decode(PyString_AsString(name), PyString_Size(name), NULL, NULL);
    if (!name)
      return -1;
  } else if (!PyUnicode_Check(name))
# else
  if (!PyString_Check(name))
# endif
  {
    PyErr_Format(PyExc_TypeError, "attribute name must be string, not '%.200s'", name->ob_type->tp_name);
    return -1;
  } else {
    Py_INCREF(name);
  }

  if (!tp->tp_dict) {
    if (PyType_Ready(tp) < 0)
      goto done;
  }

  descr = _PyType_Lookup(tp, name);
  f = NULL;
  if (descr != NULL)
    f = descr->ob_type->tp_descr_set;
  if (!f) {
    if (PyString_Check(name)) {
      encoded_name = name;
      Py_INCREF(name);
    } else {
      encoded_name = PyUnicode_AsUTF8String(name);
    }
    PyErr_Format(PyExc_AttributeError, "'%.100s' object has no attribute '%.200s'", tp->tp_name, PyString_AsString(encoded_name));
    Py_DECREF(encoded_name);
  } else {
    res = f(descr, obj, value);
  }
  
  done:
  Py_DECREF(name);
  return res;
}
#endif


#ifdef __cplusplus
}
#endif



#define SWIG_exception_fail(code, msg) do { SWIG_Error(code, msg); SWIG_fail; } while(0) 

#define SWIG_contract_assert(expr, msg) if (!(expr)) { SWIG_Error(SWIG_RuntimeError, msg); SWIG_fail; } else 



  #define SWIG_exception(code, msg) do { SWIG_Error(code, msg); SWIG_fail;; } while(0) 


/* -------- TYPES TABLE (BEGIN) -------- */

#define SWIGTYPE_p_All_cells_iterator swig_types[0]
#define SWIGTYPE_p_All_edges_iterator swig_types[1]
#define SWIGTYPE_p_All_facets_iterator swig_types[2]
#define SWIGTYPE_p_All_vertices_iterator swig_types[3]
#define SWIGTYPE_p_Base swig_types[4]
#define SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t swig_types[5]
#define SWIGTYPE_p_Cell_circulator swig_types[6]
#define SWIGTYPE_p_Cell_handle swig_types[7]
#define SWIGTYPE_p_Cell_handle_output_iterator swig_types[8]
#define SWIGTYPE_p_Cell_iterator swig_types[9]
#define SWIGTYPE_p_Edge swig_types[10]
#define SWIGTYPE_p_Edge_iterator swig_types[11]
#define SWIGTYPE_p_Edge_output_iterator swig_types[12]
#define SWIGTYPE_p_Facet swig_types[13]
#define SWIGTYPE_p_Facet_circulator swig_types[14]
#define SWIGTYPE_p_Facet_iterator swig_types[15]
#define SWIGTYPE_p_Facet_output_iterator swig_types[16]
#define SWIGTYPE_p_Finite_cells_iterator swig_types[17]
#define SWIGTYPE_p_Finite_edges_iterator swig_types[18]
#define SWIGTYPE_p_Finite_facets_iterator swig_types[19]
#define SWIGTYPE_p_Finite_vertices_iterator swig_types[20]
#define SWIGTYPE_p_General_modifierT_Polyhedron_3___HalfedgeDS_t swig_types[21]
#define SWIGTYPE_p_Halfedge_around_facet_circulator swig_types[22]
#define SWIGTYPE_p_Halfedge_around_vertex_circulator swig_types[23]
#define SWIGTYPE_p_Halfedge_iterator swig_types[24]
#define SWIGTYPE_p_Line_2 swig_types[25]
#define SWIGTYPE_p_Line_3 swig_types[26]
#define SWIGTYPE_p_Mesh_3_parameters swig_types[27]
#define SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t swig_types[28]
#define SWIGTYPE_p_Object swig_types[29]
#define SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t swig_types[30]
#define SWIGTYPE_p_Plane_3 swig_types[31]
#define SWIGTYPE_p_Point_2 swig_types[32]
#define SWIGTYPE_p_Point_3 swig_types[33]
#define SWIGTYPE_p_Point_iterator swig_types[34]
#define SWIGTYPE_p_Point_range swig_types[35]
#define SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t swig_types[36]
#define SWIGTYPE_p_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t swig_types[37]
#define SWIGTYPE_p_Ray_2 swig_types[38]
#define SWIGTYPE_p_Ray_3 swig_types[39]
#define SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t swig_types[40]
#define SWIGTYPE_p_Reference_wrapperT_int_t swig_types[41]
#define SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t swig_types[42]
#define SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t swig_types[43]
#define SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t swig_types[44]
#define SWIGTYPE_p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_facet_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t swig_types[45]
#define SWIGTYPE_p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_vertex_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t swig_types[46]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t swig_types[47]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t swig_types[48]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t swig_types[49]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t swig_types[50]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t swig_types[51]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t swig_types[52]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t swig_types[53]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t swig_types[54]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t swig_types[55]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t swig_types[56]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t swig_types[57]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_Polyhedron_3___Edge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t swig_types[58]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_Polyhedron_3___Facet_iterator_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t swig_types[59]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_Polyhedron_3___Halfedge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t swig_types[60]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_Polyhedron_3___Point_iterator_Point_3_t swig_types[61]
#define SWIGTYPE_p_SWIG_CGAL_IteratorT_Polyhedron_3___Vertex_iterator_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_t swig_types[62]
#define SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t swig_types[63]
#define SWIGTYPE_p_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t swig_types[64]
#define SWIGTYPE_p_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t swig_types[65]
#define SWIGTYPE_p_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t swig_types[66]
#define SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t swig_types[67]
#define SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t swig_types[68]
#define SWIGTYPE_p_Segment_2 swig_types[69]
#define SWIGTYPE_p_Segment_3 swig_types[70]
#define SWIGTYPE_p_Self swig_types[71]
#define SWIGTYPE_p_Tetrahedron_3 swig_types[72]
#define SWIGTYPE_p_Triangle_2 swig_types[73]
#define SWIGTYPE_p_Triangle_3 swig_types[74]
#define SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t swig_types[75]
#define SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t swig_types[76]
#define SWIGTYPE_p_Vertex_handle swig_types[77]
#define SWIGTYPE_p_Vertex_handle_output_iterator swig_types[78]
#define SWIGTYPE_p_Vertex_iterator swig_types[79]
#define SWIGTYPE_p_Weighted_point_3 swig_types[80]
#define SWIGTYPE_p_char swig_types[81]
#define SWIGTYPE_p_cpp_base swig_types[82]
#define SWIGTYPE_p_first_type swig_types[83]
#define SWIGTYPE_p_second_type swig_types[84]
#define SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t swig_types[85]
#define SWIGTYPE_p_std__pairT_int_double_t swig_types[86]
#define SWIGTYPE_p_std__pairT_int_int_t swig_types[87]
#define SWIGTYPE_p_third_type swig_types[88]
static swig_type_info *swig_types[90];
static swig_module_info swig_module = {swig_types, 89, 0, 0, 0, 0};
#define SWIG_TypeQuery(name) SWIG_TypeQueryModule(&swig_module, &swig_module, name)
#define SWIG_MangledTypeQuery(name) SWIG_MangledTypeQueryModule(&swig_module, &swig_module, name)

/* -------- TYPES TABLE (END) -------- */

#if (PY_VERSION_HEX <= 0x02000000)
# if !defined(SWIG_PYTHON_CLASSIC)
#  error "This python version requires swig to be run with the '-classic' option"
# endif
#endif

/*-----------------------------------------------
              @(target):= _CGAL_Mesh_3.so
  ------------------------------------------------*/
#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_init    PyInit__CGAL_Mesh_3

#else
#  define SWIG_init    init_CGAL_Mesh_3

#endif
#define SWIG_name    "_CGAL_Mesh_3"

#define SWIGVERSION 0x030008 
#define SWIG_VERSION SWIGVERSION


#define SWIG_as_voidptr(a) const_cast< void * >(static_cast< const void * >(a)) 
#define SWIG_as_voidptrptr(a) ((void)SWIG_as_voidptr(*a),reinterpret_cast< void** >(a)) 


#include <stdexcept>


namespace swig {
  class SwigPtr_PyObject {
  protected:
    PyObject *_obj;

  public:
    SwigPtr_PyObject() :_obj(0)
    {
    }

    SwigPtr_PyObject(const SwigPtr_PyObject& item) : _obj(item._obj)
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XINCREF(_obj);      
      SWIG_PYTHON_THREAD_END_BLOCK;
    }
    
    SwigPtr_PyObject(PyObject *obj, bool initial_ref = true) :_obj(obj)
    {
      if (initial_ref) {
        SWIG_PYTHON_THREAD_BEGIN_BLOCK;
        Py_XINCREF(_obj);
        SWIG_PYTHON_THREAD_END_BLOCK;
      }
    }
    
    SwigPtr_PyObject & operator=(const SwigPtr_PyObject& item) 
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XINCREF(item._obj);
      Py_XDECREF(_obj);
      _obj = item._obj;
      SWIG_PYTHON_THREAD_END_BLOCK;
      return *this;      
    }
    
    ~SwigPtr_PyObject() 
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XDECREF(_obj);
      SWIG_PYTHON_THREAD_END_BLOCK;
    }
    
    operator PyObject *() const
    {
      return _obj;
    }

    PyObject *operator->() const
    {
      return _obj;
    }
  };
}


namespace swig {
  struct SwigVar_PyObject : SwigPtr_PyObject {
    SwigVar_PyObject(PyObject* obj = 0) : SwigPtr_PyObject(obj, false) { }
    
    SwigVar_PyObject & operator = (PyObject* obj)
    {
      Py_XDECREF(_obj);
      _obj = obj;
      return *this;      
    }
  };
}


#include <string>


#if !defined(SWIGPYTHON) && !defined(SWIGJAVA)
  #define SWIG_CGAL_NON_SUPPORTED_TARGET_LANGUAGE 1
#else
  #define SWIG_CGAL_NON_SUPPORTED_TARGET_LANGUAGE 0
#endif  


  #define SWIG_CGAL_NO_TRIANGULATION_STRING_OUTPUT //I/O are broken for C3T3 triangulation
  #include  <SWIG_CGAL/Kernel/typedefs.h>
  #include  <SWIG_CGAL/Mesh_3/Object.h>
  #include  <SWIG_CGAL/Triangulation_3/Regular_triangulation_3.h>
  #include  <SWIG_CGAL/Triangulation_3/Triangulation_3.h>
  #include  <SWIG_CGAL/Triangulation_3/triangulation_handles.h>
  #include  <SWIG_CGAL/Common/triple.h>
  #include  <SWIG_CGAL/Common/Variant.h>
  #include  <SWIG_CGAL/Common/Optional.h>
  #include  <SWIG_CGAL/Mesh_3/all_includes.h>


SWIGINTERNINLINE PyObject*
  SWIG_From_int  (int value)
{
  return PyInt_FromLong((long) value);
}


SWIGINTERN int
SWIG_AsVal_double (PyObject *obj, double *val)
{
  int res = SWIG_TypeError;
  if (PyFloat_Check(obj)) {
    if (val) *val = PyFloat_AsDouble(obj);
    return SWIG_OK;
#if PY_VERSION_HEX < 0x03000000
  } else if (PyInt_Check(obj)) {
    if (val) *val = PyInt_AsLong(obj);
    return SWIG_OK;
#endif
  } else if (PyLong_Check(obj)) {
    double v = PyLong_AsDouble(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    double d = PyFloat_AsDouble(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = d;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      long v = PyLong_AsLong(obj);
      if (!PyErr_Occurred()) {
	if (val) *val = v;
	return SWIG_AddCast(SWIG_AddCast(SWIG_OK));
      } else {
	PyErr_Clear();
      }
    }
  }
#endif
  return res;
}


#include <limits.h>
#if !defined(SWIG_NO_LLONG_MAX)
# if !defined(LLONG_MAX) && defined(__GNUC__) && defined (__LONG_LONG_MAX__)
#   define LLONG_MAX __LONG_LONG_MAX__
#   define LLONG_MIN (-LLONG_MAX - 1LL)
#   define ULLONG_MAX (LLONG_MAX * 2ULL + 1ULL)
# endif
#endif


#include <float.h>


#include <math.h>


SWIGINTERNINLINE int
SWIG_CanCastAsInteger(double *d, double min, double max) {
  double x = *d;
  if ((min <= x && x <= max)) {
   double fx = floor(x);
   double cx = ceil(x);
   double rd =  ((x - fx) < 0.5) ? fx : cx; /* simple rint */
   if ((errno == EDOM) || (errno == ERANGE)) {
     errno = 0;
   } else {
     double summ, reps, diff;
     if (rd < x) {
       diff = x - rd;
     } else if (rd > x) {
       diff = rd - x;
     } else {
       return 1;
     }
     summ = rd + x;
     reps = diff/summ;
     if (reps < 8*DBL_EPSILON) {
       *d = rd;
       return 1;
     }
   }
  }
  return 0;
}


SWIGINTERN int
SWIG_AsVal_long (PyObject *obj, long* val)
{
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(obj)) {
    if (val) *val = PyInt_AsLong(obj);
    return SWIG_OK;
  } else
#endif
  if (PyLong_Check(obj)) {
    long v = PyLong_AsLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
      return SWIG_OverflowError;
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    long v = PyInt_AsLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      double d;
      int res = SWIG_AddCast(SWIG_AsVal_double (obj,&d));
      if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, LONG_MIN, LONG_MAX)) {
	if (val) *val = (long)(d);
	return res;
      }
    }
  }
#endif
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsVal_int (PyObject * obj, int *val)
{
  long v;
  int res = SWIG_AsVal_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v < INT_MIN || v > INT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = static_cast< int >(v);
    }
  }  
  return res;
}


#include <stdexcept>


#if defined(__GNUC__)
#  if __GNUC__ == 2 && __GNUC_MINOR <= 96
#     define SWIG_STD_NOMODERN_STL
#  endif
#endif


#include <stddef.h>


#include <utility>

 typedef std::pair<int,double>  Mesh_3_Quality_SWIG_wrapper; 

namespace swig {
  template <class Type>
  struct noconst_traits {
    typedef Type noconst_type;
  };

  template <class Type>
  struct noconst_traits<const Type> {
    typedef Type noconst_type;
  };

  /*
    type categories
  */
  struct pointer_category { };
  struct value_category { };

  /*
    General traits that provides type_name and type_info
  */
  template <class Type> struct traits { };

  template <class Type>
  inline const char* type_name() {
    return traits<typename noconst_traits<Type >::noconst_type >::type_name();
  }

  template <class Type>
  struct traits_info {
    static swig_type_info *type_query(std::string name) {
      name += " *";
      return SWIG_TypeQuery(name.c_str());
    }
    static swig_type_info *type_info() {
      static swig_type_info *info = type_query(type_name<Type>());
      return info;
    }
  };

  template <class Type>
  inline swig_type_info *type_info() {
    return traits_info<Type>::type_info();
  }

  /*
    Partial specialization for pointers
  */
  template <class Type> struct traits <Type *> {
    typedef pointer_category category;
    static std::string make_ptr_name(const char* name) {
      std::string ptrname = name;
      ptrname += " *";
      return ptrname;
    }
    static const char* type_name() {
      static std::string name = make_ptr_name(swig::type_name<Type>());
      return name.c_str();
    }
  };

  template <class Type, class Category>
  struct traits_as { };

  template <class Type, class Category>
  struct traits_check { };

}


namespace swig {  
  /*
    Traits that provides the from method
  */
  template <class Type> struct traits_from_ptr {
    static PyObject *from(Type *val, int owner = 0) {
      return SWIG_InternalNewPointerObj(val, type_info<Type>(), owner);
    }
  };

  template <class Type> struct traits_from {
    static PyObject *from(const Type& val) {
      return traits_from_ptr<Type>::from(new Type(val), 1);
    }
  };

  template <class Type> struct traits_from<Type *> {
    static PyObject *from(Type* val) {
      return traits_from_ptr<Type>::from(val, 0);
    }
  };

  template <class Type> struct traits_from<const Type *> {
    static PyObject *from(const Type* val) {
      return traits_from_ptr<Type>::from(const_cast<Type*>(val), 0);
    }
  };


  template <class Type>
  inline PyObject *from(const Type& val) {
    return traits_from<Type>::from(val);
  }

  template <class Type>
  inline PyObject *from_ptr(Type* val, int owner) {
    return traits_from_ptr<Type>::from(val, owner);
  }

  /*
    Traits that provides the asval/as/check method
  */
  template <class Type>
  struct traits_asptr {   
    static int asptr(PyObject *obj, Type **val) {
      Type *p;
      int res = SWIG_ConvertPtr(obj, (void**)&p, type_info<Type>(), 0);
      if (SWIG_IsOK(res)) {
	if (val) *val = p;
      }
      return res;
    }
  }; 

  template <class Type>
  inline int asptr(PyObject *obj, Type **vptr) {
    return traits_asptr<Type>::asptr(obj, vptr);
  }

  template <class Type> 
  struct traits_asval {
    static int asval(PyObject *obj, Type *val) {
      if (val) {
	Type *p = 0;
	int res = traits_asptr<Type>::asptr(obj, &p);
	if (!SWIG_IsOK(res)) return res;	
	if (p) {
	  typedef typename noconst_traits<Type>::noconst_type noconst_type;
	  *(const_cast<noconst_type*>(val)) = *p;
	  if (SWIG_IsNewObj(res)){
	    delete p;
	    res = SWIG_DelNewMask(res);
	  }
	  return res;
	} else {
	  return SWIG_ERROR;
	}
      } else {
	return traits_asptr<Type>::asptr(obj, (Type **)(0));
      }
    }
  };

  template <class Type> struct traits_asval<Type*> {
    static int asval(PyObject *obj, Type **val) {
      if (val) {
        typedef typename noconst_traits<Type>::noconst_type noconst_type;
        noconst_type *p = 0;
        int res = traits_asptr<noconst_type>::asptr(obj,  &p);
        if (SWIG_IsOK(res)) {
          *(const_cast<noconst_type**>(val)) = p;
	}
	return res;
      } else {
	return traits_asptr<Type>::asptr(obj, (Type **)(0));
      }
    }
  };
  
  template <class Type>
  inline int asval(PyObject *obj, Type *val) {
    return traits_asval<Type>::asval(obj, val);
  }

  template <class Type> 
  struct traits_as<Type, value_category> {
    static Type as(PyObject *obj, bool throw_error) {
      Type v;
      int res = asval(obj, &v);
      if (!obj || !SWIG_IsOK(res)) {
	if (!PyErr_Occurred()) {
	  ::SWIG_Error(SWIG_TypeError,  swig::type_name<Type>());
	}
	if (throw_error) throw std::invalid_argument("bad type");
      }
      return v;
    }
  };

  template <class Type> 
  struct traits_as<Type, pointer_category> {
    static Type as(PyObject *obj, bool throw_error) {
      Type *v = 0;      
      int res = (obj ? traits_asptr<Type>::asptr(obj, &v) : SWIG_ERROR);
      if (SWIG_IsOK(res) && v) {
	if (SWIG_IsNewObj(res)) {
	  Type r(*v);
	  delete v;
	  return r;
	} else {
	  return *v;
	}
      } else {
	// Uninitialized return value, no Type() constructor required.
	static Type *v_def = (Type*) malloc(sizeof(Type));
	if (!PyErr_Occurred()) {
	  SWIG_Error(SWIG_TypeError,  swig::type_name<Type>());
	}
	if (throw_error) throw std::invalid_argument("bad type");
	memset(v_def,0,sizeof(Type));
	return *v_def;
      }
    }
  };

  template <class Type> 
  struct traits_as<Type*, pointer_category> {
    static Type* as(PyObject *obj, bool throw_error) {
      Type *v = 0;      
      int res = (obj ? traits_asptr<Type>::asptr(obj, &v) : SWIG_ERROR);
      if (SWIG_IsOK(res)) {
	return v;
      } else {
	if (!PyErr_Occurred()) {
	  SWIG_Error(SWIG_TypeError,  swig::type_name<Type>());
	}
	if (throw_error) throw std::invalid_argument("bad type");
	return 0;
      }
    }
  };
    
  template <class Type>
  inline Type as(PyObject *obj, bool te = false) {
    return traits_as<Type, typename traits<Type>::category>::as(obj, te);
  }

  template <class Type> 
  struct traits_check<Type, value_category> {
    static bool check(PyObject *obj) {
      int res = obj ? asval(obj, (Type *)(0)) : SWIG_ERROR;
      return SWIG_IsOK(res) ? true : false;
    }
  };

  template <class Type> 
  struct traits_check<Type, pointer_category> {
    static bool check(PyObject *obj) {
      int res = obj ? asptr(obj, (Type **)(0)) : SWIG_ERROR;
      return SWIG_IsOK(res) ? true : false;
    }
  };

  template <class Type>
  inline bool check(PyObject *obj) {
    return traits_check<Type, typename traits<Type>::category>::check(obj);
  }
}


namespace swig {
  template <> struct traits< int > {
    typedef value_category category;
    static const char* type_name() { return"int"; }
  };
  template <>  struct traits_asval< int > {
    typedef int value_type;
    static int asval(PyObject *obj, value_type *val) {
      return SWIG_AsVal_int (obj, val);
    }
  };
  template <>  struct traits_from< int > {
    typedef int value_type;
    static PyObject *from(const value_type& val) {
      return SWIG_From_int  (val);
    }
  };
}


  #define SWIG_From_double   PyFloat_FromDouble 


namespace swig {
  template <> struct traits< double > {
    typedef value_category category;
    static const char* type_name() { return"double"; }
  };
  template <>  struct traits_asval< double > {
    typedef double value_type;
    static int asval(PyObject *obj, value_type *val) {
      return SWIG_AsVal_double (obj, val);
    }
  };
  template <>  struct traits_from< double > {
    typedef double value_type;
    static PyObject *from(const value_type& val) {
      return SWIG_From_double  (val);
    }
  };
}


  namespace swig {

















































    template <class T, class U >
    struct traits_asptr<std::pair<T,U> >  {
      typedef std::pair<T,U> value_type;

      static int get_pair(PyObject* first, PyObject* second,
			  std::pair<T,U> **val) 
      {
	if (val) {
	  value_type *vp = (new std::pair<T,U>);
	  T *pfirst = &(vp->first);
	  int res1 = swig::asval((PyObject*)first, pfirst);
	  if (!SWIG_IsOK(res1)) return res1;
	  U *psecond = &(vp->second);
	  int res2 = swig::asval((PyObject*)second, psecond);
	  if (!SWIG_IsOK(res2)) return res2;
	  *val = vp;
	  return SWIG_AddNewMask(res1 > res2 ? res1 : res2);
	} else {
	  T *pfirst = 0;
	  int res1 = swig::asval((PyObject*)first, pfirst);
	  if (!SWIG_IsOK(res1)) return res1;
	  U *psecond = 0;
	  int res2 = swig::asval((PyObject*)second, psecond);
	  if (!SWIG_IsOK(res2)) return res2;
	  return res1 > res2 ? res1 : res2;
	}	
      }

      static int asptr(PyObject *obj, std::pair<T,U> **val) {
	int res = SWIG_ERROR;
	if (PyTuple_Check(obj)) {
	  if (PyTuple_GET_SIZE(obj) == 2) {
	    res = get_pair(PyTuple_GET_ITEM(obj,0),PyTuple_GET_ITEM(obj,1), val);
	  }
	} else if (PySequence_Check(obj)) {
	  if (PySequence_Size(obj) == 2) {
	    swig::SwigVar_PyObject first = PySequence_GetItem(obj,0);
	    swig::SwigVar_PyObject second = PySequence_GetItem(obj,1);
	    res = get_pair(first, second, val);
	  }
	} else {
	  value_type *p;
	  res = SWIG_ConvertPtr(obj,(void**)&p,swig::type_info<value_type>(),0);
	  if (SWIG_IsOK(res) && val)  *val = p;
	}
	return res;
      }
    };


    template <class T, class U >
    struct traits_from<std::pair<T,U> >   {
      static PyObject *from(const std::pair<T,U>& val) {
	PyObject* obj = PyTuple_New(2);
	PyTuple_SetItem(obj,0,swig::from(val.first));
	PyTuple_SetItem(obj,1,swig::from(val.second));
	return obj;
      }
    };
  }





































      namespace swig {
	template <>  struct traits<std::pair< int, double > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::pair<" "int" "," "double" " >";
	  }
	};
      }
    
 typedef Optional< std::pair<int,double> >  Mesh_3_Badness_SWIG_wrapper; 

SWIGINTERNINLINE PyObject*
  SWIG_From_bool  (bool value)
{
  return PyBool_FromLong(value ? 1 : 0);
}


  template < class T1, class T2 >
  std::ostream&
  operator<<(std::ostream &os,
             const std::pair<T1,T2>& p)
  {
    os << p.first << " " << p.second;
    return os;
  }               


  #include <SWIG_CGAL/Common/Reference_wrapper.h>

 typedef Reference_wrapper<SWIG_Triangulation_3::Locate_type>  Ref_Locate_type_3_SWIG_wrapper; 
 typedef SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>  Mesh_3_regular_triangulation_3_Cell_handle_SWIG_wrapper; 

SWIGINTERN int
SWIG_AsVal_bool (PyObject *obj, bool *val)
{
  int r;
  if (!PyBool_Check(obj))
    return SWIG_ERROR;
  r = PyObject_IsTrue(obj);
  if (r == -1)
    return SWIG_ERROR;
  if (val) *val = r ? true : false;
  return SWIG_OK;
}

SWIGINTERN int SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__subdomain_index(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *self){return self->get_data()->subdomain_index();}
SWIGINTERN void SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_subdomain_index(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *self,int i){self->get_data()->set_subdomain_index(i);}
SWIGINTERN bool SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__is_facet_on_surface(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *self,int i){return self->get_data()->is_facet_on_surface(i);}
SWIGINTERN void SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_facet_on_surface(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *self,int i,std::pair< int,int > p){self->get_data()->set_surface_index(i,p);}
SWIGINTERN bool SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__is_facet_visited(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *self,int i){return self->get_data()->is_facet_visited(i);}
SWIGINTERN void SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_facet_visited(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *self,int i){self->get_data()->set_facet_visited(i);}
SWIGINTERN Weighted_point_3 SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__get_facet_surface_center(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *self,int i){return Weighted_point_3(self->get_data()->get_facet_surface_center(i));}
SWIGINTERN void SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_facet_surface_center(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *self,int i,Weighted_point_3 const &p){return self->get_data()->set_facet_surface_center(i,p.get_data());}
 typedef SWIG_Triangulation_3::CGAL_Vertex_handle<MT_PMD,Weighted_point_3>  Mesh_3_regular_triangulation_3_Vertex_handle_SWIG_wrapper; 
SWIGINTERN int SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__in_dimension(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *self){return self->get_data()->in_dimension();}
SWIGINTERN void SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_dimension(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *self,int d){self->get_data()->set_dimension(d);}
SWIGINTERN Variant< int,std::pair< int,int > > SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__index(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *self){return self->get_data()->index();}
SWIGINTERN void SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_index(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *self,Variant< int,std::pair< int,int > > const &v){self->get_data()->set_index(v.get_data());}
SWIGINTERN double SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__meshing_info(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *self){return self->get_data()->meshing_info();}
SWIGINTERN void SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_meshing_info(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *self,double d){self->get_data()->set_meshing_info(d);}
 typedef std::pair<SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,int>  Mesh_3_regular_triangulation_3_Facet_SWIG_wrapper; 

  namespace swig {
    template <>  struct traits< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > {
      typedef pointer_category category;
      static const char* type_name() { return"SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >, int > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::pair<" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >" "," "int" " >";
	  }
	};
      }
    
 typedef SWIG_CGAL::Triple<SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,int,int>  Mesh_3_regular_triangulation_3_Edge_SWIG_wrapper; 

  typedef SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>                              Mesh_3_regular_triangulation_3_Cell_handle;
  typedef SWIG_Triangulation_3::CGAL_Vertex_handle<MT_PMD,Weighted_point_3>                            Mesh_3_regular_triangulation_3_Vertex_handle;
  typedef std::pair<SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,int>               Mesh_3_regular_triangulation_3_Facet;
  typedef SWIG_CGAL::Triple<SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,int,int>   Mesh_3_regular_triangulation_3_Edge;  
  
 typedef Triangulation_3_wrapper<MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle<MT_PMD,Weighted_point_3>,SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,CGAL::Tag_true,boost::shared_ptr<C3T3_PMD> >  Internal_Triangulation_3_Mesh_3_regular_triangulation_3_SWIG_wrapper; 
 typedef SWIG_CGAL_Iterator<MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle<MT_PMD,Weighted_point_3> >  Mesh_3_regular_triangulation_3_All_vertices_iterator_SWIG_wrapper; 
 typedef SWIG_CGAL_Iterator<MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle<MT_PMD,Weighted_point_3> >  Mesh_3_regular_triangulation_3_Finite_vertices_iterator_SWIG_wrapper; 
 typedef SWIG_CGAL_Iterator<MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3> >  Mesh_3_regular_triangulation_3_All_cells_iterator_SWIG_wrapper; 
 typedef SWIG_CGAL_Iterator<MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3> >  Mesh_3_regular_triangulation_3_Finite_cells_iterator_SWIG_wrapper; 
 typedef SWIG_CGAL_Iterator<MT_PMD::All_facets_iterator,std::pair<SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,int> >  Mesh_3_regular_triangulation_3_All_facets_iterator_SWIG_wrapper; 
 typedef SWIG_CGAL_Iterator<MT_PMD::Finite_facets_iterator,std::pair<SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,int> >  Mesh_3_regular_triangulation_3_Finite_facets_iterator_SWIG_wrapper; 
 typedef SWIG_CGAL_Iterator<MT_PMD::All_edges_iterator,SWIG_CGAL::Triple<SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,int,int> >  Mesh_3_regular_triangulation_3_All_edges_iterator_SWIG_wrapper; 
 typedef SWIG_CGAL_Iterator<MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple<SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,int,int> >  Mesh_3_regular_triangulation_3_Finite_edges_iterator_SWIG_wrapper; 
 typedef SWIG_CGAL_Iterator<MT_PMD::Point_iterator,Weighted_point_3>  Mesh_3_regular_triangulation_3_Point_iterator_SWIG_wrapper; 
 typedef SWIG_CGAL_Circulator<MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3> >  Mesh_3_regular_triangulation_3_Cell_circulator_SWIG_wrapper; 
 typedef SWIG_CGAL_Circulator<MT_PMD::Facet_circulator,std::pair<SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,int> >  Mesh_3_regular_triangulation_3_Facet_circulator_SWIG_wrapper; 
 typedef Regular_triangulation_3_wrapper<MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle<MT_PMD,Weighted_point_3>,SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,boost::shared_ptr<C3T3_PMD> >  Mesh_3_regular_triangulation_3_SWIG_wrapper; 
 typedef SWIG_CGAL_Iterator<C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3> >  Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_SWIG_wrapper; 
 typedef SWIG_CGAL_Iterator<C3T3_PMD::Facet_iterator,std::pair<SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,int> >  Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_SWIG_wrapper; 
 typedef std::pair<int,int>  Mesh_3_Surface_index_SWIG_wrapper; 

      namespace swig {
	template <>  struct traits<std::pair< int, int > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::pair<" "int" "," "int" " >";
	  }
	};
      }
    
 typedef Variant<int,std::pair<int,int> >  Mesh_3_Index_SWIG_wrapper; 
 typedef C3T3_wrapper<  C3T3_PMD,Regular_triangulation_3_wrapper<MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle<MT_PMD,Weighted_point_3>,SWIG_Triangulation_3::CGAL_Cell_handle<MT_PMD,Weighted_point_3>,boost::shared_ptr<C3T3_PMD> >,Variant< int,std::pair<int,int> >,std::pair<int,int>,int >  Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper; 

SWIGINTERN swig_type_info*
SWIG_pchar_descriptor(void)
{
  static int init = 0;
  static swig_type_info* info = 0;
  if (!init) {
    info = SWIG_TypeQuery("_p_char");
    init = 1;
  }
  return info;
}


SWIGINTERN int
SWIG_AsCharPtrAndSize(PyObject *obj, char** cptr, size_t* psize, int *alloc)
{
#if PY_VERSION_HEX>=0x03000000
  if (PyUnicode_Check(obj))
#else  
  if (PyString_Check(obj))
#endif
  {
    char *cstr; Py_ssize_t len;
#if PY_VERSION_HEX>=0x03000000
    if (!alloc && cptr) {
        /* We can't allow converting without allocation, since the internal
           representation of string in Python 3 is UCS-2/UCS-4 but we require
           a UTF-8 representation.
           TODO(bhy) More detailed explanation */
        return SWIG_RuntimeError;
    }
    obj = PyUnicode_AsUTF8String(obj);
    PyBytes_AsStringAndSize(obj, &cstr, &len);
    if(alloc) *alloc = SWIG_NEWOBJ;
#else
    PyString_AsStringAndSize(obj, &cstr, &len);
#endif
    if (cptr) {
      if (alloc) {
	/* 
	   In python the user should not be able to modify the inner
	   string representation. To warranty that, if you define
	   SWIG_PYTHON_SAFE_CSTRINGS, a new/copy of the python string
	   buffer is always returned.

	   The default behavior is just to return the pointer value,
	   so, be careful.
	*/ 
#if defined(SWIG_PYTHON_SAFE_CSTRINGS)
	if (*alloc != SWIG_OLDOBJ) 
#else
	if (*alloc == SWIG_NEWOBJ) 
#endif
	{
	  *cptr = reinterpret_cast< char* >(memcpy((new char[len + 1]), cstr, sizeof(char)*(len + 1)));
	  *alloc = SWIG_NEWOBJ;
	} else {
	  *cptr = cstr;
	  *alloc = SWIG_OLDOBJ;
	}
      } else {
	#if PY_VERSION_HEX>=0x03000000
	assert(0); /* Should never reach here in Python 3 */
	#endif
	*cptr = SWIG_Python_str_AsChar(obj);
      }
    }
    if (psize) *psize = len + 1;
#if PY_VERSION_HEX>=0x03000000
    Py_XDECREF(obj);
#endif
    return SWIG_OK;
  } else {
#if defined(SWIG_PYTHON_2_UNICODE)
#if PY_VERSION_HEX<0x03000000
    if (PyUnicode_Check(obj)) {
      char *cstr; Py_ssize_t len;
      if (!alloc && cptr) {
        return SWIG_RuntimeError;
      }
      obj = PyUnicode_AsUTF8String(obj);
      if (PyString_AsStringAndSize(obj, &cstr, &len) != -1) {
        if (cptr) {
          if (alloc) *alloc = SWIG_NEWOBJ;
          *cptr = reinterpret_cast< char* >(memcpy((new char[len + 1]), cstr, sizeof(char)*(len + 1)));
        }
        if (psize) *psize = len + 1;

        Py_XDECREF(obj);
        return SWIG_OK;
      } else {
        Py_XDECREF(obj);
      }
    }
#endif
#endif

    swig_type_info* pchar_descriptor = SWIG_pchar_descriptor();
    if (pchar_descriptor) {
      void* vptr = 0;
      if (SWIG_ConvertPtr(obj, &vptr, pchar_descriptor, 0) == SWIG_OK) {
	if (cptr) *cptr = (char *) vptr;
	if (psize) *psize = vptr ? (strlen((char *)vptr) + 1) : 0;
	if (alloc) *alloc = SWIG_OLDOBJ;
	return SWIG_OK;
      }
    }
  }
  return SWIG_TypeError;
}




typedef Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle<Polyhedron_3_>,SWIG_Polyhedron_3::CGAL_Halfedge_handle<Polyhedron_3_>,SWIG_Polyhedron_3::CGAL_Facet_handle<Polyhedron_3_> >  Polyhedron_3_SWIG_wrapper; 
 typedef Polyhedral_mesh_domain_3_wrapper<PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair<int,int> >,std::pair<int,int>,int >  Polyhedral_mesh_domain_3_SWIG_wrapper; 
 typedef Mesh_criteria_with_fields_wrapper<DMC,double,double,double,double>  Default_mesh_criteria_SWIG_wrapper; 

  Mesh_optimization_return_code  exude_mesh_3( Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper& c3t3, double time_limit, double sliver_bound)
  {
    return CGAL::enum_cast< Mesh_optimization_return_code >( CGAL::exude_mesh_3(c3t3.get_data(),time_limit,sliver_bound) );
  }


  Mesh_optimization_return_code perturb_mesh_3 (  Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper& c3t3,const Polyhedral_mesh_domain_3_SWIG_wrapper& domain,double time_limit,double sliver_bound)
  {
    return CGAL::enum_cast< Mesh_optimization_return_code >( CGAL::perturb_mesh_3(c3t3.get_data(),domain.get_data(),time_limit,sliver_bound) );
  } 
    
  Mesh_optimization_return_code lloyd_optimize_mesh_3 ( Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper& c3t3,const Polyhedral_mesh_domain_3_SWIG_wrapper& domain,double time_limit,int max_iteration_number,double convergence,double freeze_bound)
  {
    return CGAL::enum_cast< Mesh_optimization_return_code >( CGAL::lloyd_optimize_mesh_3(c3t3.get_data(),domain.get_data(),time_limit,max_iteration_number,convergence,freeze_bound) );
  }

  Mesh_optimization_return_code odt_optimize_mesh_3 (Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper& c3t3,const Polyhedral_mesh_domain_3_SWIG_wrapper& domain,double time_limit,std::size_t max_iteration_number,double convergence,double freeze_bound)
  {
    return CGAL::enum_cast< Mesh_optimization_return_code >( CGAL::odt_optimize_mesh_3(c3t3.get_data(),domain.get_data(),time_limit,max_iteration_number,convergence,freeze_bound) );
  }  


SWIGINTERN int
SWIG_AsVal_unsigned_SS_long (PyObject *obj, unsigned long *val) 
{
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(obj)) {
    long v = PyInt_AsLong(obj);
    if (v >= 0) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      return SWIG_OverflowError;
    }
  } else
#endif
  if (PyLong_Check(obj)) {
    unsigned long v = PyLong_AsUnsignedLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
      return SWIG_OverflowError;
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    unsigned long v = PyLong_AsUnsignedLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      double d;
      int res = SWIG_AddCast(SWIG_AsVal_double (obj,&d));
      if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, 0, ULONG_MAX)) {
	if (val) *val = (unsigned long)(d);
	return res;
      }
    }
  }
#endif
  return SWIG_TypeError;
}


SWIGINTERNINLINE int
SWIG_AsVal_size_t (PyObject * obj, size_t *val)
{
  unsigned long v;
  int res = SWIG_AsVal_unsigned_SS_long (obj, val ? &v : 0);
  if (SWIG_IsOK(res) && val) *val = static_cast< size_t >(v);
  return res;
}


  Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper make_mesh_3(const Polyhedral_mesh_domain_3_SWIG_wrapper& domain, const Default_mesh_criteria_SWIG_wrapper& criteria,const Mesh_3_parameters& parameters)
  {
    return Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper( CGAL::make_mesh_3<Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper::cpp_base>( domain.get_data(),criteria.get_data(),
                                                                        parameters.get_lloyd_parameters(),
                                                                        parameters.get_odt_parameters(),
                                                                        parameters.get_perturb_parameters(),
                                                                        parameters.get_exude_parameters()
    ));
  }

  void  refine_mesh_3 ( Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper& c3t3, const Polyhedral_mesh_domain_3_SWIG_wrapper& domain,const Default_mesh_criteria_SWIG_wrapper& criteria,const Mesh_3_parameters& parameters)
  {
    CGAL::refine_mesh_3(c3t3.get_data(),domain.get_data(),criteria.get_data(),
                        parameters.get_lloyd_parameters(),
                        parameters.get_odt_parameters(),
                        parameters.get_perturb_parameters(),
                        parameters.get_exude_parameters());
  }

#ifdef __cplusplus
extern "C" {
#endif
SWIGINTERN PyObject *VERTEX_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "VERTEX",SWIG_From_int(static_cast< int >(SWIG_Triangulation_3::VERTEX)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *EDGE_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "EDGE",SWIG_From_int(static_cast< int >(SWIG_Triangulation_3::EDGE)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *FACET_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "FACET",SWIG_From_int(static_cast< int >(SWIG_Triangulation_3::FACET)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *CELL_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "CELL",SWIG_From_int(static_cast< int >(SWIG_Triangulation_3::CELL)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *OUTSIDE_CONVEX_HULL_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "OUTSIDE_CONVEX_HULL",SWIG_From_int(static_cast< int >(SWIG_Triangulation_3::OUTSIDE_CONVEX_HULL)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *OUTSIDE_AFFINE_HULL_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "OUTSIDE_AFFINE_HULL",SWIG_From_int(static_cast< int >(SWIG_Triangulation_3::OUTSIDE_AFFINE_HULL)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *FACET_VERTICES_ON_SURFACE_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "FACET_VERTICES_ON_SURFACE",SWIG_From_int(static_cast< int >(FACET_VERTICES_ON_SURFACE)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *FACET_VERTICES_ON_SAME_SURFACE_PATCH_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "FACET_VERTICES_ON_SAME_SURFACE_PATCH",SWIG_From_int(static_cast< int >(FACET_VERTICES_ON_SAME_SURFACE_PATCH)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *FACET_VERTICES_ON_SAME_SURFACE_PATCH_WITH_ADJACENCY_CHECK_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "FACET_VERTICES_ON_SAME_SURFACE_PATCH_WITH_ADJACENCY_CHECK",SWIG_From_int(static_cast< int >(FACET_VERTICES_ON_SAME_SURFACE_PATCH_WITH_ADJACENCY_CHECK)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *BOUND_REACHED_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "BOUND_REACHED",SWIG_From_int(static_cast< int >(BOUND_REACHED)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *TIME_LIMIT_REACHED_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "TIME_LIMIT_REACHED",SWIG_From_int(static_cast< int >(TIME_LIMIT_REACHED)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *CANT_IMPROVE_ANYMORE_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "CANT_IMPROVE_ANYMORE",SWIG_From_int(static_cast< int >(CANT_IMPROVE_ANYMORE)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *CONVERGENCE_REACHED_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "CONVERGENCE_REACHED",SWIG_From_int(static_cast< int >(CONVERGENCE_REACHED)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *MAX_ITERATION_NUMBER_REACHED_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "MAX_ITERATION_NUMBER_REACHED",SWIG_From_int(static_cast< int >(MAX_ITERATION_NUMBER_REACHED)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_parameters(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_parameters *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_parameters")) SWIG_fail;
  {
    try {
      result = (Mesh_3_parameters *)new Mesh_3_parameters();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Mesh_3_parameters, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_parameters_set_lloyd(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_parameters *arg1 = (Mesh_3_parameters *) 0 ;
  double arg2 ;
  int arg3 ;
  double arg4 ;
  double arg5 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  double val4 ;
  int ecode4 = 0 ;
  double val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Mesh_3_parameters_set_lloyd",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_3_parameters, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_parameters_set_lloyd" "', argument " "1"" of type '" "Mesh_3_parameters *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_parameters * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_parameters_set_lloyd" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_parameters_set_lloyd" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Mesh_3_parameters_set_lloyd" "', argument " "4"" of type '" "double""'");
  } 
  arg4 = static_cast< double >(val4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Mesh_3_parameters_set_lloyd" "', argument " "5"" of type '" "double""'");
  } 
  arg5 = static_cast< double >(val5);
  {
    try {
      (arg1)->set_lloyd(arg2,arg3,arg4,arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_parameters_set_odt(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_parameters *arg1 = (Mesh_3_parameters *) 0 ;
  double arg2 ;
  int arg3 ;
  double arg4 ;
  double arg5 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  double val4 ;
  int ecode4 = 0 ;
  double val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Mesh_3_parameters_set_odt",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_3_parameters, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_parameters_set_odt" "', argument " "1"" of type '" "Mesh_3_parameters *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_parameters * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_parameters_set_odt" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_parameters_set_odt" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Mesh_3_parameters_set_odt" "', argument " "4"" of type '" "double""'");
  } 
  arg4 = static_cast< double >(val4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Mesh_3_parameters_set_odt" "', argument " "5"" of type '" "double""'");
  } 
  arg5 = static_cast< double >(val5);
  {
    try {
      (arg1)->set_odt(arg2,arg3,arg4,arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_parameters_set_perturb(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_parameters *arg1 = (Mesh_3_parameters *) 0 ;
  double arg2 ;
  double arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_parameters_set_perturb",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_3_parameters, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_parameters_set_perturb" "', argument " "1"" of type '" "Mesh_3_parameters *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_parameters * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_parameters_set_perturb" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_parameters_set_perturb" "', argument " "3"" of type '" "double""'");
  } 
  arg3 = static_cast< double >(val3);
  {
    try {
      (arg1)->set_perturb(arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_parameters_set_exude(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_parameters *arg1 = (Mesh_3_parameters *) 0 ;
  double arg2 ;
  double arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_parameters_set_exude",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_3_parameters, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_parameters_set_exude" "', argument " "1"" of type '" "Mesh_3_parameters *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_parameters * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_parameters_set_exude" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_parameters_set_exude" "', argument " "3"" of type '" "double""'");
  } 
  arg3 = static_cast< double >(val3);
  {
    try {
      (arg1)->set_exude(arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_parameters_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_parameters *arg1 = (Mesh_3_parameters *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Mesh_3_parameters::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_parameters_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_3_parameters, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_parameters_deepcopy" "', argument " "1"" of type '" "Mesh_3_parameters const *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_parameters * >(argp1);
  {
    try {
      result = ((Mesh_3_parameters const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Mesh_3_parameters::Self(static_cast< const Mesh_3_parameters::Self& >(result))), SWIGTYPE_p_Mesh_3_parameters, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_parameters_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_parameters *arg1 = (Mesh_3_parameters *) 0 ;
  Mesh_3_parameters::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_parameters_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_3_parameters, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_parameters_deepcopy" "', argument " "1"" of type '" "Mesh_3_parameters *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_parameters * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Mesh_3_parameters,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_parameters_deepcopy" "', argument " "2"" of type '" "Mesh_3_parameters::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_parameters_deepcopy" "', argument " "2"" of type '" "Mesh_3_parameters::Self const &""'"); 
  }
  arg2 = reinterpret_cast< Mesh_3_parameters::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((Mesh_3_parameters::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_parameters_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Mesh_3_parameters, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_parameters_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Mesh_3_parameters, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Mesh_3_parameters, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_parameters_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_parameters_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Mesh_3_parameters::deepcopy() const\n"
    "    Mesh_3_parameters::deepcopy(Mesh_3_parameters::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_parameters(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_parameters *arg1 = (Mesh_3_parameters *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_parameters",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_3_parameters, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_parameters" "', argument " "1"" of type '" "Mesh_3_parameters *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_parameters * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_parameters_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_Mesh_3_parameters, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_Quality__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_Quality")) SWIG_fail;
  {
    try {
      result = (std::pair< int,double > *)new std::pair< int,double >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__pairT_int_double_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_Quality__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  double arg2 ;
  int val1 ;
  int ecode1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  std::pair< int,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_Mesh_3_Quality",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Mesh_3_Quality" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = static_cast< int >(val1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_Mesh_3_Quality" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      result = (std::pair< int,double > *)new std::pair< int,double >(arg1,arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__pairT_int_double_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_Quality__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,double > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  std::pair< int,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_Mesh_3_Quality",&obj0)) SWIG_fail;
  {
    std::pair< int,double > *ptr = (std::pair< int,double > *)0;
    res1 = swig::asptr(obj0, &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_Mesh_3_Quality" "', argument " "1"" of type '" "std::pair< int,double > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Mesh_3_Quality" "', argument " "1"" of type '" "std::pair< int,double > const &""'"); 
    }
    arg1 = ptr;
  }
  {
    try {
      result = (std::pair< int,double > *)new std::pair< int,double >((std::pair< int,double > const &)*arg1);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__pairT_int_double_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_Quality(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_Mesh_3_Quality__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::pair< int,double >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_Mesh_3_Quality__SWIG_2(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_Mesh_3_Quality__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_Mesh_3_Quality'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::pair< int,double >::pair()\n"
    "    std::pair< int,double >::pair(int,double)\n"
    "    std::pair< int,double >::pair(std::pair< int,double > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Quality_first_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,double > *arg1 = (std::pair< int,double > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Quality_first_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_int_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Quality_first_set" "', argument " "1"" of type '" "std::pair< int,double > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< int,double > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_Quality_first_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->first = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Quality_first_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,double > *arg1 = (std::pair< int,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Quality_first_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_int_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Quality_first_get" "', argument " "1"" of type '" "std::pair< int,double > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< int,double > * >(argp1);
  result = (int) ((arg1)->first);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Quality_second_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,double > *arg1 = (std::pair< int,double > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Quality_second_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_int_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Quality_second_set" "', argument " "1"" of type '" "std::pair< int,double > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< int,double > * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_Quality_second_set" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  if (arg1) (arg1)->second = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Quality_second_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,double > *arg1 = (std::pair< int,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  double result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Quality_second_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_int_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Quality_second_get" "', argument " "1"" of type '" "std::pair< int,double > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< int,double > * >(argp1);
  result = (double) ((arg1)->second);
  resultobj = SWIG_From_double(static_cast< double >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_Quality(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,double > *arg1 = (std::pair< int,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_Quality",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_int_double_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_Quality" "', argument " "1"" of type '" "std::pair< int,double > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< int,double > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_Quality_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__pairT_int_double_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_Badness(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Optional< std::pair< int,double > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_Badness")) SWIG_fail;
  {
    try {
      result = (Optional< std::pair< int,double > > *)new Optional< std::pair< int,double > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Badness_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Optional< std::pair< int,double > > *arg1 = (Optional< std::pair< int,double > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Badness_empty",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Badness_empty" "', argument " "1"" of type '" "Optional< std::pair< int,double > > const *""'"); 
  }
  arg1 = reinterpret_cast< Optional< std::pair< int,double > > * >(argp1);
  {
    try {
      result = (bool)((Optional< std::pair< int,double > > const *)arg1)->empty();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Badness_value(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Optional< std::pair< int,double > > *arg1 = (Optional< std::pair< int,double > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  std::pair< int,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Badness_value",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Badness_value" "', argument " "1"" of type '" "Optional< std::pair< int,double > > const *""'"); 
  }
  arg1 = reinterpret_cast< Optional< std::pair< int,double > > * >(argp1);
  {
    try {
      result = (std::pair< int,double > *) &((Optional< std::pair< int,double > > const *)arg1)->value();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< int,double > >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Badness_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Optional< std::pair< int,double > > *arg1 = (Optional< std::pair< int,double > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Optional< std::pair< int,double > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Badness_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Badness_deepcopy" "', argument " "1"" of type '" "Optional< std::pair< int,double > > const *""'"); 
  }
  arg1 = reinterpret_cast< Optional< std::pair< int,double > > * >(argp1);
  {
    try {
      result = ((Optional< std::pair< int,double > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Optional< std::pair< int,double > >::Self(static_cast< const Optional< std::pair< int,double > >::Self& >(result))), SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Badness_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Optional< std::pair< int,double > > *arg1 = (Optional< std::pair< int,double > > *) 0 ;
  Optional< std::pair< int,double > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Badness_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Badness_deepcopy" "', argument " "1"" of type '" "Optional< std::pair< int,double > > *""'"); 
  }
  arg1 = reinterpret_cast< Optional< std::pair< int,double > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Badness_deepcopy" "', argument " "2"" of type '" "Optional< std::pair< int,double > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Badness_deepcopy" "', argument " "2"" of type '" "Optional< std::pair< int,double > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< Optional< std::pair< int,double > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((Optional< std::pair< int,double > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Badness_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_Badness_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Badness_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Badness_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Optional< std::pair< int,double > >::deepcopy() const\n"
    "    Optional< std::pair< int,double > >::deepcopy(Optional< std::pair< int,double > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_Badness(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Optional< std::pair< int,double > > *arg1 = (Optional< std::pair< int,double > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_Badness",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_Badness" "', argument " "1"" of type '" "Optional< std::pair< int,double > > *""'"); 
  }
  arg1 = reinterpret_cast< Optional< std::pair< int,double > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_Badness_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_OptionalT_std__pairT_int_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Object(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Object")) SWIG_fail;
  {
    try {
      result = (Object *)new Object();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Object, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_is_Point_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_is_Point_2",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_is_Point_2" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_Point_2();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_get_Point_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Point_2 result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_get_Point_2",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_get_Point_2" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (arg1)->get_Point_2();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Point_2(static_cast< const Point_2& >(result))), SWIGTYPE_p_Point_2, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_is_Point_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_is_Point_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_is_Point_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_Point_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_get_Point_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Point_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_get_Point_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_get_Point_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (arg1)->get_Point_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Point_3(static_cast< const Point_3& >(result))), SWIGTYPE_p_Point_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_is_Triangle_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_is_Triangle_2",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_is_Triangle_2" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_Triangle_2();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_get_Triangle_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangle_2 result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_get_Triangle_2",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_get_Triangle_2" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (arg1)->get_Triangle_2();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangle_2(static_cast< const Triangle_2& >(result))), SWIGTYPE_p_Triangle_2, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_is_Triangle_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_is_Triangle_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_is_Triangle_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_Triangle_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_get_Triangle_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangle_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_get_Triangle_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_get_Triangle_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (arg1)->get_Triangle_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangle_3(static_cast< const Triangle_3& >(result))), SWIGTYPE_p_Triangle_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_is_Segment_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_is_Segment_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_is_Segment_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_Segment_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_get_Segment_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Segment_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_get_Segment_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_get_Segment_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (arg1)->get_Segment_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Segment_3(static_cast< const Segment_3& >(result))), SWIGTYPE_p_Segment_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_is_Segment_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_is_Segment_2",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_is_Segment_2" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_Segment_2();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_get_Segment_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Segment_2 result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_get_Segment_2",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_get_Segment_2" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (arg1)->get_Segment_2();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Segment_2(static_cast< const Segment_2& >(result))), SWIGTYPE_p_Segment_2, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_is_Line_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_is_Line_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_is_Line_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_Line_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_get_Line_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Line_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_get_Line_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_get_Line_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (arg1)->get_Line_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Line_3(static_cast< const Line_3& >(result))), SWIGTYPE_p_Line_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_is_Line_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_is_Line_2",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_is_Line_2" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_Line_2();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_get_Line_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< Line_2 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_get_Line_2",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_get_Line_2" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (arg1)->get_Line_2();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Line_2(static_cast< const Line_2& >(result))), SWIGTYPE_p_Line_2, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_is_Plane_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_is_Plane_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_is_Plane_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_Plane_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_get_Plane_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Plane_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_get_Plane_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_get_Plane_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (arg1)->get_Plane_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Plane_3(static_cast< const Plane_3& >(result))), SWIGTYPE_p_Plane_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_is_Ray_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_is_Ray_2",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_is_Ray_2" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_Ray_2();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_get_Ray_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< Ray_2 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_get_Ray_2",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_get_Ray_2" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (arg1)->get_Ray_2();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Ray_2(static_cast< const Ray_2& >(result))), SWIGTYPE_p_Ray_2, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_is_Ray_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_is_Ray_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_is_Ray_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_Ray_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_get_Ray_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< Ray_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_get_Ray_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_get_Ray_3" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (arg1)->get_Ray_3();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Ray_3(static_cast< const Ray_3& >(result))), SWIGTYPE_p_Ray_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Object_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Object_empty",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Object_empty" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      result = (bool)(arg1)->empty();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Object(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Object *arg1 = (Object *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Object",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Object, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Object" "', argument " "1"" of type '" "Object *""'"); 
  }
  arg1 = reinterpret_cast< Object * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Object_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_Object, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Ref_Locate_type_3__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Ref_Locate_type_3")) SWIG_fail;
  {
    try {
      result = (Reference_wrapper< SWIG_Triangulation_3::Locate_type > *)new Reference_wrapper< SWIG_Triangulation_3::Locate_type >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Ref_Locate_type_3__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::Locate_type *arg1 = 0 ;
  int val1 ;
  int ecode1 ;
  SWIG_Triangulation_3::Locate_type temp1 ;
  PyObject * obj0 = 0 ;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_Ref_Locate_type_3",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int (obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Ref_Locate_type_3" "', argument " "1"" of type '" "SWIG_Triangulation_3::Locate_type const &""'");
  } else {
    temp1 = static_cast< SWIG_Triangulation_3::Locate_type >(val1);
    arg1 = &temp1;
  }
  {
    try {
      result = (Reference_wrapper< SWIG_Triangulation_3::Locate_type > *)new Reference_wrapper< SWIG_Triangulation_3::Locate_type >((SWIG_Triangulation_3::Locate_type const &)*arg1);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Ref_Locate_type_3(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[2] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_Ref_Locate_type_3__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_Ref_Locate_type_3__SWIG_1(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_Ref_Locate_type_3'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Reference_wrapper< SWIG_Triangulation_3::Locate_type >::Reference_wrapper()\n"
    "    Reference_wrapper< SWIG_Triangulation_3::Locate_type >::Reference_wrapper(SWIG_Triangulation_3::Locate_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Ref_Locate_type_3_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg1 = (Reference_wrapper< SWIG_Triangulation_3::Locate_type > *) 0 ;
  SWIG_Triangulation_3::Locate_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Ref_Locate_type_3_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Ref_Locate_type_3_set" "', argument " "1"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > *""'"); 
  }
  arg1 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Ref_Locate_type_3_set" "', argument " "2"" of type '" "SWIG_Triangulation_3::Locate_type""'");
  } 
  arg2 = static_cast< SWIG_Triangulation_3::Locate_type >(val2);
  {
    try {
      (arg1)->set(arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Ref_Locate_type_3_object(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg1 = (Reference_wrapper< SWIG_Triangulation_3::Locate_type > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::Locate_type result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Ref_Locate_type_3_object",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Ref_Locate_type_3_object" "', argument " "1"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > const *""'"); 
  }
  arg1 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp1);
  {
    try {
      result = (SWIG_Triangulation_3::Locate_type)((Reference_wrapper< SWIG_Triangulation_3::Locate_type > const *)arg1)->object();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Ref_Locate_type_3_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg1 = (Reference_wrapper< SWIG_Triangulation_3::Locate_type > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Reference_wrapper< enum SWIG_Triangulation_3::Locate_type >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Ref_Locate_type_3_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Ref_Locate_type_3_deepcopy" "', argument " "1"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > const *""'"); 
  }
  arg1 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp1);
  {
    try {
      result = ((Reference_wrapper< SWIG_Triangulation_3::Locate_type > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Reference_wrapper< enum SWIG_Triangulation_3::Locate_type >::Self(static_cast< const Reference_wrapper< enum SWIG_Triangulation_3::Locate_type >::Self& >(result))), SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Ref_Locate_type_3_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg1 = (Reference_wrapper< SWIG_Triangulation_3::Locate_type > *) 0 ;
  Reference_wrapper< enum SWIG_Triangulation_3::Locate_type >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Ref_Locate_type_3_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Ref_Locate_type_3_deepcopy" "', argument " "1"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > *""'"); 
  }
  arg1 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Ref_Locate_type_3_deepcopy" "', argument " "2"" of type '" "Reference_wrapper< enum SWIG_Triangulation_3::Locate_type >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Ref_Locate_type_3_deepcopy" "', argument " "2"" of type '" "Reference_wrapper< enum SWIG_Triangulation_3::Locate_type >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< Reference_wrapper< enum SWIG_Triangulation_3::Locate_type >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((Reference_wrapper< enum SWIG_Triangulation_3::Locate_type >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Ref_Locate_type_3_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Ref_Locate_type_3_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Ref_Locate_type_3_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Ref_Locate_type_3_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Reference_wrapper< SWIG_Triangulation_3::Locate_type >::deepcopy() const\n"
    "    Reference_wrapper< SWIG_Triangulation_3::Locate_type >::deepcopy(Reference_wrapper< enum SWIG_Triangulation_3::Locate_type >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_Ref_Locate_type_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg1 = (Reference_wrapper< SWIG_Triangulation_3::Locate_type > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Ref_Locate_type_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Ref_Locate_type_3" "', argument " "1"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > *""'"); 
  }
  arg1 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Ref_Locate_type_3_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Cell_handle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_Cell_handle")) SWIG_fail;
  {
    try {
      result = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *)new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_vertex__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int temp2 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_vertex",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_vertex" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_vertex" "', argument " "2"" of type '" "int""'");
  } 
  temp2 = static_cast< int >(val2);
  arg2 = &temp2;
  {
    try {
      result = (arg1)->vertex((int const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_vertex__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int temp2 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_Cell_handle_vertex",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_vertex" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_vertex" "', argument " "2"" of type '" "int""'");
  } 
  temp2 = static_cast< int >(val2);
  arg2 = &temp2;
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_vertex" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_vertex" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle * >(argp3);
  {
    try {
      (arg1)->vertex((int const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_vertex(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_vertex__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_vertex__SWIG_1(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Cell_handle_vertex'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::vertex(int const &)\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::vertex(int const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_index__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_index",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_index" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_index" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_index" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle * >(argp2);
  {
    try {
      result = (int)(arg1)->index((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_vertex__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_has_vertex",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_vertex" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle * >(argp2);
  {
    try {
      result = (bool)(arg1)->has_vertex((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_neighbor__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int temp2 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_neighbor",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_neighbor" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_neighbor" "', argument " "2"" of type '" "int""'");
  } 
  temp2 = static_cast< int >(val2);
  arg2 = &temp2;
  {
    try {
      result = (arg1)->neighbor((int const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_neighbor__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int temp2 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_Cell_handle_neighbor",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_neighbor" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_neighbor" "', argument " "2"" of type '" "int""'");
  } 
  temp2 = static_cast< int >(val2);
  arg2 = &temp2;
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_neighbor" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_neighbor" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle * >(argp3);
  {
    try {
      (arg1)->neighbor((int const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_neighbor(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_neighbor__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_neighbor__SWIG_1(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Cell_handle_neighbor'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::neighbor(int const &)\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::neighbor(int const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_index__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_index",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_index" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_index" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_index" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle * >(argp2);
  {
    try {
      result = (int)(arg1)->index((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_index(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_index__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_index__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Cell_handle_index'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::index(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &)\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::index(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle * >(argp2);
  {
    try {
      result = (bool)(arg1)->has_neighbor((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_vertex(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int temp2 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_Cell_handle_set_vertex",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertex" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertex" "', argument " "2"" of type '" "int""'");
  } 
  temp2 = static_cast< int >(val2);
  arg2 = &temp2;
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertex" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertex" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle * >(argp3);
  {
    try {
      (arg1)->set_vertex((int const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_vertices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle *arg4 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Mesh_3_regular_triangulation_3_Cell_handle_set_vertices",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertices" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertices" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertices" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertices" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertices" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertices" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertices" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertices" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_vertices" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  arg5 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle * >(argp5);
  {
    try {
      (arg1)->set_vertices((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &)*arg3,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &)*arg4,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &)*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_neighbor(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int temp2 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_Cell_handle_set_neighbor",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbor" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbor" "', argument " "2"" of type '" "int""'");
  } 
  temp2 = static_cast< int >(val2);
  arg2 = &temp2;
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbor" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbor" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle * >(argp3);
  {
    try {
      (arg1)->set_neighbor((int const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle *arg4 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  arg5 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle * >(argp5);
  {
    try {
      (arg1)->set_neighbors((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &)*arg3,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &)*arg4,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &)*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_valid__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Cell_handle_is_valid",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_is_valid" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_valid();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_valid__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  bool *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool temp2 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_is_valid",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_is_valid" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_bool(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_is_valid" "', argument " "2"" of type '" "bool""'");
  } 
  temp2 = static_cast< bool >(val2);
  arg2 = &temp2;
  {
    try {
      result = (bool)(arg1)->is_valid((bool const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_valid__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  bool *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool temp2 ;
  bool val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_Cell_handle_is_valid",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_is_valid" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_bool(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_is_valid" "', argument " "2"" of type '" "bool""'");
  } 
  temp2 = static_cast< bool >(val2);
  arg2 = &temp2;
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_is_valid" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (bool)(arg1)->is_valid((bool const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_valid(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_valid__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_valid__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_valid__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Cell_handle_is_valid'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::is_valid()\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::is_valid(bool const &)\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::is_valid(bool const &,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_vertex__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle *arg2 = 0 ;
  Reference_wrapper< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_Cell_handle_has_vertex",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_vertex" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_vertex" "', argument " "3"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_vertex" "', argument " "3"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg3 = reinterpret_cast< Reference_wrapper< int > * >(argp3);
  {
    try {
      result = (bool)(arg1)->has_vertex((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_vertex(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_vertex__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_vertex__SWIG_1(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Cell_handle_has_vertex'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::has_vertex(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &)\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::has_vertex(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle const &,Reference_wrapper< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle *arg2 = 0 ;
  Reference_wrapper< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor" "', argument " "3"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor" "', argument " "3"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg3 = reinterpret_cast< Reference_wrapper< int > * >(argp3);
  {
    try {
      result = (bool)(arg1)->has_neighbor((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor__SWIG_1(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::has_neighbor(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &)\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::has_neighbor(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &,Reference_wrapper< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle___lt__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle___lt__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___lt__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___lt__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___lt__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator <(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle___gt__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle___gt__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___gt__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___gt__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___gt__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator >(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle___le__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle___le__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___le__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___le__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___le__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator <=(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle___ge__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle___ge__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___ge__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___ge__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___ge__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator >=(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___eq__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___eq__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___eq__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator ==(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___ne__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___ne__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___ne__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator !=(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle___hash__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Cell_handle___hash__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle___hash__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = (int)((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *)arg1)->hashCode();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Cell_handle_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_deepcopy" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = ((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_deepcopy" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_deepcopy" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_deepcopy" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Cell_handle_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Cell_handle_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::deepcopy() const\n"
    "    SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::deepcopy(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_subdomain_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Cell_handle_subdomain_index",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_subdomain_index" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = (int)SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__subdomain_index(arg1);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_subdomain_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_set_subdomain_index",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_subdomain_index" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_subdomain_index" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_subdomain_index(arg1,arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_facet_on_surface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_is_facet_on_surface",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_is_facet_on_surface" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_is_facet_on_surface" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      result = (bool)SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__is_facet_on_surface(arg1,arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_facet_on_surface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int arg2 ;
  std::pair< int,int > arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_Cell_handle_set_facet_on_surface",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_facet_on_surface" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_facet_on_surface" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_std__pairT_int_int_t,  0  | 0);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_facet_on_surface" "', argument " "3"" of type '" "std::pair< int,int >""'"); 
    }  
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_facet_on_surface" "', argument " "3"" of type '" "std::pair< int,int >""'");
    } else {
      std::pair< int,int > * temp = reinterpret_cast< std::pair< int,int > * >(argp3);
      arg3 = *temp;
      if (SWIG_IsNewObj(res3)) delete temp;
    }
  }
  {
    try {
      SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_facet_on_surface(arg1,arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_facet_visited(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_is_facet_visited",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_is_facet_visited" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_is_facet_visited" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      result = (bool)SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__is_facet_visited(arg1,arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_facet_visited(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_set_facet_visited",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_facet_visited" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_facet_visited" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_facet_visited(arg1,arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_get_facet_surface_center(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Weighted_point_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_handle_get_facet_surface_center",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_get_facet_surface_center" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_get_facet_surface_center" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      result = SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__get_facet_surface_center(arg1,arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Weighted_point_3(static_cast< const Weighted_point_3& >(result))), SWIGTYPE_p_Weighted_point_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_facet_surface_center(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int arg2 ;
  Weighted_point_3 *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_Cell_handle_set_facet_surface_center",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_facet_surface_center" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_facet_surface_center" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_facet_surface_center" "', argument " "3"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_handle_set_facet_surface_center" "', argument " "3"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg3 = reinterpret_cast< Weighted_point_3 * >(argp3);
  {
    try {
      SWIG_Triangulation_3_CGAL_Cell_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_facet_surface_center(arg1,arg2,(Weighted_point_3 const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_Cell_handle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_Cell_handle",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_Cell_handle" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_Cell_handle_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Vertex_handle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_Vertex_handle")) SWIG_fail;
  {
    try {
      result = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *)new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_point__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Weighted_point_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Vertex_handle_point",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_point" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = (arg1)->point();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Weighted_point_3(static_cast< const Weighted_point_3& >(result))), SWIGTYPE_p_Weighted_point_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_point__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle_point",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_point" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_point" "', argument " "2"" of type '" "Weighted_point_3 &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_point" "', argument " "2"" of type '" "Weighted_point_3 &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  {
    try {
      (arg1)->point(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_point(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_point__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_point__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Vertex_handle_point'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::point()\n"
    "    SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::point(Weighted_point_3 &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_cell__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Vertex_handle_cell",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_cell" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = (arg1)->cell();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_cell__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle_cell",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_cell" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_cell" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_cell" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle * >(argp2);
  {
    try {
      (arg1)->cell(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_cell(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_cell__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_cell__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Vertex_handle_cell'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::cell()\n"
    "    SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::cell(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_set_cell(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle_set_cell",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_cell" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_cell" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_cell" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle * >(argp2);
  {
    try {
      (arg1)->set_cell((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_set_point(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle_set_point",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_point" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_point" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_point" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  {
    try {
      (arg1)->set_point((Weighted_point_3 const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_is_valid__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Vertex_handle_is_valid",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_is_valid" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_valid();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_is_valid__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  bool *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool temp2 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle_is_valid",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_is_valid" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_bool(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_is_valid" "', argument " "2"" of type '" "bool""'");
  } 
  temp2 = static_cast< bool >(val2);
  arg2 = &temp2;
  {
    try {
      result = (bool)(arg1)->is_valid((bool const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_is_valid(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_is_valid__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_is_valid__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Vertex_handle_is_valid'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::is_valid()\n"
    "    SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::is_valid(bool const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle___lt__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle___lt__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___lt__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___lt__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___lt__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator <(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle___gt__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle___gt__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___gt__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___gt__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___gt__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator >(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle___le__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle___le__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___le__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___le__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___le__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator <=(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle___ge__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle___ge__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___ge__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___ge__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___ge__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator >=(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___eq__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___eq__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___eq__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator ==(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___ne__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___ne__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___ne__" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *)arg1)->operator !=(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle___hash__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Vertex_handle___hash__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle___hash__" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = (int)((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *)arg1)->hashCode();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = ((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::deepcopy() const\n"
    "    SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::deepcopy(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_in_dimension(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Vertex_handle_in_dimension",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_in_dimension" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = (int)SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__in_dimension(arg1);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_set_dimension(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle_set_dimension",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_dimension" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_dimension" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_dimension(arg1,arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Variant< int,std::pair< int,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Vertex_handle_index",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_index" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__index(arg1);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Variant< int,std::pair< int,int > >(static_cast< const Variant< int,std::pair< int,int > >& >(result))), SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_set_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  Variant< int,std::pair< int,int > > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle_set_index",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_index" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_index" "', argument " "2"" of type '" "Variant< int,std::pair< int,int > > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_index" "', argument " "2"" of type '" "Variant< int,std::pair< int,int > > const &""'"); 
  }
  arg2 = reinterpret_cast< Variant< int,std::pair< int,int > > * >(argp2);
  {
    try {
      SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_index(arg1,(Variant< int,std::pair< int,int > > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_meshing_info(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  double result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Vertex_handle_meshing_info",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_meshing_info" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      result = (double)SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__meshing_info(arg1);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_double(static_cast< double >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Vertex_handle_set_meshing_info(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Vertex_handle_set_meshing_info",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_meshing_info" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Vertex_handle_set_meshing_info" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      SWIG_Triangulation_3_CGAL_Vertex_handle_Sl_MT_PMD_Sc_Weighted_point_3_Sg__set_meshing_info(arg1,arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_Vertex_handle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg1 = (SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_Vertex_handle",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_Vertex_handle" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_Vertex_handle_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Facet__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_Facet")) SWIG_fail;
  {
    try {
      result = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)new std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Facet__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > arg1 ;
  int arg2 ;
  void *argp1 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_Mesh_3_regular_triangulation_3_Facet",&obj0,&obj1)) SWIG_fail;
  {
    res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_Mesh_3_regular_triangulation_3_Facet" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >""'"); 
    }  
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Mesh_3_regular_triangulation_3_Facet" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >""'");
    } else {
      SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * temp = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
      arg1 = *temp;
      if (SWIG_IsNewObj(res1)) delete temp;
    }
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_Mesh_3_regular_triangulation_3_Facet" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      result = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)new std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >(arg1,arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Facet__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_Mesh_3_regular_triangulation_3_Facet",&obj0)) SWIG_fail;
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res1 = swig::asptr(obj0, &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_Mesh_3_regular_triangulation_3_Facet" "', argument " "1"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Mesh_3_regular_triangulation_3_Facet" "', argument " "1"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > const &""'"); 
    }
    arg1 = ptr;
  }
  {
    try {
      result = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)new std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >((std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > const &)*arg1);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Facet(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_Mesh_3_regular_triangulation_3_Facet__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_Mesh_3_regular_triangulation_3_Facet__SWIG_2(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_Mesh_3_regular_triangulation_3_Facet__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_Mesh_3_regular_triangulation_3_Facet'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >::pair()\n"
    "    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >::pair(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int)\n"
    "    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >::pair(std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_first_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *arg1 = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Facet_first_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_first_set" "', argument " "1"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Facet_first_set" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  if (arg1) (arg1)->first = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_first_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *arg1 = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Facet_first_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_first_get" "', argument " "1"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > * >(argp1);
  result = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *)& ((arg1)->first);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_second_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *arg1 = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Facet_second_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_second_set" "', argument " "1"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Facet_second_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->second = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_second_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *arg1 = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Facet_second_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_second_get" "', argument " "1"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > * >(argp1);
  result = (int) ((arg1)->second);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_Facet(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *arg1 = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_Facet",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_Facet" "', argument " "1"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_Facet_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Edge_first_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *arg1 = (SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Edge_first_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Edge_first_set" "', argument " "1"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Edge_first_set" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  if (arg1) (arg1)->first = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Edge_first_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *arg1 = (SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Edge_first_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Edge_first_get" "', argument " "1"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > * >(argp1);
  result = (SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *)& ((arg1)->first);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Edge_second_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *arg1 = (SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Edge_second_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Edge_second_set" "', argument " "1"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Edge_second_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->second = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Edge_second_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *arg1 = (SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Edge_second_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Edge_second_get" "', argument " "1"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > * >(argp1);
  result = (int) ((arg1)->second);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Edge_third_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *arg1 = (SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Edge_third_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Edge_third_set" "', argument " "1"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_regular_triangulation_3_Edge_third_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->third = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Edge_third_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *arg1 = (SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Edge_third_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Edge_third_get" "', argument " "1"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > * >(argp1);
  result = (int) ((arg1)->third);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Edge__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_Edge")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *)new SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Edge__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg1 = 0 ;
  int *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int temp2 ;
  int val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:new_Mesh_3_regular_triangulation_3_Edge",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_Mesh_3_regular_triangulation_3_Edge" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Mesh_3_regular_triangulation_3_Edge" "', argument " "1"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg1 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_Mesh_3_regular_triangulation_3_Edge" "', argument " "2"" of type '" "int""'");
  } 
  temp2 = static_cast< int >(val2);
  arg2 = &temp2;
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "new_Mesh_3_regular_triangulation_3_Edge" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *)new SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg1,(int const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Edge(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_Mesh_3_regular_triangulation_3_Edge__SWIG_0(self, args);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_new_Mesh_3_regular_triangulation_3_Edge__SWIG_1(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_Mesh_3_regular_triangulation_3_Edge'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Triple()\n"
    "    SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Triple(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Edge_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *arg1 = (SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Edge_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Edge_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Self(static_cast< const SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Edge_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *arg1 = (SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *) 0 ;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Edge_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Edge_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Edge_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Edge_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Edge_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Edge_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Edge_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Edge_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::deepcopy() const\n"
    "    SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::deepcopy(SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_Edge(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *arg1 = (SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_Edge",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_Edge" "', argument " "1"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_Edge_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Internal_Triangulation_3_Mesh_3_regular_triangulation_3__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Internal_Triangulation_3_Mesh_3_regular_triangulation_3")) SWIG_fail;
  {
    try{
      result = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *)new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >();
    }
    catch(Bad_element_type){
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Internal_Triangulation_3_Mesh_3_regular_triangulation_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Internal_Triangulation_3_Mesh_3_regular_triangulation_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Internal_Triangulation_3_Mesh_3_regular_triangulation_3" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Internal_Triangulation_3_Mesh_3_regular_triangulation_3__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Point_range arg1 ;
  PyObject * obj0 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_Internal_Triangulation_3_Mesh_3_regular_triangulation_3",&obj0)) SWIG_fail;
  {
    try{
      Input_iterator_wrapper<Weighted_point_3,Weighted_point_3::cpp_base> it_end;
      Input_iterator_wrapper<Weighted_point_3,Weighted_point_3::cpp_base> it_begin(obj0,SWIGTYPE_p_Weighted_point_3);
      arg1=std::make_pair(it_begin,it_end);
    }
    catch(Bad_element_type){
      SWIG_fail;
    }
    catch(Not_an_iterator){
      SWIG_fail;
    }
  }
  {
    try{
      result = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *)new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >(arg1);
    }
    catch(Bad_element_type){
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Internal_Triangulation_3_Mesh_3_regular_triangulation_3(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[2] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_Internal_Triangulation_3_Mesh_3_regular_triangulation_3__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      PyObject* iter=PyObject_GetIter(argv[0]);
      if (iter!=NULL){
        Py_DECREF(iter);
        _v=1;
      }
      else _v=0;
    }
    if (_v) {
      return _wrap_new_Internal_Triangulation_3_Mesh_3_regular_triangulation_3__SWIG_1(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_Internal_Triangulation_3_Mesh_3_regular_triangulation_3'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Triangulation_3_wrapper()\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Triangulation_3_wrapper(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Point_range)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_clear",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_clear" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      (arg1)->clear();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_dimension(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_dimension",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_dimension" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (int)(arg1)->dimension();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_vertices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_vertices",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_vertices" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (int)(arg1)->number_of_vertices();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_cells(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_cells",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (int)(arg1)->number_of_cells();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (arg1)->infinite_vertex();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try {
      (arg1)->infinite_vertex(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::infinite_vertex()\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::infinite_vertex(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (arg1)->infinite_cell();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try {
      (arg1)->infinite_cell(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::infinite_cell()\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::infinite_cell(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_facets(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_facets",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (int)(arg1)->number_of_facets();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_edges(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_edges",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_edges" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (int)(arg1)->number_of_edges();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_cells(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_cells",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (int)(arg1)->number_of_finite_cells();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_facets(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_facets",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (int)(arg1)->number_of_finite_facets();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_edges(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_edges",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_edges" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (int)(arg1)->number_of_finite_edges();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try {
      result = (bool)(arg1)->is_infinite((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try {
      result = (bool)(arg1)->is_infinite((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (bool)(arg1)->is_infinite((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    try {
      result = (bool)(arg1)->is_infinite((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      result = (bool)(arg1)->is_infinite((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  {
    try {
      result = (bool)(arg1)->is_infinite((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_5(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_3(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_2(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite__SWIG_4(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_infinite(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_infinite(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_infinite(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_infinite(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_infinite(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_infinite(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_vertex(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_vertex",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_vertex" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try {
      result = (bool)(arg1)->is_vertex((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try {
      result = (bool)(arg1)->is_cell((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  {
    try {
      result = (bool)(arg1)->has_vertex((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2,(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp4);
  {
    try {
      result = (bool)(arg1)->has_vertex((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::has_vertex(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::has_vertex(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg4 = 0 ;
  int *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  {
    try {
      result = (bool)(arg1)->are_equal((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg4,(int const &)*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res3 = swig::asptr(obj2, &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg3 = ptr;
  }
  {
    try {
      result = (bool)(arg1)->are_equal((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2,(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  int *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      result = (bool)(arg1)->are_equal((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,(int const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[6] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = swig::asptr(argv[2], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal__SWIG_2(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::are_equal(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::are_equal(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::are_equal(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  {
    try {
      result = (arg1)->locate((Weighted_point_3 const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  {
    try {
      result = (arg1)->locate((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp4);
  {
    try {
      (arg1)->locate((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  {
    try {
      result = (arg1)->locate((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp4);
  {
    try {
      (arg1)->locate((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg3 = 0 ;
  Reference_wrapper< int > *arg4 = 0 ;
  Reference_wrapper< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  arg3 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "4"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "4"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg4 = reinterpret_cast< Reference_wrapper< int > * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg5 = reinterpret_cast< Reference_wrapper< int > * >(argp5);
  {
    try {
      result = (arg1)->locate((Weighted_point_3 const &)*arg2,*arg3,*arg4,*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg3 = 0 ;
  Reference_wrapper< int > *arg4 = 0 ;
  Reference_wrapper< int > *arg5 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  arg3 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "4"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "4"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg4 = reinterpret_cast< Reference_wrapper< int > * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg5 = reinterpret_cast< Reference_wrapper< int > * >(argp5);
  res6 = SWIG_ConvertPtr(obj5, &argp6, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "6"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp6) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "6"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg6 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp6);
  {
    try {
      result = (arg1)->locate((Weighted_point_3 const &)*arg2,*arg3,*arg4,*arg5,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg6);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg3 = 0 ;
  Reference_wrapper< int > *arg4 = 0 ;
  Reference_wrapper< int > *arg5 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "3"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  arg3 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "4"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "4"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg4 = reinterpret_cast< Reference_wrapper< int > * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg5 = reinterpret_cast< Reference_wrapper< int > * >(argp5);
  res6 = SWIG_ConvertPtr(obj5, &argp6, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "6"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp6) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate" "', argument " "6"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg6 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp6);
  {
    try {
      result = (arg1)->locate((Weighted_point_3 const &)*arg2,*arg3,*arg4,*arg5,(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg6);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[7] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_3(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_2(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_4(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_5(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_6(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate__SWIG_7(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::locate(Weighted_point_3 const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::locate(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::locate(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::locate(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::locate(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::locate(Weighted_point_3 const &,Reference_wrapper< SWIG_Triangulation_3::Locate_type > &,Reference_wrapper< int > &,Reference_wrapper< int > &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::locate(Weighted_point_3 const &,Reference_wrapper< SWIG_Triangulation_3::Locate_type > &,Reference_wrapper< int > &,Reference_wrapper< int > &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::locate(Weighted_point_3 const &,Reference_wrapper< SWIG_Triangulation_3::Locate_type > &,Reference_wrapper< int > &,Reference_wrapper< int > &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg4 = 0 ;
  Reference_wrapper< int > *arg5 = 0 ;
  Reference_wrapper< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  Bounded_side result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell" "', argument " "4"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell" "', argument " "4"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  arg4 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg5 = reinterpret_cast< Reference_wrapper< int > * >(argp5);
  res6 = SWIG_ConvertPtr(obj5, &argp6, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell" "', argument " "6"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp6) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell" "', argument " "6"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg6 = reinterpret_cast< Reference_wrapper< int > * >(argp6);
  {
    try {
      result = (Bounded_side)(arg1)->side_of_cell((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,*arg4,*arg5,*arg6);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg3 = 0 ;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg4 = 0 ;
  Reference_wrapper< int > *arg5 = 0 ;
  Reference_wrapper< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  Bounded_side result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res3 = swig::asptr(obj2, &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg3 = ptr;
  }
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet" "', argument " "4"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet" "', argument " "4"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  arg4 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg5 = reinterpret_cast< Reference_wrapper< int > * >(argp5);
  res6 = SWIG_ConvertPtr(obj5, &argp6, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet" "', argument " "6"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp6) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet" "', argument " "6"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg6 = reinterpret_cast< Reference_wrapper< int > * >(argp6);
  {
    try {
      result = (Bounded_side)(arg1)->side_of_facet((Weighted_point_3 const &)*arg2,(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg3,*arg4,*arg5,*arg6);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg3 = 0 ;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg4 = 0 ;
  Reference_wrapper< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  Bounded_side result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg3 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "4"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "4"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  arg4 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg5 = reinterpret_cast< Reference_wrapper< int > * >(argp5);
  {
    try {
      result = (Bounded_side)(arg1)->side_of_edge((Weighted_point_3 const &)*arg2,(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg3,*arg4,*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  Reference_wrapper< SWIG_Triangulation_3::Locate_type > *arg4 = 0 ;
  Reference_wrapper< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  Bounded_side result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "4"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "4"" of type '" "Reference_wrapper< SWIG_Triangulation_3::Locate_type > &""'"); 
  }
  arg4 = reinterpret_cast< Reference_wrapper< SWIG_Triangulation_3::Locate_type > * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge" "', argument " "5"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg5 = reinterpret_cast< Reference_wrapper< int > * >(argp5);
  {
    try {
      result = (Bounded_side)(arg1)->side_of_edge((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,*arg4,*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[6] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::side_of_edge(Weighted_point_3 const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &,Reference_wrapper< SWIG_Triangulation_3::Locate_type > &,Reference_wrapper< int > &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::side_of_edge(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,Reference_wrapper< SWIG_Triangulation_3::Locate_type > &,Reference_wrapper< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  {
    try {
      result = (bool)(arg1)->flip((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      result = (bool)(arg1)->flip((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  {
    try {
      (arg1)->flip_flippable((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      (arg1)->flip_flippable((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    try {
      result = (bool)(arg1)->flip((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (bool)(arg1)->flip((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip__SWIG_2(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip__SWIG_3(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::flip(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::flip(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::flip(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::flip(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    try {
      (arg1)->flip_flippable((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      (arg1)->flip_flippable((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable__SWIG_2(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable__SWIG_3(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::flip_flippable(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::flip_flippable(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::flip_flippable(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::flip_flippable(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  {
    try{
      result = (arg1)->insert((Weighted_point_3 const &)*arg2);
    }
    catch(Bad_element_type){
      //TODO: throw a specify exception
      //TODO add a message to specify that the list does not contains only points
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  {
    try{
      result = (arg1)->insert((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3);
    }
    catch(Bad_element_type){
      //TODO: throw a specify exception
      //TODO add a message to specify that the list does not contains only points
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp4);
  {
    try{
      (arg1)->insert((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,*arg4);
    }
    catch(Bad_element_type){
      //TODO: throw a specify exception
      //TODO add a message to specify that the list does not contains only points
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  {
    try{
      result = (arg1)->insert((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg3);
    }
    catch(Bad_element_type){
      //TODO: throw a specify exception
      //TODO add a message to specify that the list does not contains only points
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp4);
  {
    try{
      (arg1)->insert((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg3,*arg4);
    }
    catch(Bad_element_type){
      //TODO: throw a specify exception
      //TODO add a message to specify that the list does not contains only points
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Point_range arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try{
      Input_iterator_wrapper<Weighted_point_3,Weighted_point_3::cpp_base> it_end;
      Input_iterator_wrapper<Weighted_point_3,Weighted_point_3::cpp_base> it_begin(obj1,SWIGTYPE_p_Weighted_point_3);
      arg2=std::make_pair(it_begin,it_end);
    }
    catch(Bad_element_type){
      SWIG_fail;
    }
    catch(Not_an_iterator){
      SWIG_fail;
    }
  }
  {
    try{
      result = (int)(arg1)->insert(arg2);
    }
    catch(Bad_element_type){
      //TODO: throw a specify exception
      //TODO add a message to specify that the list does not contains only points
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        PyObject* iter=PyObject_GetIter(argv[1]);
        if (iter!=NULL){
          Py_DECREF(iter);
          _v=1;
        }
        else _v=0;
      }
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_5(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_3(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_4(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert__SWIG_2(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert(Weighted_point_3 const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Point_range)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  {
    try {
      result = (arg1)->insert_in_cell((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp4);
  {
    try {
      (arg1)->insert_in_cell((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_in_cell(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_in_cell(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res3 = swig::asptr(obj2, &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg3 = ptr;
  }
  {
    try {
      result = (arg1)->insert_in_facet((Weighted_point_3 const &)*arg2,(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res3 = swig::asptr(obj2, &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg3 = ptr;
  }
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp4);
  {
    try {
      (arg1)->insert_in_facet((Weighted_point_3 const &)*arg2,(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  int *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      result = (arg1)->insert_in_facet((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,(int const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  int *arg4 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg5 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp5);
  {
    try {
      (arg1)->insert_in_facet((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,(int const &)*arg4,*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[6] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = swig::asptr(argv[2], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet__SWIG_2(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = swig::asptr(argv[2], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet__SWIG_1(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet__SWIG_3(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_in_facet(Weighted_point_3 const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_in_facet(Weighted_point_3 const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_in_facet(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_in_facet(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg3 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp3);
  {
    try {
      result = (arg1)->insert_in_edge((Weighted_point_3 const &)*arg2,(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg3 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp4);
  {
    try {
      (arg1)->insert_in_edge((Weighted_point_3 const &)*arg2,(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  int *arg4 = 0 ;
  int *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  {
    try {
      result = (arg1)->insert_in_edge((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,(int const &)*arg4,(int const &)*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  int *arg4 = 0 ;
  int *arg5 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "6"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp6) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge" "', argument " "6"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg6 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp6);
  {
    try {
      (arg1)->insert_in_edge((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,(int const &)*arg4,(int const &)*arg5,*arg6);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[7] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge__SWIG_1(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge__SWIG_3(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_in_edge(Weighted_point_3 const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_in_edge(Weighted_point_3 const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_in_edge(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_in_edge(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  {
    try {
      result = (arg1)->insert_outside_convex_hull((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp4);
  {
    try {
      (arg1)->insert_outside_convex_hull((Weighted_point_3 const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_outside_convex_hull(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_outside_convex_hull(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  {
    try {
      result = (arg1)->insert_outside_affine_hull((Weighted_point_3 const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  {
    try {
      (arg1)->insert_outside_affine_hull((Weighted_point_3 const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull__SWIG_1(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_outside_affine_hull(Weighted_point_3 const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::insert_outside_affine_hull(Weighted_point_3 const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_vertices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_vertices_iterator result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_vertices",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_vertices" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (arg1)->finite_vertices();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_vertices_iterator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_vertices_iterator& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_edges(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_edges_iterator result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_edges",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_edges" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (arg1)->finite_edges();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_edges_iterator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_edges_iterator& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_facets(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_facets_iterator result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_facets",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (arg1)->finite_facets();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_facets_iterator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_facets_iterator& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_cells(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_cells_iterator result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_cells",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (arg1)->finite_cells();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_cells_iterator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_cells_iterator& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_vertices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_vertices_iterator result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_vertices",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_vertices" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (arg1)->all_vertices();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_vertices_iterator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_vertices_iterator& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_edges(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_edges_iterator result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_edges",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_edges" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (arg1)->all_edges();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_edges_iterator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_edges_iterator& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_facets(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_facets_iterator result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_facets",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (arg1)->all_facets();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_facets_iterator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_facets_iterator& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_cells(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_cells_iterator result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_cells",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (arg1)->all_cells();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_cells_iterator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_cells_iterator& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_points(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Point_iterator result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_points",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_points" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (arg1)->points();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Point_iterator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Point_iterator& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  {
    try {
      result = (arg1)->incident_cells((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &""'"); 
  }
  arg3 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator * >(argp3);
  {
    try {
      (arg1)->incident_cells((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      result = (arg1)->incident_cells((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "5"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "5"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &""'"); 
  }
  arg5 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator * >(argp5);
  {
    try {
      (arg1)->incident_cells((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4,*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  {
    try {
      result = (arg1)->incident_cells((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "4"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "4"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &""'"); 
  }
  arg4 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator * >(argp4);
  {
    try {
      (arg1)->incident_cells((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg5 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp5);
  {
    try {
      result = (arg1)->incident_cells((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg5 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg5 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp5);
  res6 = SWIG_ConvertPtr(obj5, &argp6, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "6"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &""'"); 
  }
  if (!argp6) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "6"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &""'"); 
  }
  arg6 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator * >(argp6);
  {
    try {
      (arg1)->incident_cells((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg5,*arg6);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  {
    try {
      result = (arg1)->incident_facets((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &""'"); 
  }
  arg3 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator * >(argp3);
  {
    try {
      (arg1)->incident_facets((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      result = (arg1)->incident_facets((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "5"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "5"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &""'"); 
  }
  arg5 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator * >(argp5);
  {
    try {
      (arg1)->incident_facets((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4,*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res3 = swig::asptr(obj2, &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg3 = ptr;
  }
  {
    try {
      result = (arg1)->incident_facets((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2,(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg3 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res3 = swig::asptr(obj2, &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg3 = ptr;
  }
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "4"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "4"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &""'"); 
  }
  arg4 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator * >(argp4);
  {
    try {
      (arg1)->incident_facets((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2,(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  int *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      result = (arg1)->incident_facets((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,(int const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg3 = 0 ;
  int *arg4 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg3 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "5"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "5"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &""'"); 
  }
  arg5 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator * >(argp5);
  {
    try {
      (arg1)->incident_facets((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg3,(int const &)*arg4,*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  int res5 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res5 = swig::asptr(obj4, &ptr);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "5"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "5"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg5 = ptr;
  }
  {
    try {
      result = (arg1)->incident_facets((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4,(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res5)) delete arg5;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res5)) delete arg5;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg5 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  int res5 = SWIG_OLDOBJ ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res5 = swig::asptr(obj4, &ptr);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "5"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "5"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg5 = ptr;
  }
  res6 = SWIG_ConvertPtr(obj5, &argp6, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "6"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &""'"); 
  }
  if (!argp6) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "6"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &""'"); 
  }
  arg6 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator * >(argp6);
  {
    try {
      (arg1)->incident_facets((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4,(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg5,*arg6);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res5)) delete arg5;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res5)) delete arg5;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg5 = 0 ;
  int *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  int temp6 ;
  int val6 ;
  int ecode6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg5 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp5);
  ecode6 = SWIG_AsVal_int(obj5, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "6"" of type '" "int""'");
  } 
  temp6 = static_cast< int >(val6);
  arg6 = &temp6;
  {
    try {
      result = (arg1)->incident_facets((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4,(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg5,(int const &)*arg6);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_handle_output_iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      arg3=boost::make_function_output_iterator( Container_writer<Mesh_3_regular_triangulation_3_Cell_handle,MT_PMD::Cell_handle>(obj2,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t) );
    }
    catch(Not_a_list){
      SWIG_fail;
    }
  }
  {
    try {
      (arg1)->incident_cells((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[7] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_4(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          _v = PyList_Check(argv[2]) ? 1 : 0;
        }
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_8(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_5(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_2(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_6(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_3(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells__SWIG_7(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_cells(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_cells(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_cells(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_cells(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_cells(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_cells(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_cells(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_cells(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_cells(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_handle_output_iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_cells(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_handle_output_iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_cells",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_cells" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_cells" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      arg3=boost::make_function_output_iterator( Container_writer<Mesh_3_regular_triangulation_3_Cell_handle,MT_PMD::Cell_handle>(obj2,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t) );
    }
    catch(Not_a_list){
      SWIG_fail;
    }
  }
  {
    try {
      (arg1)->finite_incident_cells((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_output_iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      arg3=boost::make_function_output_iterator( Container_writer<Mesh_3_regular_triangulation_3_Facet,MT_PMD::Facet>(obj2,SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t) );
    }
    catch(Not_a_list){
      SWIG_fail;
    }
  }
  {
    try {
      (arg1)->incident_facets((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[7] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = swig::asptr(argv[2], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_4(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          _v = PyList_Check(argv[2]) ? 1 : 0;
        }
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_11(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = swig::asptr(argv[2], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_5(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_2(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_7(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_3(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = swig::asptr(argv[4], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_8(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              {
                int res = SWIG_AsVal_int(argv[5], NULL);
                _v = SWIG_CheckState(res);
              }
              if (_v) {
                return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_10(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = swig::asptr(argv[4], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
            _v = SWIG_CheckState(res);
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets__SWIG_9(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::incident_facets(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_output_iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_facets(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_output_iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_facets",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_facets" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_facets" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      arg3=boost::make_function_output_iterator( Container_writer<Mesh_3_regular_triangulation_3_Facet,MT_PMD::Facet>(obj2,SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t) );
    }
    catch(Not_a_list){
      SWIG_fail;
    }
  }
  {
    try {
      (arg1)->finite_incident_facets((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_edges(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge_output_iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_edges",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_edges" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_edges" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_edges" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      arg3=boost::make_function_output_iterator( Container_writer<Mesh_3_regular_triangulation_3_Edge,MT_PMD::Edge>(obj2,SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t) );
    }
    catch(Not_a_list){
      SWIG_fail;
    }
  }
  {
    try {
      (arg1)->incident_edges((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_edges(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge_output_iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_edges",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_edges" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_edges" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_edges" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      arg3=boost::make_function_output_iterator( Container_writer<Mesh_3_regular_triangulation_3_Edge,MT_PMD::Edge>(obj2,SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t) );
    }
    catch(Not_a_list){
      SWIG_fail;
    }
  }
  {
    try {
      (arg1)->finite_incident_edges((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_adjacent_vertices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Vertex_handle_output_iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_adjacent_vertices",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_adjacent_vertices" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_adjacent_vertices" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_adjacent_vertices" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      arg3=boost::make_function_output_iterator( Container_writer<Mesh_3_regular_triangulation_3_Vertex_handle,MT_PMD::Vertex_handle>(obj2,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t) );
    }
    catch(Not_a_list){
      SWIG_fail;
    }
  }
  {
    try {
      (arg1)->adjacent_vertices((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_adjacent_vertices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Vertex_handle_output_iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_adjacent_vertices",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_adjacent_vertices" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_adjacent_vertices" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_adjacent_vertices" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      arg3=boost::make_function_output_iterator( Container_writer<Mesh_3_regular_triangulation_3_Vertex_handle,MT_PMD::Vertex_handle>(obj2,SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t) );
    }
    catch(Not_a_list){
      SWIG_fail;
    }
  }
  {
    try {
      (arg1)->finite_adjacent_vertices((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_degree(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_degree",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_degree" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_degree" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_degree" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try {
      result = (int)(arg1)->degree((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_index",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_index" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_index" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_index" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_index" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (int)(arg1)->mirror_index((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (arg1)->mirror_vertex((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg4 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp4);
  {
    try {
      (arg1)->mirror_vertex((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::mirror_vertex(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::mirror_vertex(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    try {
      result = (arg1)->mirror_facet((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet" "', argument " "3"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet &""'"); 
  }
  arg3 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet * >(argp3);
  {
    try {
      (arg1)->mirror_facet((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet__SWIG_1(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::mirror_facet(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::mirror_facet(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &,Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Tetrahedron_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try {
      result = (arg1)->tetrahedron((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Tetrahedron_3(static_cast< const Tetrahedron_3& >(result))), SWIGTYPE_p_Tetrahedron_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  Tetrahedron_3 *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Tetrahedron_3,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron" "', argument " "3"" of type '" "Tetrahedron_3 &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron" "', argument " "3"" of type '" "Tetrahedron_3 &""'"); 
  }
  arg3 = reinterpret_cast< Tetrahedron_3 * >(argp3);
  {
    try {
      (arg1)->tetrahedron((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_Tetrahedron_3, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron__SWIG_1(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::tetrahedron(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::tetrahedron(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,Tetrahedron_3 &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Triangle_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (arg1)->triangle((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangle_3(static_cast< const Triangle_3& >(result))), SWIGTYPE_p_Triangle_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  Triangle_3 *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Triangle_3,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "4"" of type '" "Triangle_3 &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "4"" of type '" "Triangle_3 &""'"); 
  }
  arg4 = reinterpret_cast< Triangle_3 * >(argp4);
  {
    try {
      (arg1)->triangle((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Triangle_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    try {
      result = (arg1)->triangle((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangle_3(static_cast< const Triangle_3& >(result))), SWIGTYPE_p_Triangle_3, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  Triangle_3 *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Triangle_3,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "3"" of type '" "Triangle_3 &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle" "', argument " "3"" of type '" "Triangle_3 &""'"); 
  }
  arg3 = reinterpret_cast< Triangle_3 * >(argp3);
  {
    try {
      (arg1)->triangle((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle__SWIG_2(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_Triangle_3, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle__SWIG_3(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_Triangle_3, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::triangle(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::triangle(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,Triangle_3 &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::triangle(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::triangle(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet const &,Triangle_3 &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Segment_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  {
    try {
      result = (arg1)->segment((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Segment_3(static_cast< const Segment_3& >(result))), SWIGTYPE_p_Segment_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  Segment_3 *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Segment_3,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "3"" of type '" "Segment_3 &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "3"" of type '" "Segment_3 &""'"); 
  }
  arg3 = reinterpret_cast< Segment_3 * >(argp3);
  {
    try {
      (arg1)->segment((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  Segment_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      result = (arg1)->segment((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Segment_3(static_cast< const Segment_3& >(result))), SWIGTYPE_p_Segment_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  Segment_3 *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_Segment_3,  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "5"" of type '" "Segment_3 &""'"); 
  }
  if (!argp5) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment" "', argument " "5"" of type '" "Segment_3 &""'"); 
  }
  arg5 = reinterpret_cast< Segment_3 * >(argp5);
  {
    try {
      (arg1)->segment((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,(int const &)*arg4,*arg5);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[6] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_Segment_3, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment__SWIG_2(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_Segment_3, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment__SWIG_3(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::segment(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::segment(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge const &,Segment_3 &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::segment(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::segment(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,int const &,Segment_3 &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Weighted_point_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (arg1)->point((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Weighted_point_3(static_cast< const Weighted_point_3& >(result))), SWIGTYPE_p_Weighted_point_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  int *arg3 = 0 ;
  Weighted_point_3 *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Weighted_point_3,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "4"" of type '" "Weighted_point_3 &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "4"" of type '" "Weighted_point_3 &""'"); 
  }
  arg4 = reinterpret_cast< Weighted_point_3 * >(argp4);
  {
    try {
      (arg1)->point((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(int const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Weighted_point_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try {
      result = (arg1)->point((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Weighted_point_3(static_cast< const Weighted_point_3& >(result))), SWIGTYPE_p_Weighted_point_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  Weighted_point_3 *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Weighted_point_3,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "3"" of type '" "Weighted_point_3 &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point" "', argument " "3"" of type '" "Weighted_point_3 &""'"); 
  }
  arg3 = reinterpret_cast< Weighted_point_3 * >(argp3);
  {
    try {
      (arg1)->point((SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point__SWIG_2(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_Weighted_point_3, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point__SWIG_3(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_Weighted_point_3, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::point(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::point(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,int const &,Weighted_point_3 &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::point(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::point(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > const &,Weighted_point_3 &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->is_valid();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  bool *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool temp2 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  ecode2 = SWIG_AsVal_bool(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid" "', argument " "2"" of type '" "bool""'");
  } 
  temp2 = static_cast< bool >(val2);
  arg2 = &temp2;
  {
    try {
      result = (bool)(arg1)->is_valid((bool const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try {
      result = (bool)(arg1)->is_valid((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  bool *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  bool temp3 ;
  bool val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  ecode3 = SWIG_AsVal_bool(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid" "', argument " "3"" of type '" "bool""'");
  } 
  temp3 = static_cast< bool >(val3);
  arg3 = &temp3;
  {
    try {
      result = (bool)(arg1)->is_valid((SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)*arg2,(bool const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid__SWIG_2(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid__SWIG_3(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_valid()\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_valid(bool const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_valid(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_valid(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &,bool const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > arg2 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > arg3 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > arg4 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > arg5 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg6 = 0 ;
  Reference_wrapper< int > *arg7 = 0 ;
  Reference_wrapper< int > *arg8 = 0 ;
  Reference_wrapper< int > *arg9 = 0 ;
  Reference_wrapper< int > *arg10 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  void *argp3 ;
  int res3 = 0 ;
  void *argp4 ;
  int res4 = 0 ;
  void *argp5 ;
  int res5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  void *argp9 = 0 ;
  int res9 = 0 ;
  void *argp10 = 0 ;
  int res10 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  PyObject * obj7 = 0 ;
  PyObject * obj8 = 0 ;
  PyObject * obj9 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOOOOO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6,&obj7,&obj8,&obj9)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >""'"); 
    }  
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >""'");
    } else {
      SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * temp = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
      arg2 = *temp;
      if (SWIG_IsNewObj(res2)) delete temp;
    }
  }
  {
    res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >""'"); 
    }  
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "3"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >""'");
    } else {
      SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * temp = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp3);
      arg3 = *temp;
      if (SWIG_IsNewObj(res3)) delete temp;
    }
  }
  {
    res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >""'"); 
    }  
    if (!argp4) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "4"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >""'");
    } else {
      SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * temp = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp4);
      arg4 = *temp;
      if (SWIG_IsNewObj(res4)) delete temp;
    }
  }
  {
    res5 = SWIG_ConvertPtr(obj4, &argp5, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >""'"); 
    }  
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "5"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >""'");
    } else {
      SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * temp = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp5);
      arg5 = *temp;
      if (SWIG_IsNewObj(res5)) delete temp;
    }
  }
  res6 = SWIG_ConvertPtr(obj5, &argp6, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "6"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp6) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "6"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg6 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp6);
  res7 = SWIG_ConvertPtr(obj6, &argp7, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res7)) {
    SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "7"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp7) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "7"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg7 = reinterpret_cast< Reference_wrapper< int > * >(argp7);
  res8 = SWIG_ConvertPtr(obj7, &argp8, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res8)) {
    SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "8"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp8) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "8"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg8 = reinterpret_cast< Reference_wrapper< int > * >(argp8);
  res9 = SWIG_ConvertPtr(obj8, &argp9, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res9)) {
    SWIG_exception_fail(SWIG_ArgError(res9), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "9"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp9) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "9"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg9 = reinterpret_cast< Reference_wrapper< int > * >(argp9);
  res10 = SWIG_ConvertPtr(obj9, &argp10, SWIGTYPE_p_Reference_wrapperT_int_t,  0 );
  if (!SWIG_IsOK(res10)) {
    SWIG_exception_fail(SWIG_ArgError(res10), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "10"" of type '" "Reference_wrapper< int > &""'"); 
  }
  if (!argp10) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell" "', argument " "10"" of type '" "Reference_wrapper< int > &""'"); 
  }
  arg10 = reinterpret_cast< Reference_wrapper< int > * >(argp10);
  {
    try {
      result = (bool)(arg1)->is_cell(arg2,arg3,arg4,arg5,*arg6,*arg7,*arg8,*arg9,*arg10);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[11] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 10) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell__SWIG_0(self, args);
      }
    }
  }
  if (argc == 10) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                void *vptr = 0;
                int res = SWIG_ConvertPtr(argv[6], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  void *vptr = 0;
                  int res = SWIG_ConvertPtr(argv[7], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
                  _v = SWIG_CheckState(res);
                  if (_v) {
                    void *vptr = 0;
                    int res = SWIG_ConvertPtr(argv[8], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
                    _v = SWIG_CheckState(res);
                    if (_v) {
                      void *vptr = 0;
                      int res = SWIG_ConvertPtr(argv[9], &vptr, SWIGTYPE_p_Reference_wrapperT_int_t, 0);
                      _v = SWIG_CheckState(res);
                      if (_v) {
                        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell__SWIG_1(self, args);
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_cell(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > const &)\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::is_cell(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &,Reference_wrapper< int > &,Reference_wrapper< int > &,Reference_wrapper< int > &,Reference_wrapper< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_equal(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_equal",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_equal" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_equal" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_equal" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp2);
  {
    try {
      result = (bool)(arg1)->equal((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3___eq__" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > const *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3___eq__" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3___eq__" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self * >(argp2);
  {
    try {
      result = (bool)((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > const *)arg1)->operator ==(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3___ne__" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > const *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3___ne__" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3___ne__" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self * >(argp2);
  {
    try {
      result = (bool)((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > const *)arg1)->operator !=(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > const *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      result = ((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self(static_cast< const Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self& >(result))), SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::deepcopy() const\n"
    "    Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::deepcopy(Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_same_internal_object(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *arg1 = (Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Internal_Triangulation_3_Mesh_3_regular_triangulation_3_same_internal_object",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_same_internal_object" "', argument " "1"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_same_internal_object" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Internal_Triangulation_3_Mesh_3_regular_triangulation_3_same_internal_object" "', argument " "2"" of type '" "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self * >(argp2);
  {
    try {
      result = (bool)(arg1)->same_internal_object((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Internal_Triangulation_3_Mesh_3_regular_triangulation_3_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_All_vertices_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_All_vertices_iterator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *)new SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_vertices_iterator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >(static_cast< const SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_next__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_vertices_iterator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_vertices_iterator___next__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator___next__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try{
      result = (arg1)->__next__();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_next__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_vertices_iterator_next",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator_next" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator_next" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      (arg1)->next(*arg2);
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_next(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_next__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_next__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_All_vertices_iterator_next'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::next()\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::next(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self(static_cast< const SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::deepcopy() const\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::deepcopy(SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_vertices_iterator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_vertices_iterator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator ==((SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_vertices_iterator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_vertices_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator !=((SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_All_vertices_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_All_vertices_iterator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_All_vertices_iterator" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_All_vertices_iterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Finite_vertices_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_Finite_vertices_iterator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *)new SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_vertices_iterator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >(static_cast< const SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_vertices_iterator___next__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator___next__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try{
      result = (arg1)->__next__();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      (arg1)->next(*arg2);
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::next()\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::next(SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self(static_cast< const SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::deepcopy() const\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::deepcopy(SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_vertices_iterator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_vertices_iterator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator ==((SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_vertices_iterator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_vertices_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator !=((SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_Finite_vertices_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_Finite_vertices_iterator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_Finite_vertices_iterator" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_Finite_vertices_iterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_All_cells_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_All_cells_iterator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *)new SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_cells_iterator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_cells_iterator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >(static_cast< const SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_next__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_cells_iterator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_cells_iterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_cells_iterator___next__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator___next__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try{
      result = (arg1)->__next__();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_next__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_cells_iterator_next",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator_next" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator_next" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      (arg1)->next(*arg2);
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_next(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_next__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_next__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_All_cells_iterator_next'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::next()\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::next(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self(static_cast< const SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::deepcopy() const\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::deepcopy(SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_cells_iterator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_cells_iterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_cells_iterator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator ==((SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_cells_iterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_cells_iterator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_cells_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator !=((SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_All_cells_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_All_cells_iterator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_All_cells_iterator" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_All_cells_iterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Finite_cells_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_Finite_cells_iterator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *)new SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_cells_iterator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >(static_cast< const SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_next__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_cells_iterator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_cells_iterator___next__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator___next__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try{
      result = (arg1)->__next__();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_next__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_cells_iterator_next",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator_next" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator_next" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      (arg1)->next(*arg2);
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_next(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_next__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_next__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Finite_cells_iterator_next'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::next()\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::next(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self(static_cast< const SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::deepcopy() const\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::deepcopy(SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_cells_iterator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_cells_iterator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator ==((SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_cells_iterator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_cells_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator !=((SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_Finite_cells_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_Finite_cells_iterator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_Finite_cells_iterator" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_Finite_cells_iterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_All_facets_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_All_facets_iterator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *)new SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_facets_iterator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_facets_iterator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(static_cast< const SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_next__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_facets_iterator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_facets_iterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_facets_iterator___next__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator___next__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try{
      result = (arg1)->__next__();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_next__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_facets_iterator_next",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator_next" "', argument " "2"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator_next" "', argument " "2"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > &""'"); 
  }
  arg2 = reinterpret_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > * >(argp2);
  {
    try{
      (arg1)->next(*arg2);
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_next(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_next__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_next__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_All_facets_iterator_next'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::next()\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::next(std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self(static_cast< const SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::deepcopy() const\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::deepcopy(SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_facets_iterator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_facets_iterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_facets_iterator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->operator ==((SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_facets_iterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_facets_iterator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_facets_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->operator !=((SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_All_facets_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_All_facets_iterator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_All_facets_iterator" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_All_facets_iterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Finite_facets_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_Finite_facets_iterator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *)new SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_facets_iterator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(static_cast< const SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_next__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_facets_iterator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_facets_iterator___next__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator___next__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try{
      result = (arg1)->__next__();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_next__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_facets_iterator_next",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator_next" "', argument " "2"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator_next" "', argument " "2"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > &""'"); 
  }
  arg2 = reinterpret_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > * >(argp2);
  {
    try{
      (arg1)->next(*arg2);
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_next(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_next__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_next__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Finite_facets_iterator_next'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::next()\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::next(std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self(static_cast< const SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::deepcopy() const\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::deepcopy(SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_facets_iterator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_facets_iterator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->operator ==((SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_facets_iterator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_facets_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->operator !=((SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_Finite_facets_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_Finite_facets_iterator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_Finite_facets_iterator" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_Finite_facets_iterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_All_edges_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_All_edges_iterator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *)new SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_edges_iterator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_edges_iterator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >(static_cast< const SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_next__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_edges_iterator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >(static_cast< const SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >& >(result))), SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_edges_iterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_edges_iterator___next__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator___next__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try{
      result = (arg1)->__next__();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >(static_cast< const SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >& >(result))), SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_next__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_edges_iterator_next",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator_next" "', argument " "2"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator_next" "', argument " "2"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > * >(argp2);
  {
    try{
      (arg1)->next(*arg2);
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_next(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_next__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_next__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_All_edges_iterator_next'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::next()\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::next(SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self(static_cast< const SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::deepcopy() const\n"
    "    SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::deepcopy(SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_All_edges_iterator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_edges_iterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_edges_iterator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *)arg1)->operator ==((SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_All_edges_iterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_All_edges_iterator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_All_edges_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *)arg1)->operator !=((SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_All_edges_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_All_edges_iterator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_All_edges_iterator" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_All_edges_iterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Finite_edges_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_Finite_edges_iterator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *)new SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_edges_iterator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >(static_cast< const SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_next__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_edges_iterator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >(static_cast< const SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >& >(result))), SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_edges_iterator___next__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator___next__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try{
      result = (arg1)->__next__();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >(static_cast< const SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >& >(result))), SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_next__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_edges_iterator_next",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator_next" "', argument " "2"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator_next" "', argument " "2"" of type '" "SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > * >(argp2);
  {
    try{
      (arg1)->next(*arg2);
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_next(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_next__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_next__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Finite_edges_iterator_next'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::next()\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::next(SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self(static_cast< const SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::deepcopy() const\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::deepcopy(SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Finite_edges_iterator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_edges_iterator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *)arg1)->operator ==((SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Finite_edges_iterator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Finite_edges_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > const *)arg1)->operator !=((SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_Finite_edges_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_Finite_edges_iterator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_Finite_edges_iterator" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_Finite_edges_iterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Point_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_Point_iterator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *)new SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Point_iterator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Point_iterator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >(static_cast< const SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Point_iterator_next__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Weighted_point_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Point_iterator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Weighted_point_3(static_cast< const Weighted_point_3& >(result))), SWIGTYPE_p_Weighted_point_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Point_iterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Weighted_point_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Point_iterator___next__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator___next__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > * >(argp1);
  {
    try{
      result = (arg1)->__next__();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Weighted_point_3(static_cast< const Weighted_point_3& >(result))), SWIGTYPE_p_Weighted_point_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Point_iterator_next__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Point_iterator_next",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator_next" "', argument " "2"" of type '" "Weighted_point_3 &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Point_iterator_next" "', argument " "2"" of type '" "Weighted_point_3 &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  {
    try{
      (arg1)->next(*arg2);
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Point_iterator_next(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Point_iterator_next__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Point_iterator_next__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Point_iterator_next'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::next()\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::next(Weighted_point_3 &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Point_iterator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Point_iterator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self(static_cast< const SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Point_iterator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Point_iterator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Point_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Point_iterator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Point_iterator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Point_iterator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Point_iterator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::deepcopy() const\n"
    "    SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::deepcopy(SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Point_iterator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Point_iterator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Point_iterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Point_iterator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Point_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > const *)arg1)->operator ==((SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Point_iterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *) 0 ;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Point_iterator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Point_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Point_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > const *)arg1)->operator !=((SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_Point_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *arg1 = (SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_Point_iterator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_Point_iterator" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_Point_iterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Cell_circulator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_Cell_circulator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *)new SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_circulator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Cell_circulator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >(static_cast< const SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_circulator_next(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Cell_circulator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator_next" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self(static_cast< const SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::deepcopy() const\n"
    "    SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::deepcopy(SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_circulator_prev(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Cell_circulator_prev",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator_prev" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (arg1)->prev();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_circulator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Cell_circulator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_circulator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_circulator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator ==((SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Cell_circulator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Cell_circulator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Cell_circulator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator !=((SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_Cell_circulator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_Cell_circulator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_Cell_circulator" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_Cell_circulator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3_Facet_circulator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3_Facet_circulator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *)new SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_circulator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Facet_circulator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(static_cast< const SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_circulator_next(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Facet_circulator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator_next" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self(static_cast< const SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::deepcopy() const\n"
    "    SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::deepcopy(SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_circulator_prev(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Facet_circulator_prev",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator_prev" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = (arg1)->prev();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_circulator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_regular_triangulation_3_Facet_circulator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_circulator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Facet_circulator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->operator ==((SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_Facet_circulator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_Facet_circulator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_Facet_circulator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->operator !=((SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3_Facet_circulator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3_Facet_circulator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3_Facet_circulator" "', argument " "1"" of type '" "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_Facet_circulator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_regular_triangulation_3")) SWIG_fail;
  {
    try{
      result = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *)new Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >();
    }
    catch(Bad_element_type){
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Point_range arg1 ;
  PyObject * obj0 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_Mesh_3_regular_triangulation_3",&obj0)) SWIG_fail;
  {
    try{
      Input_iterator_wrapper<Weighted_point_3,Weighted_point_3::cpp_base> it_end;
      Input_iterator_wrapper<Weighted_point_3,Weighted_point_3::cpp_base> it_begin(obj0,SWIGTYPE_p_Weighted_point_3);
      arg1=std::make_pair(it_begin,it_end);
    }
    catch(Bad_element_type){
      SWIG_fail;
    }
    catch(Not_an_iterator){
      SWIG_fail;
    }
  }
  {
    try{
      result = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *)new Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >(arg1);
    }
    catch(Bad_element_type){
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_regular_triangulation_3(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[2] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_Mesh_3_regular_triangulation_3__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      PyObject* iter=PyObject_GetIter(argv[0]);
      if (iter!=NULL){
        Py_DECREF(iter);
        _v=1;
      }
      else _v=0;
    }
    if (_v) {
      return _wrap_new_Mesh_3_regular_triangulation_3__SWIG_1(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_Mesh_3_regular_triangulation_3'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Regular_triangulation_3_wrapper()\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Regular_triangulation_3_wrapper(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Point_range)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_remove(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_remove",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_remove" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_remove" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_remove" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle * >(argp2);
  {
    try {
      (arg1)->remove((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_side_of_power_sphere(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg2 = 0 ;
  Weighted_point_3 *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Bounded_side result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_side_of_power_sphere",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_sphere" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_sphere" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_side_of_power_sphere" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_sphere" "', argument " "3"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_side_of_power_sphere" "', argument " "3"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg3 = reinterpret_cast< Weighted_point_3 * >(argp3);
  {
    try {
      result = (Bounded_side)(arg1)->side_of_power_sphere((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg2,(Weighted_point_3 const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_side_of_power_circle__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  Weighted_point_3 *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Bounded_side result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_side_of_power_circle",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_circle" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_circle" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_side_of_power_circle" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_circle" "', argument " "3"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_side_of_power_circle" "', argument " "3"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg3 = reinterpret_cast< Weighted_point_3 * >(argp3);
  {
    try {
      result = (Bounded_side)(arg1)->side_of_power_circle((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2,(Weighted_point_3 const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_side_of_power_circle__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  Weighted_point_3 *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  Bounded_side result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Mesh_3_regular_triangulation_3_side_of_power_circle",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_circle" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_circle" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_side_of_power_circle" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_circle" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_circle" "', argument " "4"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_side_of_power_circle" "', argument " "4"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg4 = reinterpret_cast< Weighted_point_3 * >(argp4);
  {
    try {
      result = (Bounded_side)(arg1)->side_of_power_circle((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg2,(int const &)*arg3,(Weighted_point_3 const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_side_of_power_circle(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_Weighted_point_3, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_side_of_power_circle__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_Weighted_point_3, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Mesh_3_regular_triangulation_3_side_of_power_circle__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_side_of_power_circle'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::side_of_power_circle(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &,Weighted_point_3 const &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::side_of_power_circle(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &,int const &,Weighted_point_3 const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_side_of_power_segment(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg2 = 0 ;
  Weighted_point_3 *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Bounded_side result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_side_of_power_segment",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_segment" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_segment" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_side_of_power_segment" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_side_of_power_segment" "', argument " "3"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_side_of_power_segment" "', argument " "3"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg3 = reinterpret_cast< Weighted_point_3 * >(argp3);
  {
    try {
      result = (Bounded_side)(arg1)->side_of_power_segment((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg2,(Weighted_point_3 const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_nearest_power_vertex",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  {
    try {
      result = (arg1)->nearest_power_vertex((Weighted_point_3 const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle(static_cast< const Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_nearest_power_vertex",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "3"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "3"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle &""'"); 
  }
  arg3 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle * >(argp3);
  {
    try {
      (arg1)->nearest_power_vertex((Weighted_point_3 const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_nearest_power_vertex",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "3"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "3"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg3 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp3);
  {
    try {
      result = (arg1)->nearest_power_vertex((Weighted_point_3 const &)*arg2,(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle(static_cast< const Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg3 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Mesh_3_regular_triangulation_3_nearest_power_vertex",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "3"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "3"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg3 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "4"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex" "', argument " "4"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle &""'"); 
  }
  arg4 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle * >(argp4);
  {
    try {
      (arg1)->nearest_power_vertex((Weighted_point_3 const &)*arg2,(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex__SWIG_2(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex__SWIG_3(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_nearest_power_vertex'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::nearest_power_vertex(Weighted_point_3 const &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::nearest_power_vertex(Weighted_point_3 const &,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::nearest_power_vertex(Weighted_point_3 const &,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::nearest_power_vertex(Weighted_point_3 const &,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "3"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "3"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg3 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp3);
  {
    try {
      result = (arg1)->nearest_power_vertex_in_cell((Weighted_point_3 const &)*arg2,(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle(static_cast< const Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Weighted_point_3 *arg2 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg3 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Weighted_point_3,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "2"" of type '" "Weighted_point_3 const &""'"); 
  }
  arg2 = reinterpret_cast< Weighted_point_3 * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "3"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "3"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg3 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "4"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell" "', argument " "4"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle &""'"); 
  }
  arg4 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle * >(argp4);
  {
    try {
      (arg1)->nearest_power_vertex_in_cell((Weighted_point_3 const &)*arg2,(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Weighted_point_3, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::nearest_power_vertex_in_cell(Weighted_point_3 const &,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::nearest_power_vertex_in_cell(Weighted_point_3 const &,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_is_Gabriel__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_is_Gabriel",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (bool)(arg1)->is_Gabriel((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_is_Gabriel__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  int *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Mesh_3_regular_triangulation_3_is_Gabriel",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      result = (bool)(arg1)->is_Gabriel((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg2,(int const &)*arg3,(int const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_is_Gabriel__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_is_Gabriel",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    try {
      result = (bool)(arg1)->is_Gabriel((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_is_Gabriel__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Edge *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_is_Gabriel",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Edge const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Edge * >(argp2);
  {
    try {
      result = (bool)(arg1)->is_Gabriel((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Edge const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_is_Gabriel__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_is_Gabriel",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_is_Gabriel" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle * >(argp2);
  {
    try {
      result = (bool)(arg1)->is_Gabriel((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_is_Gabriel(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_is_Gabriel__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_is_Gabriel__SWIG_4(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_is_Gabriel__SWIG_2(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_is_Gabriel__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Mesh_3_regular_triangulation_3_is_Gabriel__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_is_Gabriel'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::is_Gabriel(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &,int const &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::is_Gabriel(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &,int const &,int const &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::is_Gabriel(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::is_Gabriel(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Edge const &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::is_Gabriel(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_dual__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Weighted_point_3 result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_dual",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp2);
  {
    try {
      result = (arg1)->dual((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Weighted_point_3(static_cast< const Weighted_point_3& >(result))), SWIGTYPE_p_Weighted_point_3, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_dual__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg2 = 0 ;
  Weighted_point_3 *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_dual",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Weighted_point_3,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "3"" of type '" "Weighted_point_3 &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "3"" of type '" "Weighted_point_3 &""'"); 
  }
  arg3 = reinterpret_cast< Weighted_point_3 * >(argp3);
  {
    try {
      (arg1)->dual((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_dual__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Object result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_regular_triangulation_3_dual",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    try {
      result = (arg1)->dual((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Object(static_cast< const Object& >(result))), SWIGTYPE_p_Object, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_dual__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet *arg2 = 0 ;
  Object *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_dual",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Object,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "3"" of type '" "Object &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "3"" of type '" "Object &""'"); 
  }
  arg3 = reinterpret_cast< Object * >(argp3);
  {
    try {
      (arg1)->dual((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &)*arg2,*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_dual__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Object result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_regular_triangulation_3_dual",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (arg1)->dual((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Object(static_cast< const Object& >(result))), SWIGTYPE_p_Object, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_dual__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  Object *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Mesh_3_regular_triangulation_3_dual",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Object,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "4"" of type '" "Object &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_regular_triangulation_3_dual" "', argument " "4"" of type '" "Object &""'"); 
  }
  arg4 = reinterpret_cast< Object * >(argp4);
  {
    try {
      (arg1)->dual((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)*arg2,(int const &)*arg3,*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_regular_triangulation_3_dual(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_dual__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_regular_triangulation_3_dual__SWIG_2(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_Weighted_point_3, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_dual__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_dual__SWIG_4(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_Object, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_regular_triangulation_3_dual__SWIG_3(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_Object, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Mesh_3_regular_triangulation_3_dual__SWIG_5(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_regular_triangulation_3_dual'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::dual(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::dual(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &,Weighted_point_3 &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::dual(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::dual(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Facet const &,Object &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::dual(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &,int const &)\n"
    "    Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::dual(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle const &,int const &,Object &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_regular_triangulation_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg1 = (Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_regular_triangulation_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_regular_triangulation_3" "', argument " "1"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *""'"); 
  }
  arg1 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_regular_triangulation_3_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *)new SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >(static_cast< const SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___next__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___next__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try{
      result = (arg1)->__next__();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >(static_cast< const SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >& >(result))), SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next" "', argument " "2"" of type '" "SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > * >(argp2);
  {
    try{
      (arg1)->next(*arg2);
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::next()\n"
    "    SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::next(SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self(static_cast< const SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::deepcopy() const\n"
    "    SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::deepcopy(SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator ==((SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > const *)arg1)->operator !=((SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator")) SWIG_fail;
  {
    try {
      result = (SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *)new SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___iter__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___iter__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___iter__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = (arg1)->__iter__();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(static_cast< const SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try{
      result = (arg1)->next();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___next__",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___next__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try{
      result = (arg1)->__next__();
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next" "', argument " "2"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next" "', argument " "2"" of type '" "std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > &""'"); 
  }
  arg2 = reinterpret_cast< std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > * >(argp2);
  {
    try{
      (arg1)->next(*arg2);
    }
    catch(Stop_iteration){
      //TODO: throw a specify exception
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::next()\n"
    "    SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::next(std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = ((SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self(static_cast< const SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::deepcopy() const\n"
    "    SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::deepcopy(SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_hasNext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_hasNext",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_hasNext" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      result = (bool)(arg1)->hasNext();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___eq__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___eq__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___eq__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->operator ==((SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___ne__",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___ne__" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___ne__" "', argument " "2"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self * >(argp2);
  {
    try {
      result = (bool)((SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > const *)arg1)->operator !=((SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *arg1 = (SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator" "', argument " "1"" of type '" "SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *""'"); 
  }
  arg1 = reinterpret_cast< SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_Surface_index__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_Surface_index")) SWIG_fail;
  {
    try {
      result = (std::pair< int,int > *)new std::pair< int,int >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__pairT_int_int_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_Surface_index__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  int arg2 ;
  int val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  std::pair< int,int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_Mesh_3_Surface_index",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Mesh_3_Surface_index" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = static_cast< int >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_Mesh_3_Surface_index" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      result = (std::pair< int,int > *)new std::pair< int,int >(arg1,arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__pairT_int_int_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_Surface_index__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,int > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  std::pair< int,int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_Mesh_3_Surface_index",&obj0)) SWIG_fail;
  {
    std::pair< int,int > *ptr = (std::pair< int,int > *)0;
    res1 = swig::asptr(obj0, &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_Mesh_3_Surface_index" "', argument " "1"" of type '" "std::pair< int,int > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Mesh_3_Surface_index" "', argument " "1"" of type '" "std::pair< int,int > const &""'"); 
    }
    arg1 = ptr;
  }
  {
    try {
      result = (std::pair< int,int > *)new std::pair< int,int >((std::pair< int,int > const &)*arg1);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__pairT_int_int_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_Surface_index(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_Mesh_3_Surface_index__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::pair< int,int >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_Mesh_3_Surface_index__SWIG_2(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_Mesh_3_Surface_index__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_Mesh_3_Surface_index'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::pair< int,int >::pair()\n"
    "    std::pair< int,int >::pair(int,int)\n"
    "    std::pair< int,int >::pair(std::pair< int,int > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Surface_index_first_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,int > *arg1 = (std::pair< int,int > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Surface_index_first_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Surface_index_first_set" "', argument " "1"" of type '" "std::pair< int,int > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< int,int > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_Surface_index_first_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->first = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Surface_index_first_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,int > *arg1 = (std::pair< int,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Surface_index_first_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Surface_index_first_get" "', argument " "1"" of type '" "std::pair< int,int > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< int,int > * >(argp1);
  result = (int) ((arg1)->first);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Surface_index_second_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,int > *arg1 = (std::pair< int,int > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Surface_index_second_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Surface_index_second_set" "', argument " "1"" of type '" "std::pair< int,int > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< int,int > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Mesh_3_Surface_index_second_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->second = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Surface_index_second_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,int > *arg1 = (std::pair< int,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Surface_index_second_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_int_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Surface_index_second_get" "', argument " "1"" of type '" "std::pair< int,int > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< int,int > * >(argp1);
  result = (int) ((arg1)->second);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_Surface_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,int > *arg1 = (std::pair< int,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_Surface_index",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_std__pairT_int_int_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_Surface_index" "', argument " "1"" of type '" "std::pair< int,int > *""'"); 
  }
  arg1 = reinterpret_cast< std::pair< int,int > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_Surface_index_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__pairT_int_int_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_Index__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Variant< int,std::pair< int,int > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_Index")) SWIG_fail;
  {
    try {
      result = (Variant< int,std::pair< int,int > > *)new Variant< int,std::pair< int,int > >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_Index__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = 0 ;
  int temp1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  Variant< int,std::pair< int,int > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_Mesh_3_Index",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Mesh_3_Index" "', argument " "1"" of type '" "int""'");
  } 
  temp1 = static_cast< int >(val1);
  arg1 = &temp1;
  {
    try {
      result = (Variant< int,std::pair< int,int > > *)new Variant< int,std::pair< int,int > >((int const &)*arg1);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_Index__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::pair< int,int > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  Variant< int,std::pair< int,int > > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_Mesh_3_Index",&obj0)) SWIG_fail;
  {
    std::pair< int,int > *ptr = (std::pair< int,int > *)0;
    res1 = swig::asptr(obj0, &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_Mesh_3_Index" "', argument " "1"" of type '" "std::pair< int,int > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Mesh_3_Index" "', argument " "1"" of type '" "std::pair< int,int > const &""'"); 
    }
    arg1 = ptr;
  }
  {
    try {
      result = (Variant< int,std::pair< int,int > > *)new Variant< int,std::pair< int,int > >((std::pair< int,int > const &)*arg1);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Mesh_3_Index(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[2] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_Mesh_3_Index__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_Mesh_3_Index__SWIG_1(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::pair< int,int >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_Mesh_3_Index__SWIG_2(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_Mesh_3_Index'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Variant< int,std::pair< int,int > >::Variant()\n"
    "    Variant< int,std::pair< int,int > >::Variant(int const &)\n"
    "    Variant< int,std::pair< int,int > >::Variant(std::pair< int,int > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Index_is_of_first_type(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Variant< int,std::pair< int,int > > *arg1 = (Variant< int,std::pair< int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Index_is_of_first_type",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Index_is_of_first_type" "', argument " "1"" of type '" "Variant< int,std::pair< int,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< Variant< int,std::pair< int,int > > * >(argp1);
  {
    try {
      result = (bool)((Variant< int,std::pair< int,int > > const *)arg1)->is_of_first_type();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Index_is_of_second_type(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Variant< int,std::pair< int,int > > *arg1 = (Variant< int,std::pair< int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Index_is_of_second_type",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Index_is_of_second_type" "', argument " "1"" of type '" "Variant< int,std::pair< int,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< Variant< int,std::pair< int,int > > * >(argp1);
  {
    try {
      result = (bool)((Variant< int,std::pair< int,int > > const *)arg1)->is_of_second_type();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Index_get_first(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Variant< int,std::pair< int,int > > *arg1 = (Variant< int,std::pair< int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Index_get_first",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Index_get_first" "', argument " "1"" of type '" "Variant< int,std::pair< int,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< Variant< int,std::pair< int,int > > * >(argp1);
  {
    try {
      result = (int)((Variant< int,std::pair< int,int > > const *)arg1)->get_first();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Index_get_second(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Variant< int,std::pair< int,int > > *arg1 = (Variant< int,std::pair< int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  std::pair< int,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Index_get_second",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Index_get_second" "', argument " "1"" of type '" "Variant< int,std::pair< int,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< Variant< int,std::pair< int,int > > * >(argp1);
  {
    try {
      result = ((Variant< int,std::pair< int,int > > const *)arg1)->get_second();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< int,int > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Index_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Variant< int,std::pair< int,int > > *arg1 = (Variant< int,std::pair< int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Variant< int,std::pair< int,int > >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Index_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Index_deepcopy" "', argument " "1"" of type '" "Variant< int,std::pair< int,int > > const *""'"); 
  }
  arg1 = reinterpret_cast< Variant< int,std::pair< int,int > > * >(argp1);
  {
    try {
      result = ((Variant< int,std::pair< int,int > > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Variant< int,std::pair< int,int > >::Self(static_cast< const Variant< int,std::pair< int,int > >::Self& >(result))), SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Index_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Variant< int,std::pair< int,int > > *arg1 = (Variant< int,std::pair< int,int > > *) 0 ;
  Variant< int,std::pair< int,int > >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Index_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Index_deepcopy" "', argument " "1"" of type '" "Variant< int,std::pair< int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< Variant< int,std::pair< int,int > > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Index_deepcopy" "', argument " "2"" of type '" "Variant< int,std::pair< int,int > >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Index_deepcopy" "', argument " "2"" of type '" "Variant< int,std::pair< int,int > >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< Variant< int,std::pair< int,int > >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((Variant< int,std::pair< int,int > >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Index_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_Index_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Index_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Index_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Variant< int,std::pair< int,int > >::deepcopy() const\n"
    "    Variant< int,std::pair< int,int > >::deepcopy(Variant< int,std::pair< int,int > >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_Index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Variant< int,std::pair< int,int > > *arg1 = (Variant< int,std::pair< int,int > > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_Index",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_Index" "', argument " "1"" of type '" "Variant< int,std::pair< int,int > > *""'"); 
  }
  arg1 = reinterpret_cast< Variant< int,std::pair< int,int > > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_Index_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Mesh_3_Complex_3_in_triangulation_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Mesh_3_Complex_3_in_triangulation_3")) SWIG_fail;
  {
    try {
      result = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *)new C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_swap",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_swap" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_swap" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_swap" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self * >(argp2);
  {
    try {
      (arg1)->swap(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_triangulation__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_triangulation",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_triangulation" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    try {
      result = (arg1)->triangulation();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >(static_cast< const Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >& >(result))), SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_triangulation__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_triangulation",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_triangulation" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_triangulation" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_triangulation" "', argument " "2"" of type '" "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > &""'"); 
  }
  arg2 = reinterpret_cast< Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > * >(argp2);
  {
    try {
      (arg1)->triangulation(*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_triangulation(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_Complex_3_in_triangulation_3_triangulation__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Complex_3_in_triangulation_3_triangulation__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Complex_3_in_triangulation_3_triangulation'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::triangulation()\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::triangulation(Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_add_to_complex__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_Complex_3_in_triangulation_3_add_to_complex",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      (arg1)->add_to_complex((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_add_to_complex__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet *arg2 = 0 ;
  std::pair< int,int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_Complex_3_in_triangulation_3_add_to_complex",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::pair< int,int > *ptr = (std::pair< int,int > *)0;
    res3 = swig::asptr(obj2, &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "3"" of type '" "std::pair< int,int > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "3"" of type '" "std::pair< int,int > const &""'"); 
    }
    arg3 = ptr;
  }
  {
    try {
      (arg1)->add_to_complex((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &)*arg2,(std::pair< int,int > const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_add_to_complex__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  std::pair< int,int > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Mesh_3_Complex_3_in_triangulation_3_add_to_complex",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    std::pair< int,int > *ptr = (std::pair< int,int > *)0;
    res4 = swig::asptr(obj3, &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "4"" of type '" "std::pair< int,int > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_add_to_complex" "', argument " "4"" of type '" "std::pair< int,int > const &""'"); 
    }
    arg4 = ptr;
  }
  {
    try {
      (arg1)->add_to_complex((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)*arg2,(int const &)*arg3,(std::pair< int,int > const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_add_to_complex(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Mesh_3_Complex_3_in_triangulation_3_add_to_complex__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = swig::asptr(argv[2], (std::pair< int,int >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_Complex_3_in_triangulation_3_add_to_complex__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::pair< int,int >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Mesh_3_Complex_3_in_triangulation_3_add_to_complex__SWIG_2(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Complex_3_in_triangulation_3_add_to_complex'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::add_to_complex(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &,int const &)\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::add_to_complex(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &,std::pair< int,int > const &)\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::add_to_complex(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &,int const &,std::pair< int,int > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_remove_from_complex__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_remove_from_complex",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_remove_from_complex" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_remove_from_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_remove_from_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle * >(argp2);
  {
    try {
      (arg1)->remove_from_complex((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_remove_from_complex__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_remove_from_complex",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_remove_from_complex" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_remove_from_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_remove_from_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    try {
      (arg1)->remove_from_complex((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_remove_from_complex__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_Complex_3_in_triangulation_3_remove_from_complex",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_remove_from_complex" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_remove_from_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_remove_from_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_Complex_3_in_triangulation_3_remove_from_complex" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      (arg1)->remove_from_complex((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_remove_from_complex(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Complex_3_in_triangulation_3_remove_from_complex__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Complex_3_in_triangulation_3_remove_from_complex__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Mesh_3_Complex_3_in_triangulation_3_remove_from_complex__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Complex_3_in_triangulation_3_remove_from_complex'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::remove_from_complex(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::remove_from_complex(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &)\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::remove_from_complex(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_set_subdomain_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_Complex_3_in_triangulation_3_set_subdomain_index",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_subdomain_index" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_subdomain_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_subdomain_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_subdomain_index" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      (arg1)->set_subdomain_index((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_set_surface_index__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet *arg2 = 0 ;
  std::pair< int,int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_Complex_3_in_triangulation_3_set_surface_index",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_surface_index" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_surface_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_surface_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::pair< int,int > *ptr = (std::pair< int,int > *)0;
    res3 = swig::asptr(obj2, &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_surface_index" "', argument " "3"" of type '" "std::pair< int,int > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_surface_index" "', argument " "3"" of type '" "std::pair< int,int > const &""'"); 
    }
    arg3 = ptr;
  }
  {
    try {
      (arg1)->set_surface_index((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &)*arg2,(std::pair< int,int > const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_set_surface_index__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  std::pair< int,int > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Mesh_3_Complex_3_in_triangulation_3_set_surface_index",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_surface_index" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_surface_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_surface_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_surface_index" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    std::pair< int,int > *ptr = (std::pair< int,int > *)0;
    res4 = swig::asptr(obj3, &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_surface_index" "', argument " "4"" of type '" "std::pair< int,int > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_surface_index" "', argument " "4"" of type '" "std::pair< int,int > const &""'"); 
    }
    arg4 = ptr;
  }
  {
    try {
      (arg1)->set_surface_index((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)*arg2,(int const &)*arg3,(std::pair< int,int > const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_set_surface_index(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = swig::asptr(argv[2], (std::pair< int,int >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Mesh_3_Complex_3_in_triangulation_3_set_surface_index__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::pair< int,int >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Mesh_3_Complex_3_in_triangulation_3_set_surface_index__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Complex_3_in_triangulation_3_set_surface_index'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::set_surface_index(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &,std::pair< int,int > const &)\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::set_surface_index(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &,int const &,std::pair< int,int > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_set_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle *arg2 = 0 ;
  Variant< int,std::pair< int,int > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_Complex_3_in_triangulation_3_set_index",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_index" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_index" "', argument " "3"" of type '" "Variant< int,std::pair< int,int > > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_index" "', argument " "3"" of type '" "Variant< int,std::pair< int,int > > const &""'"); 
  }
  arg3 = reinterpret_cast< Variant< int,std::pair< int,int > > * >(argp3);
  {
    try {
      (arg1)->set_index((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &)*arg2,(Variant< int,std::pair< int,int > > const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_set_dimension(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_Complex_3_in_triangulation_3_set_dimension",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_dimension" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_dimension" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_dimension" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_Complex_3_in_triangulation_3_set_dimension" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      (arg1)->set_dimension((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_number_of_cells(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_number_of_cells",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_number_of_cells" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    try {
      result = (int)(arg1)->number_of_cells();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_number_of_facets(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_number_of_facets",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_number_of_facets" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    try {
      result = (int)(arg1)->number_of_facets();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_is_in_complex__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_is_in_complex",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_is_in_complex" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_is_in_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_is_in_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle * >(argp2);
  {
    try {
      result = (bool)(arg1)->is_in_complex((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_is_in_complex__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_is_in_complex",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_is_in_complex" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_is_in_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_is_in_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    try {
      result = (bool)(arg1)->is_in_complex((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_is_in_complex__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_Complex_3_in_triangulation_3_is_in_complex",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_is_in_complex" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_is_in_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_is_in_complex" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_Complex_3_in_triangulation_3_is_in_complex" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (bool)(arg1)->is_in_complex((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_is_in_complex(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Complex_3_in_triangulation_3_is_in_complex__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Complex_3_in_triangulation_3_is_in_complex__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Mesh_3_Complex_3_in_triangulation_3_is_in_complex__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Complex_3_in_triangulation_3_is_in_complex'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::is_in_complex(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::is_in_complex(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &)\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::is_in_complex(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_subdomain_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_subdomain_index",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_subdomain_index" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_subdomain_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_subdomain_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle * >(argp2);
  {
    try {
      result = (int)(arg1)->subdomain_index((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_surface_index__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  std::pair< int,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_surface_index",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_surface_index" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *ptr = (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_surface_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_surface_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &""'"); 
    }
    arg2 = ptr;
  }
  {
    try {
      result = (arg1)->surface_index((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< int,int > >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_surface_index__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle *arg2 = 0 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  std::pair< int,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Mesh_3_Complex_3_in_triangulation_3_surface_index",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_surface_index" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_surface_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_surface_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle * >(argp2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Mesh_3_Complex_3_in_triangulation_3_surface_index" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      result = (arg1)->surface_index((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &)*arg2,(int const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< int,int > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_surface_index(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Complex_3_in_triangulation_3_surface_index__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Mesh_3_Complex_3_in_triangulation_3_surface_index__SWIG_1(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Complex_3_in_triangulation_3_surface_index'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::surface_index(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet const &)\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::surface_index(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle const &,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_in_dimension(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_in_dimension",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_in_dimension" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_in_dimension" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_in_dimension" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle * >(argp2);
  {
    try {
      result = (int)(arg1)->in_dimension((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Variant< int,std::pair< int,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_index",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_index" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_index" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle * >(argp2);
  {
    try {
      result = (arg1)->index((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Variant< int,std::pair< int,int > >(static_cast< const Variant< int,std::pair< int,int > >& >(result))), SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_cells(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_iterator result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_cells",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_cells" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    try {
      result = (arg1)->cells();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_iterator(static_cast< const C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_iterator& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_facets(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet_iterator result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_facets",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_facets" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    try {
      result = (arg1)->facets();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet_iterator(static_cast< const C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet_iterator& >(result))), SWIGTYPE_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_output_to_medit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  char *arg2 = (char *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_output_to_medit",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_output_to_medit" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_output_to_medit" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  {
    try {
      (arg1)->output_to_medit((char const *)arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Mesh_3_Complex_3_in_triangulation_3_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_deepcopy" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > const *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    try {
      result = ((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > const *)arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self(static_cast< const C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self& >(result))), SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_deepcopy" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_deepcopy" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_deepcopy" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Mesh_3_Complex_3_in_triangulation_3_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Mesh_3_Complex_3_in_triangulation_3_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Mesh_3_Complex_3_in_triangulation_3_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::deepcopy() const\n"
    "    C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::deepcopy(C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Mesh_3_Complex_3_in_triangulation_3_same_internal_object(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Mesh_3_Complex_3_in_triangulation_3_same_internal_object",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Mesh_3_Complex_3_in_triangulation_3_same_internal_object" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Mesh_3_Complex_3_in_triangulation_3_same_internal_object" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Mesh_3_Complex_3_in_triangulation_3_same_internal_object" "', argument " "2"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self * >(argp2);
  {
    try {
      result = (bool)(arg1)->same_internal_object((C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Mesh_3_Complex_3_in_triangulation_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Mesh_3_Complex_3_in_triangulation_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Mesh_3_Complex_3_in_triangulation_3" "', argument " "1"" of type '" "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Mesh_3_Complex_3_in_triangulation_3_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Polyhedral_mesh_domain_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > > *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_Polyhedral_mesh_domain_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_Polyhedral_mesh_domain_3" "', argument " "1"" of type '" "Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Polyhedral_mesh_domain_3" "', argument " "1"" of type '" "Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > > &""'"); 
  }
  arg1 = reinterpret_cast< Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > > * >(argp1);
  {
    try {
      result = (Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *)new Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >(*arg1);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Polyhedral_mesh_domain_3_index_from_surface_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  std::pair< int,int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Variant< int,std::pair< int,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Polyhedral_mesh_domain_3_index_from_surface_index",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Polyhedral_mesh_domain_3_index_from_surface_index" "', argument " "1"" of type '" "Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    std::pair< int,int > *ptr = (std::pair< int,int > *)0;
    res2 = swig::asptr(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Polyhedral_mesh_domain_3_index_from_surface_index" "', argument " "2"" of type '" "std::pair< int,int > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Polyhedral_mesh_domain_3_index_from_surface_index" "', argument " "2"" of type '" "std::pair< int,int > const &""'"); 
    }
    arg2 = ptr;
  }
  {
    try {
      result = (arg1)->index_from_surface_index((std::pair< int,int > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Variant< int,std::pair< int,int > >(static_cast< const Variant< int,std::pair< int,int > >& >(result))), SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Polyhedral_mesh_domain_3_index_from_subdomain_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  int *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int temp2 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Variant< int,std::pair< int,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Polyhedral_mesh_domain_3_index_from_subdomain_index",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Polyhedral_mesh_domain_3_index_from_subdomain_index" "', argument " "1"" of type '" "Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Polyhedral_mesh_domain_3_index_from_subdomain_index" "', argument " "2"" of type '" "int""'");
  } 
  temp2 = static_cast< int >(val2);
  arg2 = &temp2;
  {
    try {
      result = (arg1)->index_from_subdomain_index((int const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Variant< int,std::pair< int,int > >(static_cast< const Variant< int,std::pair< int,int > >& >(result))), SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Polyhedral_mesh_domain_3_surface_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  Variant< int,std::pair< int,int > > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  std::pair< int,int > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Polyhedral_mesh_domain_3_surface_index",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Polyhedral_mesh_domain_3_surface_index" "', argument " "1"" of type '" "Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Polyhedral_mesh_domain_3_surface_index" "', argument " "2"" of type '" "Variant< int,std::pair< int,int > > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Polyhedral_mesh_domain_3_surface_index" "', argument " "2"" of type '" "Variant< int,std::pair< int,int > > const &""'"); 
  }
  arg2 = reinterpret_cast< Variant< int,std::pair< int,int > > * >(argp2);
  {
    try {
      result = (arg1)->surface_index((Variant< int,std::pair< int,int > > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = swig::from(static_cast< std::pair< int,int > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Polyhedral_mesh_domain_3_subdomain_index(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  Variant< int,std::pair< int,int > > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Polyhedral_mesh_domain_3_subdomain_index",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Polyhedral_mesh_domain_3_subdomain_index" "', argument " "1"" of type '" "Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_VariantT_int_std__pairT_int_int_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Polyhedral_mesh_domain_3_subdomain_index" "', argument " "2"" of type '" "Variant< int,std::pair< int,int > > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Polyhedral_mesh_domain_3_subdomain_index" "', argument " "2"" of type '" "Variant< int,std::pair< int,int > > const &""'"); 
  }
  arg2 = reinterpret_cast< Variant< int,std::pair< int,int > > * >(argp2);
  {
    try {
      result = (int)(arg1)->subdomain_index((Variant< int,std::pair< int,int > > const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Polyhedral_mesh_domain_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *arg1 = (Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Polyhedral_mesh_domain_3",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Polyhedral_mesh_domain_3" "', argument " "1"" of type '" "Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *""'"); 
  }
  arg1 = reinterpret_cast< Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Polyhedral_mesh_domain_3_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Default_mesh_criteria(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Default_mesh_criteria")) SWIG_fail;
  {
    try {
      result = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *)new Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Default_mesh_criteria_edge_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *arg1 = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *) 0 ;
  double *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double temp2 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Default_mesh_criteria_edge_size",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Default_mesh_criteria_edge_size" "', argument " "1"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Default_mesh_criteria_edge_size" "', argument " "2"" of type '" "double""'");
  } 
  temp2 = static_cast< double >(val2);
  arg2 = &temp2;
  {
    try {
      result = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *) &(arg1)->edge_size((double const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Default_mesh_criteria_facet_angle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *arg1 = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Default_mesh_criteria_facet_angle",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Default_mesh_criteria_facet_angle" "', argument " "1"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Default_mesh_criteria_facet_angle" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      result = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *) &(arg1)->facet_angle(arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Default_mesh_criteria_facet_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *arg1 = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *) 0 ;
  double *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double temp2 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Default_mesh_criteria_facet_size",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Default_mesh_criteria_facet_size" "', argument " "1"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Default_mesh_criteria_facet_size" "', argument " "2"" of type '" "double""'");
  } 
  temp2 = static_cast< double >(val2);
  arg2 = &temp2;
  {
    try {
      result = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *) &(arg1)->facet_size((double const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Default_mesh_criteria_facet_distance(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *arg1 = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *) 0 ;
  double *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double temp2 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Default_mesh_criteria_facet_distance",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Default_mesh_criteria_facet_distance" "', argument " "1"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Default_mesh_criteria_facet_distance" "', argument " "2"" of type '" "double""'");
  } 
  temp2 = static_cast< double >(val2);
  arg2 = &temp2;
  {
    try {
      result = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *) &(arg1)->facet_distance((double const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Default_mesh_criteria_facet_topology(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *arg1 = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *) 0 ;
  Mesh_facet_topology arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Default_mesh_criteria_facet_topology",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Default_mesh_criteria_facet_topology" "', argument " "1"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Default_mesh_criteria_facet_topology" "', argument " "2"" of type '" "Mesh_facet_topology""'");
  } 
  arg2 = static_cast< Mesh_facet_topology >(val2);
  {
    try {
      result = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *) &(arg1)->facet_topology(arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Default_mesh_criteria_cell_radius_edge_ratio(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *arg1 = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Default_mesh_criteria_cell_radius_edge_ratio",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Default_mesh_criteria_cell_radius_edge_ratio" "', argument " "1"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Default_mesh_criteria_cell_radius_edge_ratio" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      result = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *) &(arg1)->cell_radius_edge_ratio(arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Default_mesh_criteria_cell_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *arg1 = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *) 0 ;
  double *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double temp2 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Default_mesh_criteria_cell_size",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Default_mesh_criteria_cell_size" "', argument " "1"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Default_mesh_criteria_cell_size" "', argument " "2"" of type '" "double""'");
  } 
  temp2 = static_cast< double >(val2);
  arg2 = &temp2;
  {
    try {
      result = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *) &(arg1)->cell_size((double const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Default_mesh_criteria_deepcopy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *arg1 = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Default_mesh_criteria_deepcopy",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Default_mesh_criteria_deepcopy" "', argument " "1"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > * >(argp1);
  {
    try {
      result = (arg1)->deepcopy();
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self(static_cast< const Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self& >(result))), SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Default_mesh_criteria_deepcopy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *arg1 = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *) 0 ;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Default_mesh_criteria_deepcopy",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Default_mesh_criteria_deepcopy" "', argument " "1"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Default_mesh_criteria_deepcopy" "', argument " "2"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Default_mesh_criteria_deepcopy" "', argument " "2"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self const &""'"); 
  }
  arg2 = reinterpret_cast< Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self * >(argp2);
  {
    try {
      (arg1)->deepcopy((Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self const &)*arg2);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Default_mesh_criteria_deepcopy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  Py_ssize_t ii;
  
  if (!PyTuple_Check(args)) SWIG_fail;
  argc = args ? PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Default_mesh_criteria_deepcopy__SWIG_0(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Default_mesh_criteria_deepcopy__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Default_mesh_criteria_deepcopy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::deepcopy()\n"
    "    Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::deepcopy(Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_Default_mesh_criteria(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *arg1 = (Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Default_mesh_criteria",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Default_mesh_criteria" "', argument " "1"" of type '" "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *""'"); 
  }
  arg1 = reinterpret_cast< Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > * >(argp1);
  {
    try {
      delete arg1;
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Default_mesh_criteria_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_exude_mesh_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper *arg1 = 0 ;
  double arg2 ;
  double arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Mesh_optimization_return_code result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:exude_mesh_3",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "exude_mesh_3" "', argument " "1"" of type '" "Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "exude_mesh_3" "', argument " "1"" of type '" "Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper &""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper * >(argp1);
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "exude_mesh_3" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "exude_mesh_3" "', argument " "3"" of type '" "double""'");
  } 
  arg3 = static_cast< double >(val3);
  {
    try {
      result = (Mesh_optimization_return_code)exude_mesh_3(*arg1,arg2,arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_perturb_mesh_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper *arg1 = 0 ;
  Polyhedral_mesh_domain_3_SWIG_wrapper *arg2 = 0 ;
  double arg3 ;
  double arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  double val3 ;
  int ecode3 = 0 ;
  double val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  Mesh_optimization_return_code result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:perturb_mesh_3",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "perturb_mesh_3" "', argument " "1"" of type '" "Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "perturb_mesh_3" "', argument " "1"" of type '" "Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper &""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "perturb_mesh_3" "', argument " "2"" of type '" "Polyhedral_mesh_domain_3_SWIG_wrapper const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "perturb_mesh_3" "', argument " "2"" of type '" "Polyhedral_mesh_domain_3_SWIG_wrapper const &""'"); 
  }
  arg2 = reinterpret_cast< Polyhedral_mesh_domain_3_SWIG_wrapper * >(argp2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "perturb_mesh_3" "', argument " "3"" of type '" "double""'");
  } 
  arg3 = static_cast< double >(val3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "perturb_mesh_3" "', argument " "4"" of type '" "double""'");
  } 
  arg4 = static_cast< double >(val4);
  {
    try {
      result = (Mesh_optimization_return_code)perturb_mesh_3(*arg1,(Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > const &)*arg2,arg3,arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_lloyd_optimize_mesh_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper *arg1 = 0 ;
  Polyhedral_mesh_domain_3_SWIG_wrapper *arg2 = 0 ;
  double arg3 ;
  int arg4 ;
  double arg5 ;
  double arg6 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  double val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  double val5 ;
  int ecode5 = 0 ;
  double val6 ;
  int ecode6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  Mesh_optimization_return_code result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:lloyd_optimize_mesh_3",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "lloyd_optimize_mesh_3" "', argument " "1"" of type '" "Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "lloyd_optimize_mesh_3" "', argument " "1"" of type '" "Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper &""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "lloyd_optimize_mesh_3" "', argument " "2"" of type '" "Polyhedral_mesh_domain_3_SWIG_wrapper const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "lloyd_optimize_mesh_3" "', argument " "2"" of type '" "Polyhedral_mesh_domain_3_SWIG_wrapper const &""'"); 
  }
  arg2 = reinterpret_cast< Polyhedral_mesh_domain_3_SWIG_wrapper * >(argp2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "lloyd_optimize_mesh_3" "', argument " "3"" of type '" "double""'");
  } 
  arg3 = static_cast< double >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "lloyd_optimize_mesh_3" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "lloyd_optimize_mesh_3" "', argument " "5"" of type '" "double""'");
  } 
  arg5 = static_cast< double >(val5);
  ecode6 = SWIG_AsVal_double(obj5, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "lloyd_optimize_mesh_3" "', argument " "6"" of type '" "double""'");
  } 
  arg6 = static_cast< double >(val6);
  {
    try {
      result = (Mesh_optimization_return_code)lloyd_optimize_mesh_3(*arg1,(Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > const &)*arg2,arg3,arg4,arg5,arg6);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_odt_optimize_mesh_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper *arg1 = 0 ;
  Polyhedral_mesh_domain_3_SWIG_wrapper *arg2 = 0 ;
  double arg3 ;
  std::size_t arg4 ;
  double arg5 ;
  double arg6 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  double val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  double val5 ;
  int ecode5 = 0 ;
  double val6 ;
  int ecode6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  Mesh_optimization_return_code result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:odt_optimize_mesh_3",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "odt_optimize_mesh_3" "', argument " "1"" of type '" "Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "odt_optimize_mesh_3" "', argument " "1"" of type '" "Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper &""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "odt_optimize_mesh_3" "', argument " "2"" of type '" "Polyhedral_mesh_domain_3_SWIG_wrapper const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "odt_optimize_mesh_3" "', argument " "2"" of type '" "Polyhedral_mesh_domain_3_SWIG_wrapper const &""'"); 
  }
  arg2 = reinterpret_cast< Polyhedral_mesh_domain_3_SWIG_wrapper * >(argp2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "odt_optimize_mesh_3" "', argument " "3"" of type '" "double""'");
  } 
  arg3 = static_cast< double >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "odt_optimize_mesh_3" "', argument " "4"" of type '" "std::size_t""'");
  } 
  arg4 = static_cast< std::size_t >(val4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "odt_optimize_mesh_3" "', argument " "5"" of type '" "double""'");
  } 
  arg5 = static_cast< double >(val5);
  ecode6 = SWIG_AsVal_double(obj5, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "odt_optimize_mesh_3" "', argument " "6"" of type '" "double""'");
  } 
  arg6 = static_cast< double >(val6);
  {
    try {
      result = (Mesh_optimization_return_code)odt_optimize_mesh_3(*arg1,(Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > const &)*arg2,arg3,arg4,arg5,arg6);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_make_mesh_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Polyhedral_mesh_domain_3_SWIG_wrapper *arg1 = 0 ;
  Default_mesh_criteria_SWIG_wrapper *arg2 = 0 ;
  Mesh_3_parameters *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:make_mesh_3",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0  | 0);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "make_mesh_3" "', argument " "1"" of type '" "Polyhedral_mesh_domain_3_SWIG_wrapper const &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "make_mesh_3" "', argument " "1"" of type '" "Polyhedral_mesh_domain_3_SWIG_wrapper const &""'"); 
  }
  arg1 = reinterpret_cast< Polyhedral_mesh_domain_3_SWIG_wrapper * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "make_mesh_3" "', argument " "2"" of type '" "Default_mesh_criteria_SWIG_wrapper const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "make_mesh_3" "', argument " "2"" of type '" "Default_mesh_criteria_SWIG_wrapper const &""'"); 
  }
  arg2 = reinterpret_cast< Default_mesh_criteria_SWIG_wrapper * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Mesh_3_parameters,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "make_mesh_3" "', argument " "3"" of type '" "Mesh_3_parameters const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "make_mesh_3" "', argument " "3"" of type '" "Mesh_3_parameters const &""'"); 
  }
  arg3 = reinterpret_cast< Mesh_3_parameters * >(argp3);
  {
    try {
      result = make_mesh_3((Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > const &)*arg1,(Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > const &)*arg2,(Mesh_3_parameters const &)*arg3);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj((new Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper(static_cast< const Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper& >(result))), SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_refine_mesh_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper *arg1 = 0 ;
  Polyhedral_mesh_domain_3_SWIG_wrapper *arg2 = 0 ;
  Default_mesh_criteria_SWIG_wrapper *arg3 = 0 ;
  Mesh_3_parameters *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:refine_mesh_3",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "refine_mesh_3" "', argument " "1"" of type '" "Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "refine_mesh_3" "', argument " "1"" of type '" "Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper &""'"); 
  }
  arg1 = reinterpret_cast< Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "refine_mesh_3" "', argument " "2"" of type '" "Polyhedral_mesh_domain_3_SWIG_wrapper const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "refine_mesh_3" "', argument " "2"" of type '" "Polyhedral_mesh_domain_3_SWIG_wrapper const &""'"); 
  }
  arg2 = reinterpret_cast< Polyhedral_mesh_domain_3_SWIG_wrapper * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "refine_mesh_3" "', argument " "3"" of type '" "Default_mesh_criteria_SWIG_wrapper const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "refine_mesh_3" "', argument " "3"" of type '" "Default_mesh_criteria_SWIG_wrapper const &""'"); 
  }
  arg3 = reinterpret_cast< Default_mesh_criteria_SWIG_wrapper * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_Mesh_3_parameters,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "refine_mesh_3" "', argument " "4"" of type '" "Mesh_3_parameters const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "refine_mesh_3" "', argument " "4"" of type '" "Mesh_3_parameters const &""'"); 
  }
  arg4 = reinterpret_cast< Mesh_3_parameters * >(argp4);
  {
    try {
      refine_mesh_3(*arg1,(Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > const &)*arg2,(Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > const &)*arg3,(Mesh_3_parameters const &)*arg4);
    } catch (std::exception &e) {
      std::string error_msg("Error in SWIG_CGAL code. Here is the text of the C++ exception:\n");
      error_msg += e.what();
      PyErr_SetString(PyExc_Exception, error_msg.c_str());
      SWIG_fail;
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


static PyMethodDef SwigMethods[] = {
	 { (char *)"SWIG_PyInstanceMethod_New", (PyCFunction)SWIG_PyInstanceMethod_New, METH_O, NULL},
	 { (char *)"VERTEX_swigconstant", VERTEX_swigconstant, METH_VARARGS, NULL},
	 { (char *)"EDGE_swigconstant", EDGE_swigconstant, METH_VARARGS, NULL},
	 { (char *)"FACET_swigconstant", FACET_swigconstant, METH_VARARGS, NULL},
	 { (char *)"CELL_swigconstant", CELL_swigconstant, METH_VARARGS, NULL},
	 { (char *)"OUTSIDE_CONVEX_HULL_swigconstant", OUTSIDE_CONVEX_HULL_swigconstant, METH_VARARGS, NULL},
	 { (char *)"OUTSIDE_AFFINE_HULL_swigconstant", OUTSIDE_AFFINE_HULL_swigconstant, METH_VARARGS, NULL},
	 { (char *)"FACET_VERTICES_ON_SURFACE_swigconstant", FACET_VERTICES_ON_SURFACE_swigconstant, METH_VARARGS, NULL},
	 { (char *)"FACET_VERTICES_ON_SAME_SURFACE_PATCH_swigconstant", FACET_VERTICES_ON_SAME_SURFACE_PATCH_swigconstant, METH_VARARGS, NULL},
	 { (char *)"FACET_VERTICES_ON_SAME_SURFACE_PATCH_WITH_ADJACENCY_CHECK_swigconstant", FACET_VERTICES_ON_SAME_SURFACE_PATCH_WITH_ADJACENCY_CHECK_swigconstant, METH_VARARGS, NULL},
	 { (char *)"BOUND_REACHED_swigconstant", BOUND_REACHED_swigconstant, METH_VARARGS, NULL},
	 { (char *)"TIME_LIMIT_REACHED_swigconstant", TIME_LIMIT_REACHED_swigconstant, METH_VARARGS, NULL},
	 { (char *)"CANT_IMPROVE_ANYMORE_swigconstant", CANT_IMPROVE_ANYMORE_swigconstant, METH_VARARGS, NULL},
	 { (char *)"CONVERGENCE_REACHED_swigconstant", CONVERGENCE_REACHED_swigconstant, METH_VARARGS, NULL},
	 { (char *)"MAX_ITERATION_NUMBER_REACHED_swigconstant", MAX_ITERATION_NUMBER_REACHED_swigconstant, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_parameters", _wrap_new_Mesh_3_parameters, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_parameters_set_lloyd", _wrap_Mesh_3_parameters_set_lloyd, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_parameters_set_odt", _wrap_Mesh_3_parameters_set_odt, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_parameters_set_perturb", _wrap_Mesh_3_parameters_set_perturb, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_parameters_set_exude", _wrap_Mesh_3_parameters_set_exude, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_parameters_deepcopy", _wrap_Mesh_3_parameters_deepcopy, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_parameters", _wrap_delete_Mesh_3_parameters, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_parameters_swigregister", Mesh_3_parameters_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_Quality", _wrap_new_Mesh_3_Quality, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Quality_first_set", _wrap_Mesh_3_Quality_first_set, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Quality_first_get", _wrap_Mesh_3_Quality_first_get, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Quality_second_set", _wrap_Mesh_3_Quality_second_set, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Quality_second_get", _wrap_Mesh_3_Quality_second_get, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_Quality", _wrap_delete_Mesh_3_Quality, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Quality_swigregister", Mesh_3_Quality_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_Badness", _wrap_new_Mesh_3_Badness, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Badness_empty", _wrap_Mesh_3_Badness_empty, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Badness_value", _wrap_Mesh_3_Badness_value, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Badness_deepcopy", _wrap_Mesh_3_Badness_deepcopy, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_Badness", _wrap_delete_Mesh_3_Badness, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Badness_swigregister", Mesh_3_Badness_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Object", _wrap_new_Object, METH_VARARGS, NULL},
	 { (char *)"Object_is_Point_2", _wrap_Object_is_Point_2, METH_VARARGS, NULL},
	 { (char *)"Object_get_Point_2", _wrap_Object_get_Point_2, METH_VARARGS, NULL},
	 { (char *)"Object_is_Point_3", _wrap_Object_is_Point_3, METH_VARARGS, NULL},
	 { (char *)"Object_get_Point_3", _wrap_Object_get_Point_3, METH_VARARGS, NULL},
	 { (char *)"Object_is_Triangle_2", _wrap_Object_is_Triangle_2, METH_VARARGS, NULL},
	 { (char *)"Object_get_Triangle_2", _wrap_Object_get_Triangle_2, METH_VARARGS, NULL},
	 { (char *)"Object_is_Triangle_3", _wrap_Object_is_Triangle_3, METH_VARARGS, NULL},
	 { (char *)"Object_get_Triangle_3", _wrap_Object_get_Triangle_3, METH_VARARGS, NULL},
	 { (char *)"Object_is_Segment_3", _wrap_Object_is_Segment_3, METH_VARARGS, NULL},
	 { (char *)"Object_get_Segment_3", _wrap_Object_get_Segment_3, METH_VARARGS, NULL},
	 { (char *)"Object_is_Segment_2", _wrap_Object_is_Segment_2, METH_VARARGS, NULL},
	 { (char *)"Object_get_Segment_2", _wrap_Object_get_Segment_2, METH_VARARGS, NULL},
	 { (char *)"Object_is_Line_3", _wrap_Object_is_Line_3, METH_VARARGS, NULL},
	 { (char *)"Object_get_Line_3", _wrap_Object_get_Line_3, METH_VARARGS, NULL},
	 { (char *)"Object_is_Line_2", _wrap_Object_is_Line_2, METH_VARARGS, NULL},
	 { (char *)"Object_get_Line_2", _wrap_Object_get_Line_2, METH_VARARGS, NULL},
	 { (char *)"Object_is_Plane_3", _wrap_Object_is_Plane_3, METH_VARARGS, NULL},
	 { (char *)"Object_get_Plane_3", _wrap_Object_get_Plane_3, METH_VARARGS, NULL},
	 { (char *)"Object_is_Ray_2", _wrap_Object_is_Ray_2, METH_VARARGS, NULL},
	 { (char *)"Object_get_Ray_2", _wrap_Object_get_Ray_2, METH_VARARGS, NULL},
	 { (char *)"Object_is_Ray_3", _wrap_Object_is_Ray_3, METH_VARARGS, NULL},
	 { (char *)"Object_get_Ray_3", _wrap_Object_get_Ray_3, METH_VARARGS, NULL},
	 { (char *)"Object_empty", _wrap_Object_empty, METH_VARARGS, NULL},
	 { (char *)"delete_Object", _wrap_delete_Object, METH_VARARGS, NULL},
	 { (char *)"Object_swigregister", Object_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Ref_Locate_type_3", _wrap_new_Ref_Locate_type_3, METH_VARARGS, NULL},
	 { (char *)"Ref_Locate_type_3_set", _wrap_Ref_Locate_type_3_set, METH_VARARGS, NULL},
	 { (char *)"Ref_Locate_type_3_object", _wrap_Ref_Locate_type_3_object, METH_VARARGS, NULL},
	 { (char *)"Ref_Locate_type_3_deepcopy", _wrap_Ref_Locate_type_3_deepcopy, METH_VARARGS, NULL},
	 { (char *)"delete_Ref_Locate_type_3", _wrap_delete_Ref_Locate_type_3, METH_VARARGS, NULL},
	 { (char *)"Ref_Locate_type_3_swigregister", Ref_Locate_type_3_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_Cell_handle", _wrap_new_Mesh_3_regular_triangulation_3_Cell_handle, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_vertex", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_vertex, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_neighbor", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_neighbor, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_index", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_set_vertex", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_vertex, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_set_vertices", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_vertices, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_set_neighbor", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_neighbor, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_neighbors, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_is_valid", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_valid, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_has_vertex", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_vertex, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_has_neighbor, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle___lt__", _wrap_Mesh_3_regular_triangulation_3_Cell_handle___lt__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle___gt__", _wrap_Mesh_3_regular_triangulation_3_Cell_handle___gt__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle___le__", _wrap_Mesh_3_regular_triangulation_3_Cell_handle___le__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle___ge__", _wrap_Mesh_3_regular_triangulation_3_Cell_handle___ge__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle___eq__", _wrap_Mesh_3_regular_triangulation_3_Cell_handle___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle___ne__", _wrap_Mesh_3_regular_triangulation_3_Cell_handle___ne__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle___hash__", _wrap_Mesh_3_regular_triangulation_3_Cell_handle___hash__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_deepcopy", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_subdomain_index", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_subdomain_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_set_subdomain_index", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_subdomain_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_is_facet_on_surface", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_facet_on_surface, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_set_facet_on_surface", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_facet_on_surface, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_is_facet_visited", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_is_facet_visited, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_set_facet_visited", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_facet_visited, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_get_facet_surface_center", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_get_facet_surface_center, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_set_facet_surface_center", _wrap_Mesh_3_regular_triangulation_3_Cell_handle_set_facet_surface_center, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_Cell_handle", _wrap_delete_Mesh_3_regular_triangulation_3_Cell_handle, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_handle_swigregister", Mesh_3_regular_triangulation_3_Cell_handle_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_Vertex_handle", _wrap_new_Mesh_3_regular_triangulation_3_Vertex_handle, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_point", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_point, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_cell", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_cell, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_set_cell", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_set_cell, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_set_point", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_set_point, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_is_valid", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_is_valid, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle___lt__", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle___lt__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle___gt__", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle___gt__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle___le__", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle___le__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle___ge__", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle___ge__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle___eq__", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle___ne__", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle___ne__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle___hash__", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle___hash__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_in_dimension", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_in_dimension, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_set_dimension", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_set_dimension, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_index", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_set_index", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_set_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_meshing_info", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_meshing_info, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_set_meshing_info", _wrap_Mesh_3_regular_triangulation_3_Vertex_handle_set_meshing_info, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_Vertex_handle", _wrap_delete_Mesh_3_regular_triangulation_3_Vertex_handle, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Vertex_handle_swigregister", Mesh_3_regular_triangulation_3_Vertex_handle_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_Facet", _wrap_new_Mesh_3_regular_triangulation_3_Facet, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_first_set", _wrap_Mesh_3_regular_triangulation_3_Facet_first_set, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_first_get", _wrap_Mesh_3_regular_triangulation_3_Facet_first_get, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_second_set", _wrap_Mesh_3_regular_triangulation_3_Facet_second_set, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_second_get", _wrap_Mesh_3_regular_triangulation_3_Facet_second_get, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_Facet", _wrap_delete_Mesh_3_regular_triangulation_3_Facet, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_swigregister", Mesh_3_regular_triangulation_3_Facet_swigregister, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Edge_first_set", _wrap_Mesh_3_regular_triangulation_3_Edge_first_set, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Edge_first_get", _wrap_Mesh_3_regular_triangulation_3_Edge_first_get, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Edge_second_set", _wrap_Mesh_3_regular_triangulation_3_Edge_second_set, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Edge_second_get", _wrap_Mesh_3_regular_triangulation_3_Edge_second_get, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Edge_third_set", _wrap_Mesh_3_regular_triangulation_3_Edge_third_set, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Edge_third_get", _wrap_Mesh_3_regular_triangulation_3_Edge_third_get, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_Edge", _wrap_new_Mesh_3_regular_triangulation_3_Edge, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Edge_deepcopy", _wrap_Mesh_3_regular_triangulation_3_Edge_deepcopy, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_Edge", _wrap_delete_Mesh_3_regular_triangulation_3_Edge, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Edge_swigregister", Mesh_3_regular_triangulation_3_Edge_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_Internal_Triangulation_3_Mesh_3_regular_triangulation_3", _wrap_delete_Internal_Triangulation_3_Mesh_3_regular_triangulation_3, METH_VARARGS, NULL},
	 { (char *)"new_Internal_Triangulation_3_Mesh_3_regular_triangulation_3", _wrap_new_Internal_Triangulation_3_Mesh_3_regular_triangulation_3, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_clear", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_clear, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_dimension", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_dimension, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_vertices", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_vertices, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_cells", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_cells, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_vertex, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_infinite_cell, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_facets", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_facets, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_edges", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_edges, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_cells", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_cells, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_facets", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_facets, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_edges", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_number_of_finite_edges, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_infinite, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_vertex", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_vertex, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_has_vertex, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_are_equal, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_locate, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_cell, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_facet, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_side_of_edge, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_flip_flippable, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_cell, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_facet, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_in_edge, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_convex_hull, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_insert_outside_affine_hull, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_vertices", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_vertices, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_edges", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_edges, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_facets", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_facets, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_cells", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_cells, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_vertices", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_vertices, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_edges", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_edges, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_facets", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_facets, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_cells", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_all_cells, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_points", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_points, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_cells, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_cells", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_cells, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_facets, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_facets", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_facets, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_edges", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_incident_edges, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_edges", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_incident_edges, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_adjacent_vertices", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_adjacent_vertices, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_adjacent_vertices", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_finite_adjacent_vertices, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_degree", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_degree, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_index", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_index, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_vertex, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_mirror_facet, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_tetrahedron, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_triangle, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_segment, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_point, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_valid, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_is_cell, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_equal", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_equal, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3___eq__", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3___eq__, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3___ne__", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3___ne__, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_same_internal_object", _wrap_Internal_Triangulation_3_Mesh_3_regular_triangulation_3_same_internal_object, METH_VARARGS, NULL},
	 { (char *)"Internal_Triangulation_3_Mesh_3_regular_triangulation_3_swigregister", Internal_Triangulation_3_Mesh_3_regular_triangulation_3_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_All_vertices_iterator", _wrap_new_Mesh_3_regular_triangulation_3_All_vertices_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_vertices_iterator___iter__", _wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_vertices_iterator___next__", _wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator___next__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_vertices_iterator_next", _wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy", _wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_vertices_iterator_hasNext", _wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_vertices_iterator___eq__", _wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_vertices_iterator___ne__", _wrap_Mesh_3_regular_triangulation_3_All_vertices_iterator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_All_vertices_iterator", _wrap_delete_Mesh_3_regular_triangulation_3_All_vertices_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_vertices_iterator_swigregister", Mesh_3_regular_triangulation_3_All_vertices_iterator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_Finite_vertices_iterator", _wrap_new_Mesh_3_regular_triangulation_3_Finite_vertices_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_vertices_iterator___iter__", _wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_vertices_iterator___next__", _wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator___next__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next", _wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy", _wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_vertices_iterator_hasNext", _wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_vertices_iterator___eq__", _wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_vertices_iterator___ne__", _wrap_Mesh_3_regular_triangulation_3_Finite_vertices_iterator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_Finite_vertices_iterator", _wrap_delete_Mesh_3_regular_triangulation_3_Finite_vertices_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_vertices_iterator_swigregister", Mesh_3_regular_triangulation_3_Finite_vertices_iterator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_All_cells_iterator", _wrap_new_Mesh_3_regular_triangulation_3_All_cells_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_cells_iterator___iter__", _wrap_Mesh_3_regular_triangulation_3_All_cells_iterator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_cells_iterator___next__", _wrap_Mesh_3_regular_triangulation_3_All_cells_iterator___next__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_cells_iterator_next", _wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy", _wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_cells_iterator_hasNext", _wrap_Mesh_3_regular_triangulation_3_All_cells_iterator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_cells_iterator___eq__", _wrap_Mesh_3_regular_triangulation_3_All_cells_iterator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_cells_iterator___ne__", _wrap_Mesh_3_regular_triangulation_3_All_cells_iterator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_All_cells_iterator", _wrap_delete_Mesh_3_regular_triangulation_3_All_cells_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_cells_iterator_swigregister", Mesh_3_regular_triangulation_3_All_cells_iterator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_Finite_cells_iterator", _wrap_new_Mesh_3_regular_triangulation_3_Finite_cells_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_cells_iterator___iter__", _wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_cells_iterator___next__", _wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator___next__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_cells_iterator_next", _wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy", _wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_cells_iterator_hasNext", _wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_cells_iterator___eq__", _wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_cells_iterator___ne__", _wrap_Mesh_3_regular_triangulation_3_Finite_cells_iterator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_Finite_cells_iterator", _wrap_delete_Mesh_3_regular_triangulation_3_Finite_cells_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_cells_iterator_swigregister", Mesh_3_regular_triangulation_3_Finite_cells_iterator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_All_facets_iterator", _wrap_new_Mesh_3_regular_triangulation_3_All_facets_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_facets_iterator___iter__", _wrap_Mesh_3_regular_triangulation_3_All_facets_iterator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_facets_iterator___next__", _wrap_Mesh_3_regular_triangulation_3_All_facets_iterator___next__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_facets_iterator_next", _wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy", _wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_facets_iterator_hasNext", _wrap_Mesh_3_regular_triangulation_3_All_facets_iterator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_facets_iterator___eq__", _wrap_Mesh_3_regular_triangulation_3_All_facets_iterator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_facets_iterator___ne__", _wrap_Mesh_3_regular_triangulation_3_All_facets_iterator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_All_facets_iterator", _wrap_delete_Mesh_3_regular_triangulation_3_All_facets_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_facets_iterator_swigregister", Mesh_3_regular_triangulation_3_All_facets_iterator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_Finite_facets_iterator", _wrap_new_Mesh_3_regular_triangulation_3_Finite_facets_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_facets_iterator___iter__", _wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_facets_iterator___next__", _wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator___next__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_facets_iterator_next", _wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy", _wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_facets_iterator_hasNext", _wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_facets_iterator___eq__", _wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_facets_iterator___ne__", _wrap_Mesh_3_regular_triangulation_3_Finite_facets_iterator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_Finite_facets_iterator", _wrap_delete_Mesh_3_regular_triangulation_3_Finite_facets_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_facets_iterator_swigregister", Mesh_3_regular_triangulation_3_Finite_facets_iterator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_All_edges_iterator", _wrap_new_Mesh_3_regular_triangulation_3_All_edges_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_edges_iterator___iter__", _wrap_Mesh_3_regular_triangulation_3_All_edges_iterator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_edges_iterator___next__", _wrap_Mesh_3_regular_triangulation_3_All_edges_iterator___next__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_edges_iterator_next", _wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy", _wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_edges_iterator_hasNext", _wrap_Mesh_3_regular_triangulation_3_All_edges_iterator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_edges_iterator___eq__", _wrap_Mesh_3_regular_triangulation_3_All_edges_iterator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_edges_iterator___ne__", _wrap_Mesh_3_regular_triangulation_3_All_edges_iterator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_All_edges_iterator", _wrap_delete_Mesh_3_regular_triangulation_3_All_edges_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_All_edges_iterator_swigregister", Mesh_3_regular_triangulation_3_All_edges_iterator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_Finite_edges_iterator", _wrap_new_Mesh_3_regular_triangulation_3_Finite_edges_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_edges_iterator___iter__", _wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_edges_iterator___next__", _wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator___next__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_edges_iterator_next", _wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy", _wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_edges_iterator_hasNext", _wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_edges_iterator___eq__", _wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_edges_iterator___ne__", _wrap_Mesh_3_regular_triangulation_3_Finite_edges_iterator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_Finite_edges_iterator", _wrap_delete_Mesh_3_regular_triangulation_3_Finite_edges_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Finite_edges_iterator_swigregister", Mesh_3_regular_triangulation_3_Finite_edges_iterator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_Point_iterator", _wrap_new_Mesh_3_regular_triangulation_3_Point_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Point_iterator___iter__", _wrap_Mesh_3_regular_triangulation_3_Point_iterator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Point_iterator___next__", _wrap_Mesh_3_regular_triangulation_3_Point_iterator___next__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Point_iterator_next", _wrap_Mesh_3_regular_triangulation_3_Point_iterator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Point_iterator_deepcopy", _wrap_Mesh_3_regular_triangulation_3_Point_iterator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Point_iterator_hasNext", _wrap_Mesh_3_regular_triangulation_3_Point_iterator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Point_iterator___eq__", _wrap_Mesh_3_regular_triangulation_3_Point_iterator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Point_iterator___ne__", _wrap_Mesh_3_regular_triangulation_3_Point_iterator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_Point_iterator", _wrap_delete_Mesh_3_regular_triangulation_3_Point_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Point_iterator_swigregister", Mesh_3_regular_triangulation_3_Point_iterator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_Cell_circulator", _wrap_new_Mesh_3_regular_triangulation_3_Cell_circulator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_circulator___iter__", _wrap_Mesh_3_regular_triangulation_3_Cell_circulator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_circulator_next", _wrap_Mesh_3_regular_triangulation_3_Cell_circulator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy", _wrap_Mesh_3_regular_triangulation_3_Cell_circulator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_circulator_prev", _wrap_Mesh_3_regular_triangulation_3_Cell_circulator_prev, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_circulator_hasNext", _wrap_Mesh_3_regular_triangulation_3_Cell_circulator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_circulator___eq__", _wrap_Mesh_3_regular_triangulation_3_Cell_circulator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_circulator___ne__", _wrap_Mesh_3_regular_triangulation_3_Cell_circulator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_Cell_circulator", _wrap_delete_Mesh_3_regular_triangulation_3_Cell_circulator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Cell_circulator_swigregister", Mesh_3_regular_triangulation_3_Cell_circulator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3_Facet_circulator", _wrap_new_Mesh_3_regular_triangulation_3_Facet_circulator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_circulator___iter__", _wrap_Mesh_3_regular_triangulation_3_Facet_circulator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_circulator_next", _wrap_Mesh_3_regular_triangulation_3_Facet_circulator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy", _wrap_Mesh_3_regular_triangulation_3_Facet_circulator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_circulator_prev", _wrap_Mesh_3_regular_triangulation_3_Facet_circulator_prev, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_circulator_hasNext", _wrap_Mesh_3_regular_triangulation_3_Facet_circulator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_circulator___eq__", _wrap_Mesh_3_regular_triangulation_3_Facet_circulator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_circulator___ne__", _wrap_Mesh_3_regular_triangulation_3_Facet_circulator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3_Facet_circulator", _wrap_delete_Mesh_3_regular_triangulation_3_Facet_circulator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_Facet_circulator_swigregister", Mesh_3_regular_triangulation_3_Facet_circulator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_regular_triangulation_3", _wrap_new_Mesh_3_regular_triangulation_3, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_remove", _wrap_Mesh_3_regular_triangulation_3_remove, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_side_of_power_sphere", _wrap_Mesh_3_regular_triangulation_3_side_of_power_sphere, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_side_of_power_circle", _wrap_Mesh_3_regular_triangulation_3_side_of_power_circle, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_side_of_power_segment", _wrap_Mesh_3_regular_triangulation_3_side_of_power_segment, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_nearest_power_vertex", _wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell", _wrap_Mesh_3_regular_triangulation_3_nearest_power_vertex_in_cell, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_is_Gabriel", _wrap_Mesh_3_regular_triangulation_3_is_Gabriel, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_dual", _wrap_Mesh_3_regular_triangulation_3_dual, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_regular_triangulation_3", _wrap_delete_Mesh_3_regular_triangulation_3, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_regular_triangulation_3_swigregister", Mesh_3_regular_triangulation_3_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator", _wrap_new_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___iter__", _wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___next__", _wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___next__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next", _wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy", _wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_hasNext", _wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___eq__", _wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___ne__", _wrap_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator", _wrap_delete_Mesh_3_Complex_3_in_triangulation_3_Cell_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_swigregister", Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator", _wrap_new_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___iter__", _wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___iter__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___next__", _wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___next__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next", _wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_next, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy", _wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_hasNext", _wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_hasNext, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___eq__", _wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___eq__, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___ne__", _wrap_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator___ne__, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator", _wrap_delete_Mesh_3_Complex_3_in_triangulation_3_Facet_iterator, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_swigregister", Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_Surface_index", _wrap_new_Mesh_3_Surface_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Surface_index_first_set", _wrap_Mesh_3_Surface_index_first_set, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Surface_index_first_get", _wrap_Mesh_3_Surface_index_first_get, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Surface_index_second_set", _wrap_Mesh_3_Surface_index_second_set, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Surface_index_second_get", _wrap_Mesh_3_Surface_index_second_get, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_Surface_index", _wrap_delete_Mesh_3_Surface_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Surface_index_swigregister", Mesh_3_Surface_index_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_Index", _wrap_new_Mesh_3_Index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Index_is_of_first_type", _wrap_Mesh_3_Index_is_of_first_type, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Index_is_of_second_type", _wrap_Mesh_3_Index_is_of_second_type, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Index_get_first", _wrap_Mesh_3_Index_get_first, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Index_get_second", _wrap_Mesh_3_Index_get_second, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Index_deepcopy", _wrap_Mesh_3_Index_deepcopy, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_Index", _wrap_delete_Mesh_3_Index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Index_swigregister", Mesh_3_Index_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Mesh_3_Complex_3_in_triangulation_3", _wrap_new_Mesh_3_Complex_3_in_triangulation_3, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_swap", _wrap_Mesh_3_Complex_3_in_triangulation_3_swap, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_triangulation", _wrap_Mesh_3_Complex_3_in_triangulation_3_triangulation, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_add_to_complex", _wrap_Mesh_3_Complex_3_in_triangulation_3_add_to_complex, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_remove_from_complex", _wrap_Mesh_3_Complex_3_in_triangulation_3_remove_from_complex, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_set_subdomain_index", _wrap_Mesh_3_Complex_3_in_triangulation_3_set_subdomain_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_set_surface_index", _wrap_Mesh_3_Complex_3_in_triangulation_3_set_surface_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_set_index", _wrap_Mesh_3_Complex_3_in_triangulation_3_set_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_set_dimension", _wrap_Mesh_3_Complex_3_in_triangulation_3_set_dimension, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_number_of_cells", _wrap_Mesh_3_Complex_3_in_triangulation_3_number_of_cells, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_number_of_facets", _wrap_Mesh_3_Complex_3_in_triangulation_3_number_of_facets, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_is_in_complex", _wrap_Mesh_3_Complex_3_in_triangulation_3_is_in_complex, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_subdomain_index", _wrap_Mesh_3_Complex_3_in_triangulation_3_subdomain_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_surface_index", _wrap_Mesh_3_Complex_3_in_triangulation_3_surface_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_in_dimension", _wrap_Mesh_3_Complex_3_in_triangulation_3_in_dimension, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_index", _wrap_Mesh_3_Complex_3_in_triangulation_3_index, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_cells", _wrap_Mesh_3_Complex_3_in_triangulation_3_cells, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_facets", _wrap_Mesh_3_Complex_3_in_triangulation_3_facets, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_output_to_medit", _wrap_Mesh_3_Complex_3_in_triangulation_3_output_to_medit, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_deepcopy", _wrap_Mesh_3_Complex_3_in_triangulation_3_deepcopy, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_same_internal_object", _wrap_Mesh_3_Complex_3_in_triangulation_3_same_internal_object, METH_VARARGS, NULL},
	 { (char *)"delete_Mesh_3_Complex_3_in_triangulation_3", _wrap_delete_Mesh_3_Complex_3_in_triangulation_3, METH_VARARGS, NULL},
	 { (char *)"Mesh_3_Complex_3_in_triangulation_3_swigregister", Mesh_3_Complex_3_in_triangulation_3_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Polyhedral_mesh_domain_3", _wrap_new_Polyhedral_mesh_domain_3, METH_VARARGS, NULL},
	 { (char *)"Polyhedral_mesh_domain_3_index_from_surface_index", _wrap_Polyhedral_mesh_domain_3_index_from_surface_index, METH_VARARGS, NULL},
	 { (char *)"Polyhedral_mesh_domain_3_index_from_subdomain_index", _wrap_Polyhedral_mesh_domain_3_index_from_subdomain_index, METH_VARARGS, NULL},
	 { (char *)"Polyhedral_mesh_domain_3_surface_index", _wrap_Polyhedral_mesh_domain_3_surface_index, METH_VARARGS, NULL},
	 { (char *)"Polyhedral_mesh_domain_3_subdomain_index", _wrap_Polyhedral_mesh_domain_3_subdomain_index, METH_VARARGS, NULL},
	 { (char *)"delete_Polyhedral_mesh_domain_3", _wrap_delete_Polyhedral_mesh_domain_3, METH_VARARGS, NULL},
	 { (char *)"Polyhedral_mesh_domain_3_swigregister", Polyhedral_mesh_domain_3_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Default_mesh_criteria", _wrap_new_Default_mesh_criteria, METH_VARARGS, NULL},
	 { (char *)"Default_mesh_criteria_edge_size", _wrap_Default_mesh_criteria_edge_size, METH_VARARGS, NULL},
	 { (char *)"Default_mesh_criteria_facet_angle", _wrap_Default_mesh_criteria_facet_angle, METH_VARARGS, NULL},
	 { (char *)"Default_mesh_criteria_facet_size", _wrap_Default_mesh_criteria_facet_size, METH_VARARGS, NULL},
	 { (char *)"Default_mesh_criteria_facet_distance", _wrap_Default_mesh_criteria_facet_distance, METH_VARARGS, NULL},
	 { (char *)"Default_mesh_criteria_facet_topology", _wrap_Default_mesh_criteria_facet_topology, METH_VARARGS, NULL},
	 { (char *)"Default_mesh_criteria_cell_radius_edge_ratio", _wrap_Default_mesh_criteria_cell_radius_edge_ratio, METH_VARARGS, NULL},
	 { (char *)"Default_mesh_criteria_cell_size", _wrap_Default_mesh_criteria_cell_size, METH_VARARGS, NULL},
	 { (char *)"Default_mesh_criteria_deepcopy", _wrap_Default_mesh_criteria_deepcopy, METH_VARARGS, NULL},
	 { (char *)"delete_Default_mesh_criteria", _wrap_delete_Default_mesh_criteria, METH_VARARGS, NULL},
	 { (char *)"Default_mesh_criteria_swigregister", Default_mesh_criteria_swigregister, METH_VARARGS, NULL},
	 { (char *)"exude_mesh_3", _wrap_exude_mesh_3, METH_VARARGS, NULL},
	 { (char *)"perturb_mesh_3", _wrap_perturb_mesh_3, METH_VARARGS, NULL},
	 { (char *)"lloyd_optimize_mesh_3", _wrap_lloyd_optimize_mesh_3, METH_VARARGS, NULL},
	 { (char *)"odt_optimize_mesh_3", _wrap_odt_optimize_mesh_3, METH_VARARGS, NULL},
	 { (char *)"make_mesh_3", _wrap_make_mesh_3, METH_VARARGS, NULL},
	 { (char *)"refine_mesh_3", _wrap_refine_mesh_3, METH_VARARGS, NULL},
	 { NULL, NULL, 0, NULL }
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (BEGIN) -------- */

static void *_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_tTo_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *)  ((Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *) x));
}
static swig_type_info _swigt__p_All_cells_iterator = {"_p_All_cells_iterator", "All_cells_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_All_edges_iterator = {"_p_All_edges_iterator", "All_edges_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_All_facets_iterator = {"_p_All_facets_iterator", "All_facets_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_All_vertices_iterator = {"_p_All_vertices_iterator", "All_vertices_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Base = {"_p_Base", "Base *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t = {"_p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t", "C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *|C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Self *|Mesh_3_Complex_3_in_triangulation_3_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Cell_circulator = {"_p_Cell_circulator", "Cell_circulator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Cell_handle = {"_p_Cell_handle", "Cell_handle *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Cell_handle_output_iterator = {"_p_Cell_handle_output_iterator", "Cell_handle_output_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Cell_iterator = {"_p_Cell_iterator", "Cell_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Edge = {"_p_Edge", "Edge *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Edge_iterator = {"_p_Edge_iterator", "Edge_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Edge_output_iterator = {"_p_Edge_output_iterator", "Edge_output_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Facet = {"_p_Facet", "Facet *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Facet_circulator = {"_p_Facet_circulator", "Facet_circulator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Facet_iterator = {"_p_Facet_iterator", "Facet_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Facet_output_iterator = {"_p_Facet_output_iterator", "Facet_output_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Finite_cells_iterator = {"_p_Finite_cells_iterator", "Finite_cells_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Finite_edges_iterator = {"_p_Finite_edges_iterator", "Finite_edges_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Finite_facets_iterator = {"_p_Finite_facets_iterator", "Finite_facets_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Finite_vertices_iterator = {"_p_Finite_vertices_iterator", "Finite_vertices_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_General_modifierT_Polyhedron_3___HalfedgeDS_t = {"_p_General_modifierT_Polyhedron_3___HalfedgeDS_t", "General_modifier< Polyhedron_3_::HalfedgeDS > *|Polyhedron_modifier_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Halfedge_around_facet_circulator = {"_p_Halfedge_around_facet_circulator", "Halfedge_around_facet_circulator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Halfedge_around_vertex_circulator = {"_p_Halfedge_around_vertex_circulator", "Halfedge_around_vertex_circulator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Halfedge_iterator = {"_p_Halfedge_iterator", "Halfedge_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Line_2 = {"_p_Line_2", "Line_2 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Line_3 = {"_p_Line_3", "Line_3 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Mesh_3_parameters = {"_p_Mesh_3_parameters", "Mesh_3_parameters::Self *|Mesh_3_parameters *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t = {"_p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t", "Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double > *|Mesh_criteria_with_fields_wrapper< DMC,double,double,double,double >::Self *|Default_mesh_criteria_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Object = {"_p_Object", "Object *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_OptionalT_std__pairT_int_double_t_t = {"_p_OptionalT_std__pairT_int_double_t_t", "Optional< std::pair< int,double > > *|Optional< std::pair< int,double > >::Self *|Mesh_3_Badness_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Plane_3 = {"_p_Plane_3", "Plane_3 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Point_2 = {"_p_Point_2", "Point_2 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Point_3 = {"_p_Point_3", "Point_3 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Point_iterator = {"_p_Point_iterator", "Point_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Point_range = {"_p_Point_range", "Point_range *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t = {"_p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t", "Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *|Polyhedral_mesh_domain_3_wrapper< PMD,Polyhedron_3_SWIG_wrapper,Variant< int,std::pair< int,int > >,std::pair< int,int >,int > *|Polyhedral_mesh_domain_3_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t = {"_p_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t", "Polyhedron_3_wrapper< Polyhedron_3_,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ >,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > > *|Polyhedron_3_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Ray_2 = {"_p_Ray_2", "Ray_2 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Ray_3 = {"_p_Ray_3", "Ray_3 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t = {"_p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t", "Reference_wrapper< enum SWIG_Triangulation_3::Locate_type > *|Reference_wrapper< enum SWIG_Triangulation_3::Locate_type >::Self *|Reference_wrapper< SWIG_Triangulation_3::Locate_type > *|Ref_Locate_type_3_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Reference_wrapperT_int_t = {"_p_Reference_wrapperT_int_t", "Reference_wrapper< int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t = {"_p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t", "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > > *|Mesh_3_regular_triangulation_3_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t = {"_p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t", "Mesh_3_regular_triangulation_3_Cell_circulator_SWIG_wrapper *|Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Cell_circulator *|SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *|SWIG_CGAL_Circulator< MT_PMD::Cell_circulator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t = {"_p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t", "SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *|SWIG_CGAL_Circulator< MT_PMD::Facet_circulator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *|Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet_circulator *|Mesh_3_regular_triangulation_3_Facet_circulator_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_facet_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t = {"_p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_facet_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t", "Polyhedron_3_Halfedge_around_facet_circulator_SWIG_wrapper *|SWIG_CGAL_Circulator< Polyhedron_3_::Halfedge_around_facet_circulator,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_vertex_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t = {"_p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_vertex_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t", "Polyhedron_3_Halfedge_around_vertex_circulator_SWIG_wrapper *|SWIG_CGAL_Circulator< Polyhedron_3_::Halfedge_around_vertex_circulator,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t = {"_p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t", "SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *|SWIG_CGAL_Iterator< C3T3_PMD::Cell_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *|Mesh_3_Complex_3_in_triangulation_3_Cell_iterator_SWIG_wrapper *|C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t = {"_p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t", "Mesh_3_Complex_3_in_triangulation_3_Facet_iterator_SWIG_wrapper *|C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Facet_iterator *|SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *|SWIG_CGAL_Iterator< C3T3_PMD::Facet_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t = {"_p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t", "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_cells_iterator *|Mesh_3_regular_triangulation_3_All_cells_iterator_SWIG_wrapper *|SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *|SWIG_CGAL_Iterator< MT_PMD::All_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t = {"_p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t", "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_edges_iterator *|Mesh_3_regular_triangulation_3_All_edges_iterator_SWIG_wrapper *|SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *|SWIG_CGAL_Iterator< MT_PMD::All_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t = {"_p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t", "SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *|SWIG_CGAL_Iterator< MT_PMD::All_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *|Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_facets_iterator *|Mesh_3_regular_triangulation_3_All_facets_iterator_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t = {"_p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t", "SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *|SWIG_CGAL_Iterator< MT_PMD::All_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self *|Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::All_vertices_iterator *|Mesh_3_regular_triangulation_3_All_vertices_iterator_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t = {"_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t", "SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > > *|SWIG_CGAL_Iterator< MT_PMD::Finite_cells_iterator,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > >::Self *|Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_cells_iterator *|Mesh_3_regular_triangulation_3_Finite_cells_iterator_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t = {"_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t", "SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > > *|SWIG_CGAL_Iterator< MT_PMD::Finite_edges_iterator,SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > >::Self *|Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_edges_iterator *|Mesh_3_regular_triangulation_3_Finite_edges_iterator_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t = {"_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t", "Mesh_3_regular_triangulation_3_Finite_facets_iterator_SWIG_wrapper *|SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > > *|SWIG_CGAL_Iterator< MT_PMD::Finite_facets_iterator,std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > >::Self *|Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_facets_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t = {"_p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t", "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Finite_vertices_iterator *|Mesh_3_regular_triangulation_3_Finite_vertices_iterator_SWIG_wrapper *|SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > > *|SWIG_CGAL_Iterator< MT_PMD::Finite_vertices_iterator,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > >::Self *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t = {"_p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t", "Mesh_3_regular_triangulation_3_Point_iterator_SWIG_wrapper *|Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Point_iterator *|SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 > *|SWIG_CGAL_Iterator< MT_PMD::Point_iterator,Weighted_point_3 >::Self *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Edge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t = {"_p_SWIG_CGAL_IteratorT_Polyhedron_3___Edge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t", "SWIG_CGAL_Iterator< Polyhedron_3_::Edge_iterator,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ > > *|Polyhedron_3_Edge_iterator_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Facet_iterator_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t = {"_p_SWIG_CGAL_IteratorT_Polyhedron_3___Facet_iterator_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t", "SWIG_CGAL_Iterator< Polyhedron_3_::Facet_iterator,SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > > *|Polyhedron_3_Facet_iterator_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Halfedge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t = {"_p_SWIG_CGAL_IteratorT_Polyhedron_3___Halfedge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t", "SWIG_CGAL_Iterator< Polyhedron_3_::Halfedge_iterator,SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ > > *|Polyhedron_3_Halfedge_iterator_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Point_iterator_Point_3_t = {"_p_SWIG_CGAL_IteratorT_Polyhedron_3___Point_iterator_Point_3_t", "SWIG_CGAL_Iterator< Polyhedron_3_::Point_iterator,Point_3 > *|Polyhedron_3_Point_iterator_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Vertex_iterator_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_t = {"_p_SWIG_CGAL_IteratorT_Polyhedron_3___Vertex_iterator_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_t", "SWIG_CGAL_Iterator< Polyhedron_3_::Vertex_iterator,SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ > > *|Polyhedron_3_Vertex_iterator_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t = {"_p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t", "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Edge *|SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int > *|SWIG_CGAL::Triple< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int,int >::Self *|Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Edge *|Mesh_3_regular_triangulation_3_Edge_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t = {"_p_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t", "SWIG_Polyhedron_3::CGAL_Facet_handle< Polyhedron_3_ > *|Polyhedron_3_Facet_handle_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t = {"_p_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t", "SWIG_Polyhedron_3::CGAL_Halfedge_handle< Polyhedron_3_ > *|Polyhedron_3_Halfedge_handle_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t = {"_p_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t", "SWIG_Polyhedron_3::CGAL_Vertex_handle< Polyhedron_3_ > *|Polyhedron_3_Vertex_handle_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t = {"_p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t", "Mesh_3_regular_triangulation_3_Cell_handle_SWIG_wrapper *|Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Cell_handle *|SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 > *|SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Self *|SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Cell_handle *|C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Cell_handle *|SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Cell_handle *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t = {"_p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t", "Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >::Vertex_handle *|SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >::Vertex_handle *|SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 > *|Mesh_3_regular_triangulation_3_Vertex_handle_SWIG_wrapper *|C3T3_wrapper< C3T3_PMD,Regular_triangulation_3_wrapper< MT_PMD,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,boost::shared_ptr< C3T3_PMD > >,Variant< int,std::pair< int,int > >,std::pair< int,int >,int >::Vertex_handle *|SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >::Self *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Segment_2 = {"_p_Segment_2", "Segment_2 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Segment_3 = {"_p_Segment_3", "Segment_3 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Self = {"_p_Self", "Self *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Tetrahedron_3 = {"_p_Tetrahedron_3", "Tetrahedron_3 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Triangle_2 = {"_p_Triangle_2", "Triangle_2 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Triangle_3 = {"_p_Triangle_3", "Triangle_3 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t = {"_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t", "Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > > *|Internal_Triangulation_3_Mesh_3_regular_triangulation_3_SWIG_wrapper *|Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Self *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_VariantT_int_std__pairT_int_int_t_t = {"_p_VariantT_int_std__pairT_int_int_t_t", "Variant< int,std::pair< int,int > >::Self *|Variant< int,std::pair< int,int > > *|Mesh_3_Index_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Vertex_handle = {"_p_Vertex_handle", "Vertex_handle *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Vertex_handle_output_iterator = {"_p_Vertex_handle_output_iterator", "Vertex_handle_output_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Vertex_iterator = {"_p_Vertex_iterator", "Vertex_iterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Weighted_point_3 = {"_p_Weighted_point_3", "Weighted_point_3 *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_char = {"_p_char", "char *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_cpp_base = {"_p_cpp_base", "cpp_base *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_first_type = {"_p_first_type", "first_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_second_type = {"_p_second_type", "second_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t = {"_p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t", "Mesh_3_regular_triangulation_3_Facet_SWIG_wrapper *|Triangulation_3_wrapper< MT_PMD,Weighted_point_3,SWIG_Triangulation_3::CGAL_Vertex_handle< MT_PMD,Weighted_point_3 >,SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,CGAL::Tag_true,boost::shared_ptr< C3T3_PMD > >::Facet *|std::pair< SWIG_Triangulation_3::CGAL_Cell_handle< MT_PMD,Weighted_point_3 >,int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__pairT_int_double_t = {"_p_std__pairT_int_double_t", "std::pair< int,double > *|Mesh_3_Quality_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__pairT_int_int_t = {"_p_std__pairT_int_int_t", "std::pair< int,int > *|Mesh_3_Surface_index_SWIG_wrapper *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_third_type = {"_p_third_type", "third_type *", 0, 0, (void*)0, 0};

static swig_type_info *swig_type_initial[] = {
  &_swigt__p_All_cells_iterator,
  &_swigt__p_All_edges_iterator,
  &_swigt__p_All_facets_iterator,
  &_swigt__p_All_vertices_iterator,
  &_swigt__p_Base,
  &_swigt__p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,
  &_swigt__p_Cell_circulator,
  &_swigt__p_Cell_handle,
  &_swigt__p_Cell_handle_output_iterator,
  &_swigt__p_Cell_iterator,
  &_swigt__p_Edge,
  &_swigt__p_Edge_iterator,
  &_swigt__p_Edge_output_iterator,
  &_swigt__p_Facet,
  &_swigt__p_Facet_circulator,
  &_swigt__p_Facet_iterator,
  &_swigt__p_Facet_output_iterator,
  &_swigt__p_Finite_cells_iterator,
  &_swigt__p_Finite_edges_iterator,
  &_swigt__p_Finite_facets_iterator,
  &_swigt__p_Finite_vertices_iterator,
  &_swigt__p_General_modifierT_Polyhedron_3___HalfedgeDS_t,
  &_swigt__p_Halfedge_around_facet_circulator,
  &_swigt__p_Halfedge_around_vertex_circulator,
  &_swigt__p_Halfedge_iterator,
  &_swigt__p_Line_2,
  &_swigt__p_Line_3,
  &_swigt__p_Mesh_3_parameters,
  &_swigt__p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t,
  &_swigt__p_Object,
  &_swigt__p_OptionalT_std__pairT_int_double_t_t,
  &_swigt__p_Plane_3,
  &_swigt__p_Point_2,
  &_swigt__p_Point_3,
  &_swigt__p_Point_iterator,
  &_swigt__p_Point_range,
  &_swigt__p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,
  &_swigt__p_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t,
  &_swigt__p_Ray_2,
  &_swigt__p_Ray_3,
  &_swigt__p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t,
  &_swigt__p_Reference_wrapperT_int_t,
  &_swigt__p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t,
  &_swigt__p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,
  &_swigt__p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,
  &_swigt__p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_facet_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t,
  &_swigt__p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_vertex_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t,
  &_swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Edge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Facet_iterator_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Halfedge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t,
  &_swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Point_iterator_Point_3_t,
  &_swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Vertex_iterator_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_t,
  &_swigt__p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,
  &_swigt__p_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t,
  &_swigt__p_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t,
  &_swigt__p_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t,
  &_swigt__p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,
  &_swigt__p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,
  &_swigt__p_Segment_2,
  &_swigt__p_Segment_3,
  &_swigt__p_Self,
  &_swigt__p_Tetrahedron_3,
  &_swigt__p_Triangle_2,
  &_swigt__p_Triangle_3,
  &_swigt__p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t,
  &_swigt__p_VariantT_int_std__pairT_int_int_t_t,
  &_swigt__p_Vertex_handle,
  &_swigt__p_Vertex_handle_output_iterator,
  &_swigt__p_Vertex_iterator,
  &_swigt__p_Weighted_point_3,
  &_swigt__p_char,
  &_swigt__p_cpp_base,
  &_swigt__p_first_type,
  &_swigt__p_second_type,
  &_swigt__p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t,
  &_swigt__p_std__pairT_int_double_t,
  &_swigt__p_std__pairT_int_int_t,
  &_swigt__p_third_type,
};

static swig_cast_info _swigc__p_All_cells_iterator[] = {  {&_swigt__p_All_cells_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_All_edges_iterator[] = {  {&_swigt__p_All_edges_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_All_facets_iterator[] = {  {&_swigt__p_All_facets_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_All_vertices_iterator[] = {  {&_swigt__p_All_vertices_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Base[] = {  {&_swigt__p_Base, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t[] = {  {&_swigt__p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Cell_circulator[] = {  {&_swigt__p_Cell_circulator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Cell_handle[] = {  {&_swigt__p_Cell_handle, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Cell_handle_output_iterator[] = {  {&_swigt__p_Cell_handle_output_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Cell_iterator[] = {  {&_swigt__p_Cell_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Edge[] = {  {&_swigt__p_Edge, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Edge_iterator[] = {  {&_swigt__p_Edge_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Edge_output_iterator[] = {  {&_swigt__p_Edge_output_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Facet[] = {  {&_swigt__p_Facet, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Facet_circulator[] = {  {&_swigt__p_Facet_circulator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Facet_iterator[] = {  {&_swigt__p_Facet_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Facet_output_iterator[] = {  {&_swigt__p_Facet_output_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Finite_cells_iterator[] = {  {&_swigt__p_Finite_cells_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Finite_edges_iterator[] = {  {&_swigt__p_Finite_edges_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Finite_facets_iterator[] = {  {&_swigt__p_Finite_facets_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Finite_vertices_iterator[] = {  {&_swigt__p_Finite_vertices_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_General_modifierT_Polyhedron_3___HalfedgeDS_t[] = {  {&_swigt__p_General_modifierT_Polyhedron_3___HalfedgeDS_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Halfedge_around_facet_circulator[] = {  {&_swigt__p_Halfedge_around_facet_circulator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Halfedge_around_vertex_circulator[] = {  {&_swigt__p_Halfedge_around_vertex_circulator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Halfedge_iterator[] = {  {&_swigt__p_Halfedge_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Line_2[] = {  {&_swigt__p_Line_2, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Line_3[] = {  {&_swigt__p_Line_3, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Mesh_3_parameters[] = {  {&_swigt__p_Mesh_3_parameters, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t[] = {  {&_swigt__p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Object[] = {  {&_swigt__p_Object, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_OptionalT_std__pairT_int_double_t_t[] = {  {&_swigt__p_OptionalT_std__pairT_int_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Plane_3[] = {  {&_swigt__p_Plane_3, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Point_2[] = {  {&_swigt__p_Point_2, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Point_3[] = {  {&_swigt__p_Point_3, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Point_iterator[] = {  {&_swigt__p_Point_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Point_range[] = {  {&_swigt__p_Point_range, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t[] = {  {&_swigt__p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t[] = {  {&_swigt__p_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Ray_2[] = {  {&_swigt__p_Ray_2, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Ray_3[] = {  {&_swigt__p_Ray_3, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t[] = {  {&_swigt__p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Reference_wrapperT_int_t[] = {  {&_swigt__p_Reference_wrapperT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t[] = {  {&_swigt__p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t[] = {  {&_swigt__p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t[] = {  {&_swigt__p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_facet_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t[] = {  {&_swigt__p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_facet_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_vertex_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t[] = {  {&_swigt__p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_vertex_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_Polyhedron_3___Edge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Edge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_Polyhedron_3___Facet_iterator_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Facet_iterator_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_Polyhedron_3___Halfedge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Halfedge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_Polyhedron_3___Point_iterator_Point_3_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Point_iterator_Point_3_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL_IteratorT_Polyhedron_3___Vertex_iterator_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_t[] = {  {&_swigt__p_SWIG_CGAL_IteratorT_Polyhedron_3___Vertex_iterator_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t[] = {  {&_swigt__p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t[] = {  {&_swigt__p_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t[] = {  {&_swigt__p_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t[] = {  {&_swigt__p_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t[] = {  {&_swigt__p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t[] = {  {&_swigt__p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Segment_2[] = {  {&_swigt__p_Segment_2, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Segment_3[] = {  {&_swigt__p_Segment_3, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Self[] = {  {&_swigt__p_Self, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Tetrahedron_3[] = {  {&_swigt__p_Tetrahedron_3, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Triangle_2[] = {  {&_swigt__p_Triangle_2, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Triangle_3[] = {  {&_swigt__p_Triangle_3, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t[] = {  {&_swigt__p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t, _p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_tTo_p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0, 0},  {&_swigt__p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_VariantT_int_std__pairT_int_int_t_t[] = {  {&_swigt__p_VariantT_int_std__pairT_int_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Vertex_handle[] = {  {&_swigt__p_Vertex_handle, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Vertex_handle_output_iterator[] = {  {&_swigt__p_Vertex_handle_output_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Vertex_iterator[] = {  {&_swigt__p_Vertex_iterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Weighted_point_3[] = {  {&_swigt__p_Weighted_point_3, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_char[] = {  {&_swigt__p_char, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_cpp_base[] = {  {&_swigt__p_cpp_base, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_first_type[] = {  {&_swigt__p_first_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_second_type[] = {  {&_swigt__p_second_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t[] = {  {&_swigt__p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__pairT_int_double_t[] = {  {&_swigt__p_std__pairT_int_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__pairT_int_int_t[] = {  {&_swigt__p_std__pairT_int_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_third_type[] = {  {&_swigt__p_third_type, 0, 0, 0},{0, 0, 0, 0}};

static swig_cast_info *swig_cast_initial[] = {
  _swigc__p_All_cells_iterator,
  _swigc__p_All_edges_iterator,
  _swigc__p_All_facets_iterator,
  _swigc__p_All_vertices_iterator,
  _swigc__p_Base,
  _swigc__p_C3T3_wrapperT_C3T3_PMD_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,
  _swigc__p_Cell_circulator,
  _swigc__p_Cell_handle,
  _swigc__p_Cell_handle_output_iterator,
  _swigc__p_Cell_iterator,
  _swigc__p_Edge,
  _swigc__p_Edge_iterator,
  _swigc__p_Edge_output_iterator,
  _swigc__p_Facet,
  _swigc__p_Facet_circulator,
  _swigc__p_Facet_iterator,
  _swigc__p_Facet_output_iterator,
  _swigc__p_Finite_cells_iterator,
  _swigc__p_Finite_edges_iterator,
  _swigc__p_Finite_facets_iterator,
  _swigc__p_Finite_vertices_iterator,
  _swigc__p_General_modifierT_Polyhedron_3___HalfedgeDS_t,
  _swigc__p_Halfedge_around_facet_circulator,
  _swigc__p_Halfedge_around_vertex_circulator,
  _swigc__p_Halfedge_iterator,
  _swigc__p_Line_2,
  _swigc__p_Line_3,
  _swigc__p_Mesh_3_parameters,
  _swigc__p_Mesh_criteria_with_fields_wrapperT_DMC_double_double_double_double_t,
  _swigc__p_Object,
  _swigc__p_OptionalT_std__pairT_int_double_t_t,
  _swigc__p_Plane_3,
  _swigc__p_Point_2,
  _swigc__p_Point_3,
  _swigc__p_Point_iterator,
  _swigc__p_Point_range,
  _swigc__p_Polyhedral_mesh_domain_3_wrapperT_PMD_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t_VariantT_int_std__pairT_int_int_t_t_std__pairT_int_int_t_int_t,
  _swigc__p_Polyhedron_3_wrapperT_Polyhedron_3__SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t,
  _swigc__p_Ray_2,
  _swigc__p_Ray_3,
  _swigc__p_Reference_wrapperT_SWIG_Triangulation_3__Locate_type_t,
  _swigc__p_Reference_wrapperT_int_t,
  _swigc__p_Regular_triangulation_3_wrapperT_MT_PMD_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_boost__shared_ptrT_C3T3_PMD_t_t,
  _swigc__p_SWIG_CGAL_CirculatorT_MT_PMD__Cell_circulator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,
  _swigc__p_SWIG_CGAL_CirculatorT_MT_PMD__Facet_circulator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,
  _swigc__p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_facet_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t,
  _swigc__p_SWIG_CGAL_CirculatorT_Polyhedron_3___Halfedge_around_vertex_circulator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t,
  _swigc__p_SWIG_CGAL_IteratorT_C3T3_PMD__Cell_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,
  _swigc__p_SWIG_CGAL_IteratorT_C3T3_PMD__Facet_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,
  _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__All_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,
  _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__All_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t,
  _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__All_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,
  _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__All_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t,
  _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_cells_iterator_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_t,
  _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_edges_iterator_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t_t,
  _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_facets_iterator_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t_t,
  _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__Finite_vertices_iterator_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_t,
  _swigc__p_SWIG_CGAL_IteratorT_MT_PMD__Point_iterator_Weighted_point_3_t,
  _swigc__p_SWIG_CGAL_IteratorT_Polyhedron_3___Edge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t,
  _swigc__p_SWIG_CGAL_IteratorT_Polyhedron_3___Facet_iterator_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t_t,
  _swigc__p_SWIG_CGAL_IteratorT_Polyhedron_3___Halfedge_iterator_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t_t,
  _swigc__p_SWIG_CGAL_IteratorT_Polyhedron_3___Point_iterator_Point_3_t,
  _swigc__p_SWIG_CGAL_IteratorT_Polyhedron_3___Vertex_iterator_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t_t,
  _swigc__p_SWIG_CGAL__TripleT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_int_t,
  _swigc__p_SWIG_Polyhedron_3__CGAL_Facet_handleT_Polyhedron_3__t,
  _swigc__p_SWIG_Polyhedron_3__CGAL_Halfedge_handleT_Polyhedron_3__t,
  _swigc__p_SWIG_Polyhedron_3__CGAL_Vertex_handleT_Polyhedron_3__t,
  _swigc__p_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t,
  _swigc__p_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t,
  _swigc__p_Segment_2,
  _swigc__p_Segment_3,
  _swigc__p_Self,
  _swigc__p_Tetrahedron_3,
  _swigc__p_Triangle_2,
  _swigc__p_Triangle_3,
  _swigc__p_Triangulation_3_wrapperT_MT_PMD_Weighted_point_3_SWIG_Triangulation_3__CGAL_Vertex_handleT_MT_PMD_Weighted_point_3_t_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_CGAL__Tag_true_boost__shared_ptrT_C3T3_PMD_t_t,
  _swigc__p_VariantT_int_std__pairT_int_int_t_t,
  _swigc__p_Vertex_handle,
  _swigc__p_Vertex_handle_output_iterator,
  _swigc__p_Vertex_iterator,
  _swigc__p_Weighted_point_3,
  _swigc__p_char,
  _swigc__p_cpp_base,
  _swigc__p_first_type,
  _swigc__p_second_type,
  _swigc__p_std__pairT_SWIG_Triangulation_3__CGAL_Cell_handleT_MT_PMD_Weighted_point_3_t_int_t,
  _swigc__p_std__pairT_int_double_t,
  _swigc__p_std__pairT_int_int_t,
  _swigc__p_third_type,
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (END) -------- */

static swig_const_info swig_const_table[] = {
{0, 0, 0, 0.0, 0, 0}};

#ifdef __cplusplus
}
#endif
/* -----------------------------------------------------------------------------
 * Type initialization:
 * This problem is tough by the requirement that no dynamic
 * memory is used. Also, since swig_type_info structures store pointers to
 * swig_cast_info structures and swig_cast_info structures store pointers back
 * to swig_type_info structures, we need some lookup code at initialization.
 * The idea is that swig generates all the structures that are needed.
 * The runtime then collects these partially filled structures.
 * The SWIG_InitializeModule function takes these initial arrays out of
 * swig_module, and does all the lookup, filling in the swig_module.types
 * array with the correct data and linking the correct swig_cast_info
 * structures together.
 *
 * The generated swig_type_info structures are assigned statically to an initial
 * array. We just loop through that array, and handle each type individually.
 * First we lookup if this type has been already loaded, and if so, use the
 * loaded structure instead of the generated one. Then we have to fill in the
 * cast linked list. The cast data is initially stored in something like a
 * two-dimensional array. Each row corresponds to a type (there are the same
 * number of rows as there are in the swig_type_initial array). Each entry in
 * a column is one of the swig_cast_info structures for that type.
 * The cast_initial array is actually an array of arrays, because each row has
 * a variable number of columns. So to actually build the cast linked list,
 * we find the array of casts associated with the type, and loop through it
 * adding the casts to the list. The one last trick we need to do is making
 * sure the type pointer in the swig_cast_info struct is correct.
 *
 * First off, we lookup the cast->type name to see if it is already loaded.
 * There are three cases to handle:
 *  1) If the cast->type has already been loaded AND the type we are adding
 *     casting info to has not been loaded (it is in this module), THEN we
 *     replace the cast->type pointer with the type pointer that has already
 *     been loaded.
 *  2) If BOTH types (the one we are adding casting info to, and the
 *     cast->type) are loaded, THEN the cast info has already been loaded by
 *     the previous module so we just ignore it.
 *  3) Finally, if cast->type has not already been loaded, then we add that
 *     swig_cast_info to the linked list (because the cast->type) pointer will
 *     be correct.
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#if 0
} /* c-mode */
#endif
#endif

#if 0
#define SWIGRUNTIME_DEBUG
#endif


SWIGRUNTIME void
SWIG_InitializeModule(void *clientdata) {
  size_t i;
  swig_module_info *module_head, *iter;
  int init;
  
  /* check to see if the circular list has been setup, if not, set it up */
  if (swig_module.next==0) {
    /* Initialize the swig_module */
    swig_module.type_initial = swig_type_initial;
    swig_module.cast_initial = swig_cast_initial;
    swig_module.next = &swig_module;
    init = 1;
  } else {
    init = 0;
  }
  
  /* Try and load any already created modules */
  module_head = SWIG_GetModule(clientdata);
  if (!module_head) {
    /* This is the first module loaded for this interpreter */
    /* so set the swig module into the interpreter */
    SWIG_SetModule(clientdata, &swig_module);
  } else {
    /* the interpreter has loaded a SWIG module, but has it loaded this one? */
    iter=module_head;
    do {
      if (iter==&swig_module) {
        /* Our module is already in the list, so there's nothing more to do. */
        return;
      }
      iter=iter->next;
    } while (iter!= module_head);
    
    /* otherwise we must add our module into the list */
    swig_module.next = module_head->next;
    module_head->next = &swig_module;
  }
  
  /* When multiple interpreters are used, a module could have already been initialized in
       a different interpreter, but not yet have a pointer in this interpreter.
       In this case, we do not want to continue adding types... everything should be
       set up already */
  if (init == 0) return;
  
  /* Now work on filling in swig_module.types */
#ifdef SWIGRUNTIME_DEBUG
  printf("SWIG_InitializeModule: size %d\n", swig_module.size);
#endif
  for (i = 0; i < swig_module.size; ++i) {
    swig_type_info *type = 0;
    swig_type_info *ret;
    swig_cast_info *cast;
    
#ifdef SWIGRUNTIME_DEBUG
    printf("SWIG_InitializeModule: type %d %s\n", i, swig_module.type_initial[i]->name);
#endif
    
    /* if there is another module already loaded */
    if (swig_module.next != &swig_module) {
      type = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, swig_module.type_initial[i]->name);
    }
    if (type) {
      /* Overwrite clientdata field */
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: found type %s\n", type->name);
#endif
      if (swig_module.type_initial[i]->clientdata) {
        type->clientdata = swig_module.type_initial[i]->clientdata;
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: found and overwrite type %s \n", type->name);
#endif
      }
    } else {
      type = swig_module.type_initial[i];
    }
    
    /* Insert casting types */
    cast = swig_module.cast_initial[i];
    while (cast->type) {
      /* Don't need to add information already in the list */
      ret = 0;
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: look cast %s\n", cast->type->name);
#endif
      if (swig_module.next != &swig_module) {
        ret = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, cast->type->name);
#ifdef SWIGRUNTIME_DEBUG
        if (ret) printf("SWIG_InitializeModule: found cast %s\n", ret->name);
#endif
      }
      if (ret) {
        if (type == swig_module.type_initial[i]) {
#ifdef SWIGRUNTIME_DEBUG
          printf("SWIG_InitializeModule: skip old type %s\n", ret->name);
#endif
          cast->type = ret;
          ret = 0;
        } else {
          /* Check for casting already in the list */
          swig_cast_info *ocast = SWIG_TypeCheck(ret->name, type);
#ifdef SWIGRUNTIME_DEBUG
          if (ocast) printf("SWIG_InitializeModule: skip old cast %s\n", ret->name);
#endif
          if (!ocast) ret = 0;
        }
      }
      
      if (!ret) {
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: adding cast %s\n", cast->type->name);
#endif
        if (type->cast) {
          type->cast->prev = cast;
          cast->next = type->cast;
        }
        type->cast = cast;
      }
      cast++;
    }
    /* Set entry in modules->types array equal to the type */
    swig_module.types[i] = type;
  }
  swig_module.types[i] = 0;
  
#ifdef SWIGRUNTIME_DEBUG
  printf("**** SWIG_InitializeModule: Cast List ******\n");
  for (i = 0; i < swig_module.size; ++i) {
    int j = 0;
    swig_cast_info *cast = swig_module.cast_initial[i];
    printf("SWIG_InitializeModule: type %d %s\n", i, swig_module.type_initial[i]->name);
    while (cast->type) {
      printf("SWIG_InitializeModule: cast type %s\n", cast->type->name);
      cast++;
      ++j;
    }
    printf("---- Total casts: %d\n",j);
  }
  printf("**** SWIG_InitializeModule: Cast List ******\n");
#endif
}

/* This function will propagate the clientdata field of type to
* any new swig_type_info structures that have been added into the list
* of equivalent types.  It is like calling
* SWIG_TypeClientData(type, clientdata) a second time.
*/
SWIGRUNTIME void
SWIG_PropagateClientData(void) {
  size_t i;
  swig_cast_info *equiv;
  static int init_run = 0;
  
  if (init_run) return;
  init_run = 1;
  
  for (i = 0; i < swig_module.size; i++) {
    if (swig_module.types[i]->clientdata) {
      equiv = swig_module.types[i]->cast;
      while (equiv) {
        if (!equiv->converter) {
          if (equiv->type && !equiv->type->clientdata)
          SWIG_TypeClientData(equiv->type, swig_module.types[i]->clientdata);
        }
        equiv = equiv->next;
      }
    }
  }
}

#ifdef __cplusplus
#if 0
{
  /* c-mode */
#endif
}
#endif



#ifdef __cplusplus
extern "C" {
#endif
  
  /* Python-specific SWIG API */
#define SWIG_newvarlink()                             SWIG_Python_newvarlink()
#define SWIG_addvarlink(p, name, get_attr, set_attr)  SWIG_Python_addvarlink(p, name, get_attr, set_attr)
#define SWIG_InstallConstants(d, constants)           SWIG_Python_InstallConstants(d, constants)
  
  /* -----------------------------------------------------------------------------
   * global variable support code.
   * ----------------------------------------------------------------------------- */
  
  typedef struct swig_globalvar {
    char       *name;                  /* Name of global variable */
    PyObject *(*get_attr)(void);       /* Return the current value */
    int       (*set_attr)(PyObject *); /* Set the value */
    struct swig_globalvar *next;
  } swig_globalvar;
  
  typedef struct swig_varlinkobject {
    PyObject_HEAD
    swig_globalvar *vars;
  } swig_varlinkobject;
  
  SWIGINTERN PyObject *
  swig_varlink_repr(swig_varlinkobject *SWIGUNUSEDPARM(v)) {
#if PY_VERSION_HEX >= 0x03000000
    return PyUnicode_InternFromString("<Swig global variables>");
#else
    return PyString_FromString("<Swig global variables>");
#endif
  }
  
  SWIGINTERN PyObject *
  swig_varlink_str(swig_varlinkobject *v) {
#if PY_VERSION_HEX >= 0x03000000
    PyObject *str = PyUnicode_InternFromString("(");
    PyObject *tail;
    PyObject *joined;
    swig_globalvar *var;
    for (var = v->vars; var; var=var->next) {
      tail = PyUnicode_FromString(var->name);
      joined = PyUnicode_Concat(str, tail);
      Py_DecRef(str);
      Py_DecRef(tail);
      str = joined;
      if (var->next) {
        tail = PyUnicode_InternFromString(", ");
        joined = PyUnicode_Concat(str, tail);
        Py_DecRef(str);
        Py_DecRef(tail);
        str = joined;
      }
    }
    tail = PyUnicode_InternFromString(")");
    joined = PyUnicode_Concat(str, tail);
    Py_DecRef(str);
    Py_DecRef(tail);
    str = joined;
#else
    PyObject *str = PyString_FromString("(");
    swig_globalvar *var;
    for (var = v->vars; var; var=var->next) {
      PyString_ConcatAndDel(&str,PyString_FromString(var->name));
      if (var->next) PyString_ConcatAndDel(&str,PyString_FromString(", "));
    }
    PyString_ConcatAndDel(&str,PyString_FromString(")"));
#endif
    return str;
  }
  
  SWIGINTERN int
  swig_varlink_print(swig_varlinkobject *v, FILE *fp, int SWIGUNUSEDPARM(flags)) {
    char *tmp;
    PyObject *str = swig_varlink_str(v);
    fprintf(fp,"Swig global variables ");
    fprintf(fp,"%s\n", tmp = SWIG_Python_str_AsChar(str));
    SWIG_Python_str_DelForPy3(tmp);
    Py_DECREF(str);
    return 0;
  }
  
  SWIGINTERN void
  swig_varlink_dealloc(swig_varlinkobject *v) {
    swig_globalvar *var = v->vars;
    while (var) {
      swig_globalvar *n = var->next;
      free(var->name);
      free(var);
      var = n;
    }
  }
  
  SWIGINTERN PyObject *
  swig_varlink_getattr(swig_varlinkobject *v, char *n) {
    PyObject *res = NULL;
    swig_globalvar *var = v->vars;
    while (var) {
      if (strcmp(var->name,n) == 0) {
        res = (*var->get_attr)();
        break;
      }
      var = var->next;
    }
    if (res == NULL && !PyErr_Occurred()) {
      PyErr_Format(PyExc_AttributeError, "Unknown C global variable '%s'", n);
    }
    return res;
  }
  
  SWIGINTERN int
  swig_varlink_setattr(swig_varlinkobject *v, char *n, PyObject *p) {
    int res = 1;
    swig_globalvar *var = v->vars;
    while (var) {
      if (strcmp(var->name,n) == 0) {
        res = (*var->set_attr)(p);
        break;
      }
      var = var->next;
    }
    if (res == 1 && !PyErr_Occurred()) {
      PyErr_Format(PyExc_AttributeError, "Unknown C global variable '%s'", n);
    }
    return res;
  }
  
  SWIGINTERN PyTypeObject*
  swig_varlink_type(void) {
    static char varlink__doc__[] = "Swig var link object";
    static PyTypeObject varlink_type;
    static int type_init = 0;
    if (!type_init) {
      const PyTypeObject tmp = {
        /* PyObject header changed in Python 3 */
#if PY_VERSION_HEX >= 0x03000000
        PyVarObject_HEAD_INIT(NULL, 0)
#else
        PyObject_HEAD_INIT(NULL)
        0,                                  /* ob_size */
#endif
        (char *)"swigvarlink",              /* tp_name */
        sizeof(swig_varlinkobject),         /* tp_basicsize */
        0,                                  /* tp_itemsize */
        (destructor) swig_varlink_dealloc,  /* tp_dealloc */
        (printfunc) swig_varlink_print,     /* tp_print */
        (getattrfunc) swig_varlink_getattr, /* tp_getattr */
        (setattrfunc) swig_varlink_setattr, /* tp_setattr */
        0,                                  /* tp_compare */
        (reprfunc) swig_varlink_repr,       /* tp_repr */
        0,                                  /* tp_as_number */
        0,                                  /* tp_as_sequence */
        0,                                  /* tp_as_mapping */
        0,                                  /* tp_hash */
        0,                                  /* tp_call */
        (reprfunc) swig_varlink_str,        /* tp_str */
        0,                                  /* tp_getattro */
        0,                                  /* tp_setattro */
        0,                                  /* tp_as_buffer */
        0,                                  /* tp_flags */
        varlink__doc__,                     /* tp_doc */
        0,                                  /* tp_traverse */
        0,                                  /* tp_clear */
        0,                                  /* tp_richcompare */
        0,                                  /* tp_weaklistoffset */
#if PY_VERSION_HEX >= 0x02020000
        0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* tp_iter -> tp_weaklist */
#endif
#if PY_VERSION_HEX >= 0x02030000
        0,                                  /* tp_del */
#endif
#if PY_VERSION_HEX >= 0x02060000
        0,                                  /* tp_version_tag */
#endif
#if PY_VERSION_HEX >= 0x03040000
        0,                                  /* tp_finalize */
#endif
#ifdef COUNT_ALLOCS
        0,                                  /* tp_allocs */
        0,                                  /* tp_frees */
        0,                                  /* tp_maxalloc */
#if PY_VERSION_HEX >= 0x02050000
        0,                                  /* tp_prev */
#endif
        0                                   /* tp_next */
#endif
      };
      varlink_type = tmp;
      type_init = 1;
#if PY_VERSION_HEX < 0x02020000
      varlink_type.ob_type = &PyType_Type;
#else
      if (PyType_Ready(&varlink_type) < 0)
      return NULL;
#endif
    }
    return &varlink_type;
  }
  
  /* Create a variable linking object for use later */
  SWIGINTERN PyObject *
  SWIG_Python_newvarlink(void) {
    swig_varlinkobject *result = PyObject_NEW(swig_varlinkobject, swig_varlink_type());
    if (result) {
      result->vars = 0;
    }
    return ((PyObject*) result);
  }
  
  SWIGINTERN void 
  SWIG_Python_addvarlink(PyObject *p, char *name, PyObject *(*get_attr)(void), int (*set_attr)(PyObject *p)) {
    swig_varlinkobject *v = (swig_varlinkobject *) p;
    swig_globalvar *gv = (swig_globalvar *) malloc(sizeof(swig_globalvar));
    if (gv) {
      size_t size = strlen(name)+1;
      gv->name = (char *)malloc(size);
      if (gv->name) {
        strncpy(gv->name,name,size);
        gv->get_attr = get_attr;
        gv->set_attr = set_attr;
        gv->next = v->vars;
      }
    }
    v->vars = gv;
  }
  
  SWIGINTERN PyObject *
  SWIG_globals(void) {
    static PyObject *_SWIG_globals = 0; 
    if (!_SWIG_globals) _SWIG_globals = SWIG_newvarlink();  
    return _SWIG_globals;
  }
  
  /* -----------------------------------------------------------------------------
   * constants/methods manipulation
   * ----------------------------------------------------------------------------- */
  
  /* Install Constants */
  SWIGINTERN void
  SWIG_Python_InstallConstants(PyObject *d, swig_const_info constants[]) {
    PyObject *obj = 0;
    size_t i;
    for (i = 0; constants[i].type; ++i) {
      switch(constants[i].type) {
      case SWIG_PY_POINTER:
        obj = SWIG_InternalNewPointerObj(constants[i].pvalue, *(constants[i]).ptype,0);
        break;
      case SWIG_PY_BINARY:
        obj = SWIG_NewPackedObj(constants[i].pvalue, constants[i].lvalue, *(constants[i].ptype));
        break;
      default:
        obj = 0;
        break;
      }
      if (obj) {
        PyDict_SetItemString(d, constants[i].name, obj);
        Py_DECREF(obj);
      }
    }
  }
  
  /* -----------------------------------------------------------------------------*/
  /* Fix SwigMethods to carry the callback ptrs when needed */
  /* -----------------------------------------------------------------------------*/
  
  SWIGINTERN void
  SWIG_Python_FixMethods(PyMethodDef *methods,
    swig_const_info *const_table,
    swig_type_info **types,
    swig_type_info **types_initial) {
    size_t i;
    for (i = 0; methods[i].ml_name; ++i) {
      const char *c = methods[i].ml_doc;
      if (!c) continue;
      c = strstr(c, "swig_ptr: ");
      if (c) {
        int j;
        swig_const_info *ci = 0;
        const char *name = c + 10;
        for (j = 0; const_table[j].type; ++j) {
          if (strncmp(const_table[j].name, name, 
              strlen(const_table[j].name)) == 0) {
            ci = &(const_table[j]);
            break;
          }
        }
        if (ci) {
          void *ptr = (ci->type == SWIG_PY_POINTER) ? ci->pvalue : 0;
          if (ptr) {
            size_t shift = (ci->ptype) - types;
            swig_type_info *ty = types_initial[shift];
            size_t ldoc = (c - methods[i].ml_doc);
            size_t lptr = strlen(ty->name)+2*sizeof(void*)+2;
            char *ndoc = (char*)malloc(ldoc + lptr + 10);
            if (ndoc) {
              char *buff = ndoc;
              strncpy(buff, methods[i].ml_doc, ldoc);
              buff += ldoc;
              strncpy(buff, "swig_ptr: ", 10);
              buff += 10;
              SWIG_PackVoidPtr(buff, ptr, ty->name, lptr);
              methods[i].ml_doc = ndoc;
            }
          }
        }
      }
    }
  } 
  
#ifdef __cplusplus
}
#endif

/* -----------------------------------------------------------------------------*
 *  Partial Init method
 * -----------------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C"
#endif

SWIGEXPORT 
#if PY_VERSION_HEX >= 0x03000000
PyObject*
#else
void
#endif
SWIG_init(void) {
  PyObject *m, *d, *md;
#if PY_VERSION_HEX >= 0x03000000
  static struct PyModuleDef SWIG_module = {
# if PY_VERSION_HEX >= 0x03020000
    PyModuleDef_HEAD_INIT,
# else
    {
      PyObject_HEAD_INIT(NULL)
      NULL, /* m_init */
      0,    /* m_index */
      NULL, /* m_copy */
    },
# endif
    (char *) SWIG_name,
    NULL,
    -1,
    SwigMethods,
    NULL,
    NULL,
    NULL,
    NULL
  };
#endif
  
#if defined(SWIGPYTHON_BUILTIN)
  static SwigPyClientData SwigPyObject_clientdata = {
    0, 0, 0, 0, 0, 0, 0
  };
  static PyGetSetDef this_getset_def = {
    (char *)"this", &SwigPyBuiltin_ThisClosure, NULL, NULL, NULL
  };
  static SwigPyGetSet thisown_getset_closure = {
    (PyCFunction) SwigPyObject_own,
    (PyCFunction) SwigPyObject_own
  };
  static PyGetSetDef thisown_getset_def = {
    (char *)"thisown", SwigPyBuiltin_GetterClosure, SwigPyBuiltin_SetterClosure, NULL, &thisown_getset_closure
  };
  PyObject *metatype_args;
  PyTypeObject *builtin_pytype;
  int builtin_base_count;
  swig_type_info *builtin_basetype;
  PyObject *tuple;
  PyGetSetDescrObject *static_getset;
  PyTypeObject *metatype;
  SwigPyClientData *cd;
  PyObject *public_interface, *public_symbol;
  PyObject *this_descr;
  PyObject *thisown_descr;
  PyObject *self = 0;
  int i;
  
  (void)builtin_pytype;
  (void)builtin_base_count;
  (void)builtin_basetype;
  (void)tuple;
  (void)static_getset;
  (void)self;
  
  /* metatype is used to implement static member variables. */
  metatype_args = Py_BuildValue("(s(O){})", "SwigPyObjectType", &PyType_Type);
  assert(metatype_args);
  metatype = (PyTypeObject *) PyType_Type.tp_call((PyObject *) &PyType_Type, metatype_args, NULL);
  assert(metatype);
  Py_DECREF(metatype_args);
  metatype->tp_setattro = (setattrofunc) &SwigPyObjectType_setattro;
  assert(PyType_Ready(metatype) >= 0);
#endif
  
  /* Fix SwigMethods to carry the callback ptrs when needed */
  SWIG_Python_FixMethods(SwigMethods, swig_const_table, swig_types, swig_type_initial);
  
#if PY_VERSION_HEX >= 0x03000000
  m = PyModule_Create(&SWIG_module);
#else
  m = Py_InitModule((char *) SWIG_name, SwigMethods);
#endif
  
  md = d = PyModule_GetDict(m);
  (void)md;
  
  SWIG_InitializeModule(0);
  
#ifdef SWIGPYTHON_BUILTIN
  SwigPyObject_stype = SWIG_MangledTypeQuery("_p_SwigPyObject");
  assert(SwigPyObject_stype);
  cd = (SwigPyClientData*) SwigPyObject_stype->clientdata;
  if (!cd) {
    SwigPyObject_stype->clientdata = &SwigPyObject_clientdata;
    SwigPyObject_clientdata.pytype = SwigPyObject_TypeOnce();
  } else if (SwigPyObject_TypeOnce()->tp_basicsize != cd->pytype->tp_basicsize) {
    PyErr_SetString(PyExc_RuntimeError, "Import error: attempted to load two incompatible swig-generated modules.");
# if PY_VERSION_HEX >= 0x03000000
    return NULL;
# else
    return;
# endif
  }
  
  /* All objects have a 'this' attribute */
  this_descr = PyDescr_NewGetSet(SwigPyObject_type(), &this_getset_def);
  (void)this_descr;
  
  /* All objects have a 'thisown' attribute */
  thisown_descr = PyDescr_NewGetSet(SwigPyObject_type(), &thisown_getset_def);
  (void)thisown_descr;
  
  public_interface = PyList_New(0);
  public_symbol = 0;
  (void)public_symbol;
  
  PyDict_SetItemString(md, "__all__", public_interface);
  Py_DECREF(public_interface);
  for (i = 0; SwigMethods[i].ml_name != NULL; ++i)
  SwigPyBuiltin_AddPublicSymbol(public_interface, SwigMethods[i].ml_name);
  for (i = 0; swig_const_table[i].name != 0; ++i)
  SwigPyBuiltin_AddPublicSymbol(public_interface, swig_const_table[i].name);
#endif
  
  SWIG_InstallConstants(d,swig_const_table);
  
#if PY_VERSION_HEX >= 0x03000000
  return m;
#else
  return;
#endif
}

